@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.h
  * \brief Includes channel mode related definitions and structures.
- * \version $Id: channel_mode.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: channel_mode.h 7763 2016-10-06 16:59:51Z michael $
  */
 
 #ifndef INCLUDED_channel_mode_h
@@ -127,6 +127,5 @@ extern const struct ChannelMode ModeTable[];
 extern int add_id(struct Client *, struct Channel *, char *, unsigned int);
 extern void set_channel_mode(struct Client *, struct Channel *,
                              struct Membership *, int, char **);
-extern void clear_ban_cache_channel(struct Channel *);
-extern void clear_ban_cache_client(struct Client *);
+extern void clear_ban_cache_list(dlink_list *);
 #endif /* INCLUDED_channel_mode_h */
