@@ -21,7 +21,7 @@
 
 /*! \file client.h
  * \brief Header including structures, macros and prototypes for client handling
- * \version $Id: client.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: client.h 7863 2016-11-08 20:17:03Z michael $
  */
 
 
@@ -30,13 +30,11 @@
 
 #include "list.h"
 #include "fdlist.h"
-#include "config.h"
 #include "ircd_defs.h"
 #include "dbuf.h"
 #include "channel.h"
 #include "auth.h"
 
-struct MaskItem;
 
 /*
  * status macros.
@@ -132,15 +130,14 @@ enum
   FLAGS_HIDDEN        = 0x00004000U,  /**< A hidden server. Not shown in /links */
   FLAGS_BLOCKED       = 0x00008000U,  /**< Must wait for COMM_SELECT_WRITE */
   FLAGS_USERHOST      = 0x00010000U,  /**< Client is in userhost hash */
-  FLAGS_BURSTED       = 0x00020000U,  /**< User was already bursted */
-  FLAGS_EXEMPTRESV    = 0x00040000U,  /**< Client is exempt from RESV */
-  FLAGS_GOTUSER       = 0x00080000U,  /**< If we received a USER command */
-  FLAGS_FINISHED_AUTH = 0x00100000U,  /**< Client has been released from auth */
-  FLAGS_FLOOD_NOTICED = 0x00200000U,  /**< Notice to opers about this flooder has been sent */
-  FLAGS_SERVICE       = 0x00400000U,  /**< Client/server is a network service */
-  FLAGS_SSL           = 0x00800000U,  /**< User is connected via TLS/SSL */
-  FLAGS_SQUIT         = 0x01000000U,
-  FLAGS_EXEMPTXLINE   = 0x02000000U   /**< Client is exempt from x-lines */
+  FLAGS_EXEMPTRESV    = 0x00020000U,  /**< Client is exempt from RESV */
+  FLAGS_GOTUSER       = 0x00040000U,  /**< If we received a USER command */
+  FLAGS_FINISHED_AUTH = 0x00080000U,  /**< Client has been released from auth */
+  FLAGS_FLOOD_NOTICED = 0x00100000U,  /**< Notice to opers about this flooder has been sent */
+  FLAGS_SERVICE       = 0x00200000U,  /**< Client/server is a network service */
+  FLAGS_SSL           = 0x00400000U,  /**< User is connected via TLS/SSL */
+  FLAGS_SQUIT         = 0x00800000U,
+  FLAGS_EXEMPTXLINE   = 0x01000000U   /**< Client is exempt from x-lines */
 };
 
 #define HasFlag(x, y) ((x)->flags &   (y))
@@ -205,18 +202,19 @@ enum
   OPER_FLAG_NICK_RESV      = 0x00002000U,  /**< Oper can use NICK on resv {} nicks */
   OPER_FLAG_OPME           = 0x00004000U,  /**< Oper can use OPME command */
   OPER_FLAG_REHASH         = 0x00008000U,  /**< Oper can use REHASH command */
-  OPER_FLAG_REMOTEBAN      = 0x00010000U,  /**< Oper can set remote bans */
-  OPER_FLAG_RESTART        = 0x00020000U,  /**< Oper can use RESTART command */
-  OPER_FLAG_RESV           = 0x00040000U,  /**< Oper can use RESV command */
-  OPER_FLAG_SET            = 0x00080000U,  /**< Oper can use SET command */
-  OPER_FLAG_SQUIT          = 0x00100000U,  /**< Oper can do local SQUIT */
-  OPER_FLAG_SQUIT_REMOTE   = 0x00200000U,  /**< Oper can do remote SQUIT */
-  OPER_FLAG_UNDLINE        = 0x00400000U,  /**< Oper can use UNDLINE command */
-  OPER_FLAG_UNKLINE        = 0x00800000U,  /**< Oper can use UNKLINE command */
-  OPER_FLAG_UNRESV         = 0x01000000U,  /**< Oper can use UNRESV command */
-  OPER_FLAG_UNXLINE        = 0x02000000U,  /**< Oper can use UNXLINE command */
-  OPER_FLAG_WALLOPS        = 0x04000000U,  /**< Oper can use WALLOPS command */
-  OPER_FLAG_XLINE          = 0x08000000U   /**< Oper can use XLINE command */
+  OPER_FLAG_REHASH_REMOTE  = 0x00010000U,  /**< Oper can do remote REHASH command */
+  OPER_FLAG_REMOTEBAN      = 0x00020000U,  /**< Oper can set remote bans */
+  OPER_FLAG_RESTART        = 0x00040000U,  /**< Oper can use RESTART command */
+  OPER_FLAG_RESV           = 0x00080000U,  /**< Oper can use RESV command */
+  OPER_FLAG_SET            = 0x00100000U,  /**< Oper can use SET command */
+  OPER_FLAG_SQUIT          = 0x00200000U,  /**< Oper can do local SQUIT */
+  OPER_FLAG_SQUIT_REMOTE   = 0x00400000U,  /**< Oper can do remote SQUIT */
+  OPER_FLAG_UNDLINE        = 0x00800000U,  /**< Oper can use UNDLINE command */
+  OPER_FLAG_UNKLINE        = 0x01000000U,  /**< Oper can use UNKLINE command */
+  OPER_FLAG_UNRESV         = 0x02000000U,  /**< Oper can use UNRESV command */
+  OPER_FLAG_UNXLINE        = 0x04000000U,  /**< Oper can use UNXLINE command */
+  OPER_FLAG_WALLOPS        = 0x08000000U,  /**< Oper can use WALLOPS command */
+  OPER_FLAG_XLINE          = 0x10000000U   /**< Oper can use XLINE command */
 };
 
 #define HasOFlag(x, y) ((x)->connection->operflags &   (y))
@@ -243,6 +241,14 @@ enum
 #define IsHidden(x)             ((x)->flags &  FLAGS_HIDDEN)
 
 
+/*! \brief server ban types */
+enum
+{
+  CLIENT_BAN_KLINE,
+  CLIENT_BAN_DLINE,
+  CLIENT_BAN_XLINE
+};
+
 /*! \brief addr_mask_type enumeration */
 enum addr_mask_type
 {
@@ -303,20 +309,20 @@ struct Connection
 
   uintmax_t serial;     /**< Used to enforce 1 send per nick */
 
-  time_t       lasttime;   /**< Last time data read from socket */
-  time_t       firsttime;  /**< Time client was created */
-  time_t       since;      /**< Last time we parsed something */
-  time_t       last_join_time;   /**< When this client last joined a channel */
-  time_t       last_leave_time;  /**< When this client last left a channel */
+  uintmax_t    lasttime;   /**< Last time data read from socket */
+  uintmax_t    firsttime;  /**< Time client was created */
+  uintmax_t    since;      /**< Last time we parsed something */
+  uintmax_t    last_join_time;   /**< When this client last joined a channel */
+  uintmax_t    last_leave_time;  /**< When this client last left a channel */
   int          join_leave_count; /**< Count of JOIN/LEAVE in less than
                                          MIN_JOIN_LEAVE_TIME seconds */
   int          oper_warn_count_down; /**< Warn opers of this possible
                                           spambot every time this gets to 0 */
-  time_t       last_caller_id_time;
-  time_t       first_received_message_time;
-  time_t       last_privmsg;  /**< Last time we got a PRIVMSG */
+  uintmax_t    last_caller_id_time;
+  uintmax_t    first_received_message_time;
+  uintmax_t    last_privmsg;  /**< Last time we got a PRIVMSG */
 
-  int          received_number_of_privmsgs;
+  unsigned int received_number_of_privmsgs;
 
   struct ListTask  *list_task;
 
@@ -332,7 +338,7 @@ struct Connection
   struct
   {
     unsigned int count;  /**< How many AWAY/INVITE/KNOCK/NICK requests client has sent */
-    time_t last_attempt;  /**< Last time the AWAY/INVITE/KNOCK/NICK request was issued */
+    uintmax_t last_attempt;  /**< Last time the AWAY/INVITE/KNOCK/NICK request was issued */
   } away, invite, knock, nick;
 
   struct AuthRequest auth;
@@ -371,7 +377,7 @@ struct Client
   struct Client    *servptr;    /**< Points to server this Client is on */
   struct Client    *from;       /**< == self, if Local Client, *NEVER* NULL! */
 
-  time_t            tsinfo;     /**< TS on the nick, SVINFO on server */
+  uintmax_t         tsinfo;     /**< TS on the nick, SVINFO on server */
 
   unsigned int      flags;      /**< Client flags */
   unsigned int      umodes;     /**< User modes this client has set */
@@ -379,7 +385,7 @@ struct Client
   unsigned int      status;     /**< Client type */
   unsigned int      handler;    /**< Handler index */
 
-  dlink_list        whowas;
+  dlink_list        whowas_list;
   dlink_list        channel;   /**< Chain of channel pointer blocks */
   dlink_list        svstags;   /**< List of ServicesTag items */
 
@@ -436,12 +442,12 @@ extern unsigned int client_get_idle_time(const struct Client *, const struct Cli
 extern struct split_nuh_item *find_accept(const char *, const char *,
                                           const char *, struct Client *,
                                           int (*)(const char *, const char *));
-extern void client_attach_svstag(struct Client *, unsigned int, const char *, const char *const);
+extern void client_attach_svstag(struct Client *, unsigned int, const char *, const char *);
 extern void client_clear_svstags(struct Client *);
 extern void del_accept(struct split_nuh_item *, struct Client *);
 extern void del_all_accepts(struct Client *);
 extern void exit_client(struct Client *, const char *);
-extern void conf_try_ban(struct Client *, struct MaskItem *);
+extern void conf_try_ban(struct Client *, int, const char *);
 extern void check_conf_klines(void);
 extern void client_init(void);
 extern void dead_link_on_write(struct Client *, int);
@@ -450,7 +456,7 @@ extern void exit_aborted_clients(void);
 extern void free_exited_clients(void);
 extern struct Client *make_client(struct Client *);
 extern struct Client *find_chasing(struct Client *, const char *);
-extern struct Client *find_person(const struct Client *const, const char *);
+extern struct Client *find_person(const struct Client *, const char *);
 extern const char *get_client_name(const struct Client *, enum addr_mask_type);
 
 #endif /* INCLUDED_client_h */
