@@ -21,7 +21,7 @@
 
 /*! \file conf.h
  * \brief A header for the configuration functions.
- * \version $Id: conf.h 7534 2016-04-11 14:46:54Z michael $
+ * \version $Id: conf.h 7859 2016-11-08 20:09:29Z michael $
  */
 
 #ifndef INCLUDED_conf_h
@@ -210,6 +210,7 @@ struct config_general_entry
   unsigned int min_nonwildcard_simple;
   unsigned int kill_chase_time_limit;
   unsigned int default_floodcount;
+  unsigned int default_floodtime;
   unsigned int throttle_count;
   unsigned int throttle_time;
   unsigned int ping_cookie;
@@ -223,9 +224,11 @@ struct config_channel_entry
   unsigned int invite_client_count;
   unsigned int invite_client_time;
   unsigned int invite_delay_channel;
+  unsigned int invite_expire_time;
   unsigned int knock_client_count;
   unsigned int knock_client_time;
   unsigned int knock_delay_channel;
+  unsigned int max_invites;
   unsigned int max_bans;
   unsigned int max_channels;
   unsigned int default_join_flood_count;
