@@ -21,7 +21,7 @@
 
 /*! \file irc_string.h
  * \brief A header for the ircd string functions.
- * \version $Id: irc_string.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: irc_string.h 7796 2016-10-18 17:26:37Z michael $
  */
 
 #ifndef INCLUDED_irc_string_h
@@ -33,7 +33,7 @@
 extern int has_wildcards(const char *);
 extern int match(const char *, const char *);
 
-extern int token_vector(char *, char, char *[], int);
+extern unsigned int token_vector(char *, char, char *[], unsigned int);
 
 /*
  * collapse - collapse a string in place, converts multiple adjacent *'s
@@ -66,11 +66,7 @@ extern size_t strlcat(char *, const char *, size_t);
 
 extern const char *libio_basename(const char *);
 
-/*
- * strip_tabs - convert tabs to spaces
- * - jdc
- */
-extern void strip_tabs(char *, const char *, size_t);
+extern const char *stripws(char *);
 
 #define EmptyString(x) (!(x) || (*(x) == '\0'))
 
