@@ -21,7 +21,7 @@
 
 /*! \file res.h
  * \brief ircd resolver functions
- * \version $Id: res.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: res.h 7667 2016-07-20 17:09:36Z michael $
  */
 
 #ifndef INCLUDED_res_h
@@ -112,7 +112,7 @@ typedef struct
 
 typedef void (*dns_callback_fnc)(void *, const struct irc_ssaddr *, const char *, size_t);
 
-extern void init_resolver(void);
+extern void resolver_init(void);
 extern void restart_resolver(void);
 extern void delete_resolver_queries(const void *);
 extern void gethost_byname_type(dns_callback_fnc , void *, const char *, int);
