@@ -21,7 +21,7 @@
 
 /*! \file server.h
  * \brief A header for the server functions.
- * \version $Id: server.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: server.h 7667 2016-07-20 17:09:36Z michael $
  */
 
 #ifndef INCLUDED_server_h
@@ -86,13 +86,13 @@ enum
 extern int valid_servname(const char *);
 extern int check_server(const char *, struct Client *);
 extern int hunt_server(struct Client *, const char *, const int, const int, char *[]);
+extern void server_capab_init(void);
 extern void add_capability(const char *, unsigned int);
 extern void delete_capability(const char *);
 extern unsigned int find_capability(const char *);
-extern void send_capabilities(struct Client *);
+extern const char *get_capabilities(const struct Client *);
 extern void write_links_file(void *);
 extern void read_links_file(void);
-extern const char *show_capabilities(const struct Client *);
 extern void try_connections(void *);
 extern int serv_connect(struct MaskItem *, struct Client *);
 extern struct Client *find_servconn_in_progress(const char *);
