@@ -19,7 +19,7 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  *  USA
  *
- * $Id: stdinc.h 6952 2015-12-15 19:30:05Z michael $
+ * $Id: stdinc.h 7667 2016-07-20 17:09:36Z michael $
  *
  */
 
@@ -41,11 +41,6 @@
 #include <crypt.h>
 #endif
 
-#ifdef HAVE_LIBCRYPTO
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#endif
-
 #ifdef HAVE_LIBGEOIP
 #include <GeoIP.h>
 #endif
