@@ -21,7 +21,7 @@
 
 /*! \file user.h
  * \brief A header for the user functions.
- * \version $Id: user.h 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: user.h 7667 2016-07-20 17:09:36Z michael $
  */
 
 #ifndef INCLUDED_user_h
@@ -39,7 +39,7 @@ extern const struct user_modes *umode_map[];
 extern const struct user_modes  umode_tab[];
 
 extern void user_modes_init(void);
-extern void send_umode(struct Client *, struct Client *,
+extern void send_umode(struct Client *, unsigned int,
                        unsigned int, char *);
 extern void send_umode_out(struct Client *, unsigned int);
 extern void show_lusers(struct Client *);
