@@ -21,7 +21,7 @@
 
 /*! \file m_bmask.c
  * \brief Includes required functions for processing the BMASK command.
- * \version $Id: m_bmask.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_bmask.c 7329 2016-02-18 21:07:50Z michael $
  */
 
 #include "stdinc.h"
@@ -68,7 +68,7 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   /* TS is higher, drop it. */
-  if (strtoimax(parv[1], NULL, 10) > chptr->creationtime)
+  if (strtoumax(parv[1], NULL, 10) > chptr->creationtime)
     return 0;
 
   switch (*parv[3])
@@ -168,7 +168,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7329 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
