@@ -21,7 +21,7 @@
 
 /*! \file m_join.c
  * \brief Includes required functions for processing the JOIN command.
- * \version $Id: m_join.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_join.c 7356 2016-02-22 18:59:30Z michael $
  */
 
 #include "stdinc.h"
@@ -36,9 +36,9 @@
 #include "send.h"
 #include "server.h"
 #include "conf.h"
+#include "conf_resv.h"
 #include "parse.h"
 #include "modules.h"
-#include "resv.h"
 
 
 static void set_final_mode(const struct Mode *, const struct Mode *);
@@ -91,8 +91,8 @@ m_join(struct Client *source_p, int parc, char *parv[])
 static int
 ms_join(struct Client *source_p, int parc, char *parv[])
 {
-  time_t newts = 0;
-  time_t oldts = 0;
+  uintmax_t newts = 0;
+  uintmax_t oldts = 0;
   int keep_our_modes = 1;
   int keep_new_modes = 1;
   int isnew = 0;
@@ -130,7 +130,7 @@ ms_join(struct Client *source_p, int parc, char *parv[])
     chptr = channel_make(parv[2]);
   }
 
-  newts   = strtoimax(parv[1], NULL, 10);
+  newts   = strtoumax(parv[1], NULL, 10);
   oldts   = chptr->creationtime;
   oldmode = &chptr->mode;
 
@@ -319,7 +319,7 @@ set_final_mode(const struct Mode *mode, const struct Mode *oldmode)
     }
 
     *mbuf++ = 'l';
-    len = sprintf(pbuf, "%d ", mode->limit);
+    len = sprintf(pbuf, "%u ", mode->limit);
     pbuf += len;
   }
 
@@ -460,7 +460,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7356 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
