@@ -21,7 +21,7 @@
 
 /*! \file m_nick.c
  * \brief Includes required functions for processing the NICK command.
- * \version $Id: m_nick.c 7329 2016-02-18 21:07:50Z michael $
+ * \version $Id: m_nick.c 7763 2016-10-06 16:59:51Z michael $
  */
 
 #include "stdinc.h"
@@ -200,24 +200,14 @@ set_initial_nick(struct Client *source_p, const char *nick)
 static void
 change_local_nick(struct Client *source_p, const char *nick)
 {
-  int samenick = 0;
-
   assert(source_p->name[0] && !EmptyString(nick));
   assert(MyClient(source_p));
 
-  /*
-   * Client just changing his/her nick. If he/she is
-   * on a channel, send note of change to all clients
-   * on that channel. Propagate notice to other servers.
-   */
-  if ((source_p->connection->nick.last_attempt +
-       ConfigGeneral.max_nick_time) < CurrentTime)
+  if ((source_p->connection->nick.last_attempt + ConfigGeneral.max_nick_time) < CurrentTime)
     source_p->connection->nick.count = 0;
 
-  if (ConfigGeneral.anti_nick_flood &&
-      !HasUMode(source_p, UMODE_OPER) &&
-      source_p->connection->nick.count >
-      ConfigGeneral.max_nick_changes)
+  if (ConfigGeneral.anti_nick_flood && !HasUMode(source_p, UMODE_OPER) &&
+      (source_p->connection->nick.count > ConfigGeneral.max_nick_changes))
   {
     sendto_one_numeric(source_p, &me, ERR_NICKTOOFAST, nick,
                        ConfigGeneral.max_nick_time);
@@ -227,12 +217,12 @@ change_local_nick(struct Client *source_p, const char *nick)
   source_p->connection->nick.last_attempt = CurrentTime;
   source_p->connection->nick.count++;
 
-  samenick = !irccmp(source_p->name, nick);
+  int samenick = !irccmp(source_p->name, nick);
 
   if (!samenick)
   {
     source_p->tsinfo = CurrentTime;
-    clear_ban_cache_client(source_p);
+    clear_ban_cache_list(&source_p->channel);
     watch_check_hash(source_p, RPL_LOGOFF);
 
     if (HasUMode(source_p, UMODE_REGISTERED))
@@ -241,10 +231,15 @@ change_local_nick(struct Client *source_p, const char *nick)
       char modebuf[IRCD_BUFSIZE] = "";
 
       DelUMode(source_p, UMODE_REGISTERED);
-      send_umode(source_p, source_p, oldmodes, modebuf);
+      send_umode(source_p, 1, oldmodes, modebuf);
     }
   }
 
+  /*
+   * Client just changing his/her nick. If he/she is on a channel,
+   * send note of change to all clients on that channel. Propagate
+   * notice to other servers.
+   */
   sendto_realops_flags(UMODE_NCHANGE, L_ALL, SEND_NOTICE,
                        "Nick change: From %s to %s [%s@%s]",
                        source_p->name, nick, source_p->username, source_p->host);
@@ -283,13 +278,13 @@ change_local_nick(struct Client *source_p, const char *nick)
 static void
 change_remote_nick(struct Client *source_p, char *parv[])
 {
-  const int samenick = !irccmp(source_p->name, parv[1]);
-
   assert(!EmptyString(parv[1]));
   assert(IsClient(source_p));
   assert(source_p->name[0]);
 
   /* Client changing their nick */
+  int samenick = !irccmp(source_p->name, parv[1]);
+
   if (!samenick)
   {
     DelUMode(source_p, UMODE_REGISTERED);
@@ -298,6 +293,9 @@ change_remote_nick(struct Client *source_p, char *parv[])
     assert(source_p->tsinfo > 0);
   }
 
+  sendto_realops_flags(UMODE_NCHANGE, L_ALL, SEND_NOTICE,
+                       "Nick change: From %s to %s [%s@%s]",
+                       source_p->name, parv[1], source_p->username, source_p->host);
   sendto_common_channels_local(source_p, 1, 0, 0, ":%s!%s@%s NICK :%s",
                                source_p->name, source_p->username,
                                source_p->host, parv[1]);
@@ -402,7 +400,6 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
 {
   const char *uid = parv[8];
   uintmax_t newts = strtoumax(parv[3], NULL, 10);
-  int sameuser = 0;
 
   assert(IsServer(source_p));
   assert(IsClient(target_p));
@@ -431,8 +428,8 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
   }
 
   /* The timestamps are different */
-  sameuser = !irccmp(target_p->username, parv[5]) &&
-             !irccmp(target_p->sockhost, parv[7]);
+  int sameuser = !irccmp(target_p->username, parv[5]) &&
+                 !irccmp(target_p->sockhost, parv[7]);
 
   /*
    * If the users are the same (loaded a client on a different server)
@@ -487,7 +484,6 @@ static int
 perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
                              int parc, char *parv[])
 {
-  int sameuser = 0;
   uintmax_t newts = strtoumax(parv[2], NULL, 10);
 
   assert(IsClient(source_p));
@@ -518,8 +514,8 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
   }
 
   /* The timestamps are different */
-  sameuser = !irccmp(target_p->username, source_p->username) &&
-             !irccmp(target_p->sockhost, source_p->sockhost);
+  int sameuser = !irccmp(target_p->username, source_p->username) &&
+                 !irccmp(target_p->sockhost, source_p->sockhost);
 
   if ((sameuser && newts < target_p->tsinfo) ||
       (!sameuser && newts > target_p->tsinfo))
@@ -532,8 +528,8 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
     else
       sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
            "Nick change collision from %s to %s(%s <- %s)(newer killed)",
-             source_p->name, target_p->name, target_p->from->name,
-             source_p->from->name);
+           source_p->name, target_p->name, target_p->from->name,
+           source_p->from->name);
 
     ++ServerStats.is_kill;
 
@@ -680,7 +676,7 @@ m_nick(struct Client *source_p, int parc, char *parv[])
   {
     /*
      * If (target_p == source_p) the client is changing nicks between
-     * equivalent nicknames ie: [nick] -> {nick}
+     * equivalent nicknames ie: nick -> nIcK
      */
 
     /* Check the nick isn't exactly the same */
@@ -690,8 +686,8 @@ m_nick(struct Client *source_p, int parc, char *parv[])
   else if (IsUnknown(target_p))
   {
     /*
-     * If the client that has the nick isn't registered yet (nick but no
-     * user) then drop the unregged client
+     * If the client that has the nick isn't registered yet (NICK but no
+     * USER) then drop the unregistered client
      */
     exit_client(target_p, "Overridden by other sign on");
     change_local_nick(source_p, nick);
@@ -853,7 +849,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7329 $",
+  .version = "$Revision: 7763 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
