@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_sjoin.c
  * \brief Includes required functions for processing the SJOIN command.
- * \version $Id: m_sjoin.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_sjoin.c 7763 2016-10-06 16:59:51Z michael $
  */
 
 #include "stdinc.h"
@@ -71,16 +71,16 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
 {
   struct Channel *chptr = NULL;
   struct Client  *target_p = NULL;
-  time_t         newts;
-  time_t         oldts;
-  time_t         tstosend;
+  uintmax_t newts;
+  uintmax_t oldts;
+  uintmax_t tstosend;
   struct Mode mode, *oldmode;
   int            args = 0;
   char           keep_our_modes = 1;
   char           keep_new_modes = 1;
-  char           have_many_nicks = 0;
+  char           have_many_uids = 0;
   int            lcount;
-  char           uid_prefix[4];
+  char           uid_prefix[CMEMBER_STATUS_FLAGS_LEN + 1];
   char           *up = NULL;
   int            len_uid = 0;
   int            isnew = 0;
@@ -98,7 +98,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   if (!IsServer(source_p))
     return 0;
 
-  if (!check_channel_name(parv[2], 0))
+  if (!channel_check_name(parv[2], 0))
   {
     sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
                          "*** Too long or invalid channel name from %s(via %s): %s",
@@ -109,7 +109,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   modebuf[0] = '\0';
   mbuf = modebuf;
   pargs = 0;
-  newts = atol(parv[1]);
+  newts = strtoumax(parv[1], NULL, 10);
 
   mode.mode = 0;
   mode.limit = 0;
@@ -144,11 +144,11 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   if ((chptr = hash_find_channel(parv[2])) == NULL)
   {
     isnew = 1;
-    chptr = make_channel(parv[2]);
+    chptr = channel_make(parv[2]);
   }
 
   parabuf[0] = '\0';
-  oldts = chptr->channelts;
+  oldts = chptr->creationtime;
   oldmode = &chptr->mode;
 
   if (ConfigGeneral.ignore_bogus_ts)
@@ -156,8 +156,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     if (newts < 800000000)
     {
       sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
-                           "*** Bogus TS %lu on %s ignored from %s(via %s)",
-                           (unsigned long)newts, chptr->chname,
+                           "*** Bogus TS %ju on %s ignored from %s(via %s)",
+                           newts, chptr->name,
                            source_p->name, source_p->from->name);
 
       newts = (oldts == 0) ? 0 : 800000000;
@@ -167,25 +167,25 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   {
     if (!newts && !isnew && oldts)
     {
-      sendto_channel_local(ALL_MEMBERS, 0, chptr,
-                           ":%s NOTICE %s :*** Notice -- TS for %s changed from %lu to 0",
-                           me.name, chptr->chname, chptr->chname, (unsigned long)oldts);
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "Server %s changing TS on %s from %lu to 0",
-                           source_p->name, chptr->chname, (unsigned long)oldts);
+      sendto_channel_local(NULL, chptr, 0, 0, 0,
+                           ":%s NOTICE %s :*** Notice -- TS for %s changed from %ju to 0",
+                           me.name, chptr->name, chptr->name, oldts);
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                           "Server %s changing TS on %s from %ju to 0",
+                           source_p->name, chptr->name, oldts);
     }
   }
 
   if (isnew)
-    chptr->channelts = tstosend = newts;
+    chptr->creationtime = tstosend = newts;
   else if (newts == 0 || oldts == 0)
-    chptr->channelts = tstosend = 0;
+    chptr->creationtime = tstosend = 0;
   else if (newts == oldts)
     tstosend = oldts;
   else if (newts < oldts)
   {
     keep_our_modes = 0;
-    chptr->channelts = tstosend = newts;
+    chptr->creationtime = tstosend = newts;
   }
   else
   {
@@ -211,29 +211,45 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   /* Lost the TS, other side wins, so remove modes on this side */
   if (!keep_our_modes)
   {
+    /* Update channel name to be the correct case */
+    if (!isnew)
+      strlcpy(chptr->name, parv[2], sizeof(chptr->name));
+
     remove_our_modes(chptr, source_p);
 
+    if (dlink_list_length(&chptr->banlist))
+      remove_ban_list(chptr, source_p, &chptr->banlist, 'b');
+
+    if (dlink_list_length(&chptr->exceptlist))
+      remove_ban_list(chptr, source_p, &chptr->exceptlist, 'e');
+
+    if (dlink_list_length(&chptr->invexlist))
+      remove_ban_list(chptr, source_p, &chptr->invexlist, 'I');
+
+    clear_ban_cache_list(&chptr->locmembers);
+    clear_invite_list(&chptr->invites);
+
     if (chptr->topic[0])
     {
       channel_set_topic(chptr, "", "", 0, 0);
-      sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s TOPIC %s :",
+      sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s TOPIC %s :",
                            (IsHidden(source_p) ||
                            ConfigServerHide.hide_servers) ?
-                           me.name : source_p->name, chptr->chname);
+                           me.name : source_p->name, chptr->name);
     }
 
-    sendto_channel_local(ALL_MEMBERS, 0, chptr,
-                         ":%s NOTICE %s :*** Notice -- TS for %s changed from %lu to %lu",
-                         me.name, chptr->chname, chptr->chname,
-                         (unsigned long)oldts, (unsigned long)newts);
+    sendto_channel_local(NULL, chptr, 0, 0, 0,
+                         ":%s NOTICE %s :*** Notice -- TS for %s changed from %ju to %ju",
+                         me.name, chptr->name, chptr->name,
+                         oldts, newts);
   }
 
   if (*modebuf != '\0')
   {
     /* This _SHOULD_ be to ALL_MEMBERS
      * It contains only +imnpstlk, etc */
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s MODE %s %s %s",
-                         servername, chptr->chname, modebuf, parabuf);
+    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s %s",
+                         servername, chptr->name, modebuf, parabuf);
   }
 
   if (*parv[3] != '0' && keep_new_modes)
@@ -244,18 +260,18 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     modebuf[1] = '\0';
   }
 
-  buflen = snprintf(uid_buf, sizeof(uid_buf), ":%s SJOIN %lu %s %s %s:",
-                    source_p->id, (unsigned long)tstosend,
-                    chptr->chname, modebuf, parabuf);
+  buflen = snprintf(uid_buf, sizeof(uid_buf), ":%s SJOIN %ju %s %s %s:",
+                    source_p->id, tstosend,
+                    chptr->name, modebuf, parabuf);
   uid_ptr = uid_buf + buflen;
 
   /*
    * Check we can fit a nick on the end, as well as \r\n and a prefix "
    * @%+", and a space.
    */
-  if (buflen >= (IRCD_BUFSIZE - IRCD_MAX(NICKLEN, IDLEN) - 2 - 3 - 1))
+  if (buflen >= (IRCD_BUFSIZE - IDLEN - 2 - CMEMBER_STATUS_FLAGS_LEN - 1))
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Long SJOIN from server: %s(via %s) (ignored)",
                          source_p->name, source_p->from->name);
     return 0;
@@ -277,7 +293,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
 
     while (*p == ' ')
       ++p;
-    have_many_nicks = *p;
+    have_many_uids = *p;
   }
 
   while (*s)
@@ -308,12 +324,12 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     } while (valid_mode);
 
     /*
-     * If the client doesnt exist, or if it's fake direction/server, skip.
+     * If the client doesn't exist, or if it's fake direction/server, skip.
      * we cannot send ERR_NOSUCHNICK here because if it's a UID, we cannot
      * lookup the nick, and it's better to never send the numeric than only
      * sometimes.
      */
-    if ((target_p = find_chasing(source_p, s)) == NULL || target_p->from != source_p->from)
+    if ((target_p = find_person(source_p, s)) == NULL || target_p->from != source_p->from)
       goto nextnick;
 
     len_uid = strlen(target_p->id);
@@ -346,27 +362,32 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
 
     if ((uid_ptr - uid_buf + len_uid) > (IRCD_BUFSIZE - 2))
     {
-      sendto_server(source_p, NOCAPS, NOCAPS, "%s", uid_buf);
+      sendto_server(source_p, 0, 0, "%s", uid_buf);
 
-      buflen = snprintf(uid_buf, sizeof(uid_buf), ":%s SJOIN %lu %s %s %s:",
-                        source_p->id, (unsigned long)tstosend,
-                        chptr->chname, modebuf, parabuf);
+      buflen = snprintf(uid_buf, sizeof(uid_buf), ":%s SJOIN %ju %s %s %s:",
+                        source_p->id, tstosend,
+                        chptr->name, modebuf, parabuf);
       uid_ptr = uid_buf + buflen;
     }
 
-    uid_ptr += sprintf(uid_ptr,  "%s%s ", uid_prefix, target_p->id);
+    uid_ptr += sprintf(uid_ptr, "%s%s ", uid_prefix, target_p->id);
 
     if (!IsMember(target_p, chptr))
     {
-      add_user_to_channel(chptr, target_p, fl, !have_many_nicks);
-      sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s JOIN :%s",
+      add_user_to_channel(chptr, target_p, fl, !have_many_uids);
+
+      sendto_channel_local(NULL, chptr, 0, CAP_EXTENDED_JOIN, 0, ":%s!%s@%s JOIN %s %s :%s",
                            target_p->name, target_p->username,
-                           target_p->host, chptr->chname);
+                           target_p->host, chptr->name, target_p->account, target_p->info);
+      sendto_channel_local(NULL, chptr, 0, 0, CAP_EXTENDED_JOIN, ":%s!%s@%s JOIN :%s",
+                           target_p->name, target_p->username,
+                           target_p->host, chptr->name);
+
       if (target_p->away[0])
-        sendto_channel_local_butone(target_p, 0, CAP_AWAY_NOTIFY, chptr,
-                                    ":%s!%s@%s AWAY :%s",
-                                    target_p->name, target_p->username,
-                                    target_p->host, target_p->away);
+        sendto_channel_local(target_p, chptr, 0, CAP_AWAY_NOTIFY, 0,
+                             ":%s!%s@%s AWAY :%s",
+                             target_p->name, target_p->username,
+                             target_p->host, target_p->away);
     }
 
     if (fl & CHFL_CHANOP)
@@ -394,8 +415,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
           sptr += slen;  /* ready for next */
         }
 
-        sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s MODE %s %s%s",
-                            servername, chptr->chname, modebuf, sendbuf);
+        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
+                             servername, chptr->name, modebuf, sendbuf);
         mbuf = modebuf;
         *mbuf++ = '+';
 
@@ -420,8 +441,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
           sptr += slen;
         }
 
-        sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s MODE %s %s%s",
-                             servername, chptr->chname, modebuf, sendbuf);
+        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
+                             servername, chptr->name, modebuf, sendbuf);
 
         mbuf = modebuf;
         *mbuf++ = '+';
@@ -447,8 +468,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
           sptr += slen;
         }
 
-        sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s MODE %s %s%s",
-                             servername, chptr->chname, modebuf, sendbuf);
+        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
+                             servername, chptr->name, modebuf, sendbuf);
 
         mbuf = modebuf;
         *mbuf++ = '+';
@@ -495,8 +516,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
       sptr += slen;
     }
 
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s MODE %s %s%s",
-                         servername, chptr->chname, modebuf, sendbuf);
+    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
+                         servername, chptr->name, modebuf, sendbuf);
   }
 
   /*
@@ -508,28 +529,14 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
    */
   if (!dlink_list_length(&chptr->members) && isnew)
   {
-    destroy_channel(chptr);
+    channel_free(chptr);
     return 0;
   }
 
   if (*parv[4 + args] == '\0')
     return 0;
 
-  sendto_server(source_p, NOCAPS, NOCAPS, "%s", uid_buf);
-
-  if (!keep_our_modes)
-  {
-    if (dlink_list_length(&chptr->banlist))
-      remove_ban_list(chptr, source_p, &chptr->banlist, 'b');
-
-    if (dlink_list_length(&chptr->exceptlist))
-      remove_ban_list(chptr, source_p, &chptr->exceptlist, 'e');
-
-    if (dlink_list_length(&chptr->invexlist))
-      remove_ban_list(chptr, source_p, &chptr->invexlist, 'I');
-    clear_ban_cache(chptr);
-  }
-
+  sendto_server(source_p, 0, 0, "%s", uid_buf);
   return 0;
 }
 
@@ -552,14 +559,13 @@ set_final_mode(struct Mode *mode, struct Mode *oldmode)
   *mbuf++ = '-';
 
   for (const struct mode_letter *tab = chan_modes; tab->letter; ++tab)
-    if ((tab->mode & oldmode->mode) &&
-        !(tab->mode & mode->mode))
+    if ((tab->mode & oldmode->mode) && !(tab->mode & mode->mode))
       *mbuf++ = tab->letter;
 
   if (oldmode->limit && mode->limit == 0)
     *mbuf++ = 'l';
 
-  if (oldmode->key[0] && !mode->key[0])
+  if (oldmode->key[0] && mode->key[0] == '\0')
   {
     *mbuf++ = 'k';
     len = sprintf(pbuf, "%s ", oldmode->key);
@@ -573,14 +579,13 @@ set_final_mode(struct Mode *mode, struct Mode *oldmode)
     *mbuf++ = '+';
 
   for (const struct mode_letter *tab = chan_modes; tab->letter; ++tab)
-    if ((tab->mode & mode->mode) &&
-        !(tab->mode & oldmode->mode))
+    if ((tab->mode & mode->mode) && !(tab->mode & oldmode->mode))
       *mbuf++ = tab->letter;
 
   if (mode->limit && oldmode->limit != mode->limit)
   {
     *mbuf++ = 'l';
-    len = sprintf(pbuf, "%d ", mode->limit);
+    len = sprintf(pbuf, "%u ", mode->limit);
     pbuf += len;
     pargs++;
   }
@@ -628,7 +633,7 @@ static void
 remove_a_mode(struct Channel *chptr, struct Client *source_p,
              int mask, char flag)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   char lmodebuf[MODEBUFLEN];
   char *sp = sendbuf;
   const char *lpara[MAXMODEPARAMS];
@@ -639,16 +644,16 @@ remove_a_mode(struct Channel *chptr, struct Client *source_p,
   *mbuf++ = '-';
   *sp = '\0';
 
-  DLINK_FOREACH(ptr, chptr->members.head)
+  DLINK_FOREACH(node, chptr->members.head)
   {
-    struct Membership *ms = ptr->data;
+    struct Membership *member = node->data;
 
-    if ((ms->flags & mask) == 0)
+    if ((member->flags & mask) == 0)
       continue;
 
-    ms->flags &= ~mask;
+    member->flags &= ~mask;
 
-    lpara[count++] = ms->client_p->name;
+    lpara[count++] = member->client_p->name;
 
     *mbuf++ = flag;
 
@@ -661,10 +666,10 @@ remove_a_mode(struct Channel *chptr, struct Client *source_p,
       }
 
       *mbuf = '\0';
-      sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s MODE %s %s%s",
+      sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
                            (IsHidden(source_p) || ConfigServerHide.hide_servers) ?
                            me.name : source_p->name,
-                           chptr->chname, lmodebuf, sendbuf);
+                           chptr->name, lmodebuf, sendbuf);
       mbuf = lmodebuf;
       *mbuf++ = '-';
       count = 0;
@@ -683,10 +688,10 @@ remove_a_mode(struct Channel *chptr, struct Client *source_p,
       sp += l;
     }
 
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s MODE %s %s%s",
+    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
                          (IsHidden(source_p) || ConfigServerHide.hide_servers) ?
                          me.name : source_p->name,
-                         chptr->chname, lmodebuf, sendbuf);
+                         chptr->name, lmodebuf, sendbuf);
   }
 }
 
@@ -702,28 +707,28 @@ remove_ban_list(struct Channel *chptr, struct Client *source_p,
 {
   char lmodebuf[MODEBUFLEN];
   char lparabuf[IRCD_BUFSIZE];
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
   char *pbuf = NULL;
   int count = 0;
   int cur_len, mlen, plen;
 
   pbuf = lparabuf;
   cur_len = mlen = snprintf(lmodebuf, sizeof(lmodebuf), ":%s MODE %s -",
-                            source_p->name, chptr->chname);
+                            source_p->name, chptr->name);
   mbuf = lmodebuf + mlen;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, list->head)
+  DLINK_FOREACH_SAFE(node, node_next, list->head)
   {
-    struct Ban *banptr = ptr->data;
+    struct Ban *ban = node->data;
 
-    plen = banptr->len + 4;  /* another +b and "!@ " */
+    plen = ban->len + 4;  /* another +b and "!@ " */
 
     if (count >= MAXMODEPARAMS ||
         (cur_len + 1 /* space between */ + (plen - 1)) > IRCD_BUFSIZE - 2)
     {
       /* NUL-terminate and remove trailing space */
       *mbuf = *(pbuf - 1) = '\0';
-      sendto_channel_local(ALL_MEMBERS, 0, chptr, "%s %s", lmodebuf, lparabuf);
+      sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", lmodebuf, lparabuf);
       cur_len = mlen;
       mbuf = lmodebuf + mlen;
       pbuf = lparabuf;
@@ -732,21 +737,26 @@ remove_ban_list(struct Channel *chptr, struct Client *source_p,
 
     *mbuf++ = c;
     cur_len += plen;
-    pbuf += sprintf(pbuf, "%s!%s@%s ", banptr->name, banptr->user,
-                    banptr->host);
+    pbuf += sprintf(pbuf, "%s!%s@%s ", ban->name, ban->user, ban->host);
     ++count;
 
-    remove_ban(banptr, list);
+    remove_ban(ban, list);
   }
 
   *mbuf = *(pbuf - 1) = '\0';
-  sendto_channel_local(ALL_MEMBERS, 0, chptr, "%s %s", lmodebuf, lparabuf);
+  sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", lmodebuf, lparabuf);
 }
 
 static struct Message sjoin_msgtab =
 {
-  "SJOIN", NULL, 0, 0, 5, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_ignore, ms_sjoin, m_ignore, m_ignore, m_ignore }
+  .cmd = "SJOIN",
+  .args_min = 5,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_sjoin,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -763,10 +773,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7763 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
