@@ -22,7 +22,7 @@
 
 /*! \file m_cap.c
  * \brief Includes required functions for processing the CAP command.
- * \version $Id: m_cap.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_cap.c 7871 2016-11-09 20:13:07Z michael $
  */
 
 #include "stdinc.h"
@@ -310,12 +310,11 @@ cap_ack(struct Client *source_p, const char *caplist)
 static int
 cap_clear(struct Client *source_p, const char *caplist)
 {
-  struct capabilities *cap = NULL;
   unsigned int cleared = 0;
 
   for (unsigned int ii = 0; ii < CAPAB_LIST_LEN; ++ii)
   {
-    cap = &capab_list[ii];
+    const struct capabilities *cap = &capab_list[ii];
 
     /* Only clear active non-sticky capabilities. */
     if (!(source_p->connection->cap_client & cap->cap) || (cap->flags & CAPFL_STICKY))
@@ -446,7 +445,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7871 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
