@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_close.c
  * \brief Includes required functions for processing the CLOSE command.
- * \version $Id: m_close.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_close.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -50,6 +50,12 @@ mo_close(struct Client *source_p, int parc, char *parv[])
   dlink_node *node = NULL, *node_next = NULL;
   unsigned int closed = dlink_list_length(&unknown_list);
 
+  if (!HasOFlag(source_p, OPER_FLAG_CLOSE))
+  {
+    sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "close");
+    return 0;
+  }
+
   DLINK_FOREACH_SAFE(node, node_next, unknown_list.head)
   {
     struct Client *target_p = node->data;
@@ -71,8 +77,13 @@ mo_close(struct Client *source_p, int parc, char *parv[])
 
 static struct Message close_msgtab =
 {
-  "CLOSE", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, m_ignore, m_ignore, mo_close, m_ignore }
+  .cmd = "CLOSE",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_close
 };
 
 static void
@@ -89,11 +100,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
