@@ -21,7 +21,7 @@
 
 /*! \file m_connect.c
  * \brief Includes required functions for processing the CONNECT command.
- * \version $Id: m_connect.c 7524 2016-04-04 18:51:46Z michael $
+ * \version $Id: m_connect.c 7876 2016-11-11 20:42:54Z michael $
  */
 
 #include "stdinc.h"
@@ -48,13 +48,12 @@
  * \note Valid arguments for this command are:
  *      - parv[0] = command
  *      - parv[1] = target server
- *      - parv[2] = port number
+ *      - parv[2] = unused/ignored
  *      - parv[3] = nickname/servername
  */
 static int
 mo_connect(struct Client *source_p, int parc, char *parv[])
 {
-  struct MaskItem *conf = NULL;
   const struct Client *target_p = NULL;
   const char *const name = parv[1];
 
@@ -83,8 +82,9 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
   }
 
   /*
-   * Try to find the name, then host, if both fail notify ops and bail
+   * Try to find the name, then host, if both fail notify and bail
    */
+  struct MaskItem *conf;
   if (!(conf = connect_find(name, NULL, match)) &&
       !(conf = connect_find(NULL, name, match)))
   {
@@ -99,22 +99,6 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  /*
-   * Get port number from user, if given. If not specified,
-   * use the default from configuration structure.
-   */
-  int port = 0;
-
-  if (parc > 2 && !EmptyString(parv[2]))
-    port = atoi(parv[2]);
-  if (port == 0)
-    port = conf->port;
-  if (port <= 0)
-  {
-    sendto_one_notice(source_p, &me, ":Connect: Illegal port number");
-    return 0;
-  }
-
   if (find_servconn_in_progress(conf->name))
   {
     sendto_one_notice(source_p, &me, ":Connect: a connection to %s is already in progress",
@@ -122,11 +106,8 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  ilog(LOG_TYPE_IRCD, "CONNECT %s %d from %s",
-       name, port, get_oper_name(source_p));
-
-  const int tmpport = conf->port;
-  conf->port = port;
+  ilog(LOG_TYPE_IRCD, "CONNECT %s %u from %s",
+       name, conf->port, get_oper_name(source_p));
 
   /*
    * At this point we should be calling connect_server with a valid
@@ -135,21 +116,20 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
   if (serv_connect(conf, source_p))
   {
     if (!ConfigServerHide.hide_server_ips && HasUMode(source_p, UMODE_ADMIN))
-      sendto_one_notice(source_p, &me, ":*** Connecting to %s[%s].%d",
+      sendto_one_notice(source_p, &me, ":*** Connecting to %s[%s].%u",
                         conf->host, conf->name, conf->port);
     else
-      sendto_one_notice(source_p, &me, ":*** Connecting to %s.%d",
+      sendto_one_notice(source_p, &me, ":*** Connecting to %s.%u",
                         conf->name, conf->port);
   }
   else
-    sendto_one_notice(source_p, &me, ":*** Couldn't connect to %s.%d",
+    sendto_one_notice(source_p, &me, ":*** Couldn't connect to %s.%u",
                       conf->name, conf->port);
 
   /*
    * Client is either connecting with all the data it needs or has been
    * destroyed
    */
-  conf->port = tmpport;
   return 0;
 }
 
@@ -163,13 +143,12 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
  * \note Valid arguments for this command are:
  *      - parv[0] = command
  *      - parv[1] = target server
- *      - parv[2] = port number
+ *      - parv[2] = unused/ignored
  *      - parv[3] = nickname/servername
  */
 static int
 ms_connect(struct Client *source_p, int parc, char *parv[])
 {
-  struct MaskItem *conf = NULL;
   const struct Client *target_p = NULL;
   const char *const name = parv[1];
 
@@ -183,8 +162,9 @@ ms_connect(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   /*
-   * Try to find the name, then host, if both fail notify ops and bail
+   * Try to find the name, then host, if both fail notify and bail
    */
+  struct MaskItem *conf;
   if (!(conf = connect_find(name, NULL, match)) &&
       !(conf = connect_find(NULL, name, match)))
   {
@@ -199,20 +179,6 @@ ms_connect(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  /*
-   * Get port number from user, if given. If not specified,
-   * use the default from configuration structure.
-   */
-  int port = atoi(parv[2]);
-
-  if (port == 0)
-    port = conf->port;
-  if (port <= 0)
-  {
-    sendto_one_notice(source_p, &me, ":Connect: Illegal port number");
-    return 0;
-  }
-
   if (find_servconn_in_progress(conf->name))
   {
     sendto_one_notice(source_p, &me, ":Connect: a connection to %s is already in progress",
@@ -223,32 +189,28 @@ ms_connect(struct Client *source_p, int parc, char *parv[])
   /*
    * Notify all operators about remote connect requests
    */
-  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_GLOBAL, "from %s: Remote CONNECT %s %d from %s",
-                       me.name, name, port, get_oper_name(source_p));
-  sendto_server(NULL, 0, 0, ":%s GLOBOPS :Remote CONNECT %s %d from %s",
-                me.id, name, port, get_oper_name(source_p));
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_GLOBAL, "from %s: Remote CONNECT %s %u from %s",
+                       me.name, name, conf->port, get_oper_name(source_p));
+  sendto_server(NULL, 0, 0, ":%s GLOBOPS :Remote CONNECT %s %u from %s",
+                me.id, name, conf->port, get_oper_name(source_p));
 
-  ilog(LOG_TYPE_IRCD, "Remote CONNECT %s %d from %s",
-       name, port, get_oper_name(source_p));
-
-  const int tmpport = conf->port;
-  conf->port = port;
+  ilog(LOG_TYPE_IRCD, "Remote CONNECT %s %u from %s",
+       name, conf->port, get_oper_name(source_p));
 
   /*
    * At this point we should be calling connect_server with a valid
    * connect{} block and a valid port in the connect{} block
    */
   if (serv_connect(conf, source_p))
-    sendto_one_notice(source_p, &me, ":*** Connecting to %s.%d",
+    sendto_one_notice(source_p, &me, ":*** Connecting to %s.%u",
                       conf->name, conf->port);
   else
-    sendto_one_notice(source_p, &me, ":*** Couldn't connect to %s.%d",
+    sendto_one_notice(source_p, &me, ":*** Couldn't connect to %s.%u",
                       conf->name, conf->port);
   /*
    * Client is either connecting with all the data it needs or has been
    * destroyed
    */
-  conf->port = tmpport;
   return 0;
 }
 
@@ -278,7 +240,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7524 $",
+  .version = "$Revision: 7876 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
