@@ -21,7 +21,7 @@
 
 /*! \file m_etrace.c
  * \brief Includes required functions for processing the ETRACE command.
- * \version $Id: m_etrace.c 7045 2016-01-09 20:11:17Z michael $
+ * \version $Id: m_etrace.c 7909 2016-11-27 16:59:26Z michael $
  */
 
 #include "stdinc.h"
@@ -69,23 +69,23 @@ do_etrace(struct Client *source_p, const char *arg)
 {
   const char *tname = NULL;
   unsigned int wilds = 0, do_all = 0;
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   sendto_realops_flags(UMODE_SPY, L_ALL, SEND_NOTICE,
                        "ETRACE requested by %s (%s@%s) [%s]",
                        source_p->name, source_p->username,
                        source_p->host, source_p->servptr->name);
 
-  if (!EmptyString(arg))
-  {
-    tname = arg;
-    wilds = has_wildcards(tname);
-  }
-  else
+  if (EmptyString(arg))
   {
     do_all = 1;
     tname = "*";
   }
+  else
+  {
+    tname = arg;
+    wilds = has_wildcards(tname);
+  }
 
   if (!wilds && !do_all)
   {
@@ -145,7 +145,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7045 $",
+  .version = "$Revision: 7909 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
