@@ -21,7 +21,7 @@
 
 /*! \file m_info.c
  * \brief Includes required functions for processing the INFO command.
- * \version $Id: m_info.c 7436 2016-03-10 19:57:51Z michael $
+ * \version $Id: m_info.c 7859 2016-11-08 20:09:29Z michael $
  */
 
 #include "stdinc.h"
@@ -35,6 +35,7 @@
 #include "conf.h"
 #include "parse.h"
 #include "modules.h"
+#include "tls.h"
 
 
 /* Types for output_type in InfoStruct */
@@ -189,6 +190,12 @@ static const struct InfoStruct info_table[] =
     &ConfigChannel.invite_delay_channel,
     "Delay between INVITE attempts to a channel"
   },
+  {
+    "invite_expire_time",
+    OUTPUT_DECIMAL,
+    &ConfigChannel.invite_expire_time,
+    "Amount of time an INVITE will be active until it expires"
+  },
   {
     "knock_client_count",
     OUTPUT_DECIMAL,
@@ -213,6 +220,12 @@ static const struct InfoStruct info_table[] =
     &ConfigChannel.max_channels,
     "Maximum number of channels a user can join"
   },
+  {
+    "max_invites",
+    OUTPUT_DECIMAL,
+    &ConfigChannel.max_invites,
+    "Maximum number of channels a user can be invited to"
+  },
   {
     "max_bans",
     OUTPUT_DECIMAL,
@@ -351,6 +364,12 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.default_floodcount,
     "Startup value of FLOODCOUNT"
   },
+  {
+    "default_floodtime",
+    OUTPUT_DECIMAL,
+    &ConfigGeneral.default_floodtime,
+    "Startup value of FLOODTIME"
+  },
   {
     "failed_oper_notice",
     OUTPUT_BOOLEAN_YN,
@@ -678,8 +697,13 @@ send_info_text(struct Client *source_p)
   }
 
   if (HasUMode(source_p, UMODE_OPER))
+  {
     send_conf_options(source_p);
 
+    if (tls_is_initialized())
+      sendto_one_numeric(source_p, &me, RPL_INFO, tls_get_version());
+  }
+
   send_birthdate_online_time(source_p);
 
   sendto_one_numeric(source_p, &me, RPL_ENDOFINFO);
@@ -763,7 +787,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7436 $",
+  .version = "$Revision: 7859 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
