@@ -21,7 +21,7 @@
 
 /*! \file m_invite.c
  * \brief Includes required functions for processing the INVITE command.
- * \version $Id: m_invite.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_invite.c 7903 2016-11-27 13:44:31Z michael $
  */
 
 #include "stdinc.h"
@@ -61,11 +61,11 @@ m_invite(struct Client *source_p, int parc, char *parv[])
 
   if (parc < 2)
   {
-    const dlink_node *node = NULL;
+    dlink_node *node;
 
     DLINK_FOREACH(node, source_p->connection->invited.head)
       sendto_one_numeric(source_p, &me, RPL_INVITELIST,
-                         ((struct Channel *)node->data)->name);
+                         ((const struct Invite *)node->data)->chptr->name);
 
     sendto_one_numeric(source_p, &me, RPL_ENDOFINVITELIST);
     return 0;
@@ -194,7 +194,7 @@ ms_invite(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   if (parc > 3 && IsDigit(*parv[3]))
-    if (strtoimax(parv[3], NULL, 10) > chptr->creationtime)
+    if (strtoumax(parv[3], NULL, 10) > chptr->creationtime)
       return 0;
 
   chptr->last_invite = CurrentTime;
@@ -252,7 +252,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7903 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
