@@ -21,7 +21,7 @@
 
 /*! \file m_links.c
  * \brief Includes required functions for processing the LINKS command.
- * \version $Id: m_links.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_links.c 7329 2016-02-18 21:07:50Z michael $
  */
 
 #include "stdinc.h"
@@ -129,7 +129,7 @@ mo_links(struct Client *source_p, int parc, char *parv[])
 static int
 m_links(struct Client *source_p, int parc, char *parv[])
 {
-  static time_t last_used = 0;
+  static uintmax_t last_used = 0;
 
   if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
   {
@@ -195,7 +195,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7329 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
