@@ -21,7 +21,7 @@
 
 /*! \file m_module.c
  * \brief Includes required functions for processing the MODULE command.
- * \version $Id: m_module.c 7075 2016-01-20 11:47:29Z michael $
+ * \version $Id: m_module.c 7686 2016-08-18 17:32:04Z michael $
  */
 
 #include "stdinc.h"
@@ -173,7 +173,7 @@ module_reload(struct Client *source_p, const char *arg)
 static void
 module_list(struct Client *source_p, const char *arg)
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, modules_get_list()->head)
   {
@@ -283,7 +283,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7075 $",
+  .version = "$Revision: 7686 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_NOUNLOAD
