@@ -21,7 +21,7 @@
 
 /*! \file m_ping.c
  * \brief Includes required functions for processing the PING command.
- * \version $Id: m_ping.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_ping.c 7915 2016-11-27 19:07:27Z michael $
  */
 
 #include "stdinc.h"
@@ -53,7 +53,6 @@ static int
 m_ping(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
-  const char *destination = NULL;
 
   if (parc < 2 || EmptyString(parv[1]))
   {
@@ -61,8 +60,7 @@ m_ping(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  destination = parv[2];  /* Will get NULL or pointer (parc >= 2!!) */
-
+  const char *const destination = parv[2];  /* Will get NULL or pointer (parc >= 2!!) */
   if (ConfigServerHide.disable_remote_commands && !HasUMode(source_p, UMODE_OPER))
   {
     sendto_one(source_p, ":%s PONG %s :%s", me.name,
@@ -70,18 +68,15 @@ m_ping(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!EmptyString(destination) && irccmp(destination, me.name))
-  {
-    if ((target_p = hash_find_server(destination)))
-      sendto_one(target_p, ":%s PING %s :%s",
-                 ID_or_name(source_p, target_p), source_p->name,
-                 ID_or_name(target_p, target_p));
-    else
-      sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, destination);
-  }
+  if (EmptyString(destination) || ((target_p = hash_find_server(destination)) && IsMe(target_p)))
+    sendto_one(source_p, ":%s PONG %s :%s", me.name, me.name, parv[1]);
+  else if (target_p)
+    sendto_one(target_p, ":%s PING %s :%s",
+               ID_or_name(source_p, target_p), source_p->name,
+               ID_or_name(target_p, target_p));
   else
-    sendto_one(source_p, ":%s PONG %s :%s", me.name,
-               (destination) ? destination : me.name, parv[1]);
+    sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, destination);
+
   return 0;
 }
 
@@ -101,7 +96,6 @@ static int
 ms_ping(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
-  const char *destination = NULL;
 
   if (parc < 2 || EmptyString(parv[1]))
   {
@@ -109,23 +103,20 @@ ms_ping(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  destination = parv[2];  /* Will get NULL or pointer (parc >= 2!!) */
-
-  if (!EmptyString(destination) && irccmp(destination, me.name) && irccmp(destination, me.id))
-  {
-    if ((target_p = hash_find_server(destination)))
-    {
-      if (target_p->from != source_p->from)
-        sendto_one(target_p, ":%s PING %s :%s",
-                   ID_or_name(source_p, target_p), source_p->name,
-                   ID_or_name(target_p, target_p));
-    }
-    else if (!IsDigit(*destination))
-      sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, destination);
-  }
-  else
+  const char *const destination = parv[2];  /* Will get NULL or pointer (parc >= 2!!) */
+  if (EmptyString(destination) || ((target_p = hash_find_server(destination)) && IsMe(target_p)))
     sendto_one(source_p, ":%s PONG %s :%s", ID_or_name(&me, source_p),
-               (destination) ? destination : me.name, ID_or_name(source_p, source_p));
+               me.name, ID_or_name(source_p, source_p));
+  else if (target_p)
+  {
+    if (target_p->from != source_p->from)
+      sendto_one(target_p, ":%s PING %s :%s",
+                 ID_or_name(source_p, target_p), source_p->name,
+                 ID_or_name(target_p, target_p));
+  }
+  else if (!IsDigit(*destination))
+    sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, destination);
+
   return 0;
 }
 
@@ -154,7 +145,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7915 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
