@@ -21,7 +21,7 @@
 
 /*! \file m_set.c
  * \brief Includes required functions for processing the SET command.
- * \version $Id: m_set.c 7406 2016-03-06 17:19:26Z michael $
+ * \version $Id: m_set.c 7895 2016-11-24 10:09:33Z michael $
  */
 
 #include "stdinc.h"
@@ -71,14 +71,13 @@ quote_autoconnall(struct Client *source_p, const char *arg, int newval)
 {
   if (newval >= 0)
   {
-    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has changed AUTOCONNALL to %i",
-                         get_oper_name(source_p), newval);
-
     GlobalSetOptions.autoconn = newval;
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                         "%s has changed AUTOCONNALL to %u",
+                         get_oper_name(source_p), GlobalSetOptions.autoconn);
   }
   else
-    sendto_one_notice(source_p, &me, ":AUTOCONNALL is currently %i",
+    sendto_one_notice(source_p, &me, ":AUTOCONNALL is currently %u",
                       GlobalSetOptions.autoconn);
 }
 
@@ -90,14 +89,30 @@ quote_floodcount(struct Client *source_p, const char *arg, int newval)
   {
     GlobalSetOptions.floodcount = newval;
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has changed FLOODCOUNT to %i",
+                         "%s has changed FLOODCOUNT to %u",
                          get_oper_name(source_p), GlobalSetOptions.floodcount);
   }
   else
-    sendto_one_notice(source_p, &me, ":FLOODCOUNT is currently %i",
+    sendto_one_notice(source_p, &me, ":FLOODCOUNT is currently %u",
                       GlobalSetOptions.floodcount);
 }
 
+/* SET FLOODTIME */
+static void
+quote_floodtime(struct Client *source_p, const char *arg, int newval)
+{
+  if (newval >= 0)
+  {
+    GlobalSetOptions.floodtime = newval;
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                         "%s has changed FLOODTIME to %u",
+                         get_oper_name(source_p), GlobalSetOptions.floodtime);
+  }
+  else
+    sendto_one_notice(source_p, &me, ":FLOODTIME is currently %u",
+                      GlobalSetOptions.floodtime);
+}
+
 /* SET IDENTTIMEOUT */
 static void
 quote_identtimeout(struct Client *source_p, const char *arg, int newval)
@@ -110,13 +125,13 @@ quote_identtimeout(struct Client *source_p, const char *arg, int newval)
 
   if (newval > 0)
   {
-    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has changed IDENTTIMEOUT to %d",
-                         get_oper_name(source_p), newval);
     GlobalSetOptions.ident_timeout = newval;
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                         "%s has changed IDENTTIMEOUT to %u",
+                         get_oper_name(source_p), GlobalSetOptions.ident_timeout);
   }
   else
-    sendto_one_notice(source_p, &me, ":IDENTTIMEOUT is currently %d",
+    sendto_one_notice(source_p, &me, ":IDENTTIMEOUT is currently %u",
                       GlobalSetOptions.ident_timeout);
 }
 
@@ -128,26 +143,25 @@ quote_max(struct Client *source_p, const char *arg, int newval)
   {
     if (newval > MAXCLIENTS_MAX)
     {
-      sendto_one_notice(source_p, &me, ":You cannot set MAXCLIENTS to > %d, restoring to %d",
+      sendto_one_notice(source_p, &me, ":You cannot set MAXCLIENTS to > %d, restoring to %u",
                         MAXCLIENTS_MAX, GlobalSetOptions.maxclients);
       return;
     }
 
     if (newval < MAXCLIENTS_MIN)
     {
-      sendto_one_notice(source_p, &me, ":You cannot set MAXCLIENTS to < %d, restoring to %d",
+      sendto_one_notice(source_p, &me, ":You cannot set MAXCLIENTS to < %d, restoring to %u",
                         MAXCLIENTS_MIN, GlobalSetOptions.maxclients);
       return;
     }
 
     GlobalSetOptions.maxclients = newval;
-
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-        "%s set new MAXCLIENTS to %d (%d current)",
-        get_oper_name(source_p), GlobalSetOptions.maxclients, Count.local);
+                         "%s set new MAXCLIENTS to %u (%u current)",
+                         get_oper_name(source_p), GlobalSetOptions.maxclients, Count.local);
   }
   else
-    sendto_one_notice(source_p, &me, ":Current MAXCLIENTS = %d (%d)",
+    sendto_one_notice(source_p, &me, ":Current MAXCLIENTS = %u (%u)",
                       GlobalSetOptions.maxclients, Count.local);
 }
 
@@ -159,9 +173,9 @@ quote_spamnum(struct Client *source_p, const char *arg, int newval)
   {
     if (newval == 0)
     {
+      GlobalSetOptions.spam_num = newval;
       sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                            "%s has disabled ANTI_SPAMBOT", source_p->name);
-      GlobalSetOptions.spam_num = newval;
       return;
     }
 
@@ -183,11 +197,11 @@ quote_spamtime(struct Client *source_p, const char *arg, int newval)
   {
     GlobalSetOptions.spam_time = IRCD_MAX(newval, MIN_SPAM_TIME);
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has changed SPAMTIME to %i",
+                         "%s has changed SPAMTIME to %u",
                          get_oper_name(source_p), GlobalSetOptions.spam_time);
   }
   else
-    sendto_one_notice(source_p, &me, ":SPAMTIME is currently %i",
+    sendto_one_notice(source_p, &me, ":SPAMTIME is currently %u",
                       GlobalSetOptions.spam_time);
 }
 
@@ -197,13 +211,13 @@ quote_jfloodtime(struct Client *source_p, const char *arg, int newval)
 {
   if (newval >= 0)
   {
-    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has changed JFLOODTIME to %i",
-                         get_oper_name(source_p), newval);
     GlobalSetOptions.joinfloodtime = newval;
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                         "%s has changed JFLOODTIME to %u",
+                         get_oper_name(source_p), GlobalSetOptions.joinfloodtime);
   }
   else
-    sendto_one_notice(source_p, &me, ":JFLOODTIME is currently %i",
+    sendto_one_notice(source_p, &me, ":JFLOODTIME is currently %u",
                       GlobalSetOptions.joinfloodtime);
 }
 
@@ -213,13 +227,13 @@ quote_jfloodcount(struct Client *source_p, const char *arg, int newval)
 {
   if (newval >= 0)
   {
-    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has changed JFLOODCOUNT to %i",
-                         get_oper_name(source_p), newval);
     GlobalSetOptions.joinfloodcount = newval;
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                         "%s has changed JFLOODCOUNT to %u",
+                         get_oper_name(source_p), GlobalSetOptions.joinfloodcount);
   }
   else
-    sendto_one_notice(source_p, &me, ":JFLOODCOUNT is currently %i",
+    sendto_one_notice(source_p, &me, ":JFLOODCOUNT is currently %u",
                       GlobalSetOptions.joinfloodcount);
 }
 
@@ -248,6 +262,7 @@ static const struct SetStruct set_cmd_table[] =
   { "AUTOCONN",         quote_autoconn,         1,      1 },
   { "AUTOCONNALL",      quote_autoconnall,      0,      1 },
   { "FLOODCOUNT",       quote_floodcount,       0,      1 },
+  { "FLOODTIME",        quote_floodtime,        0,      1 },
   { "IDENTTIMEOUT",     quote_identtimeout,     0,      1 },
   { "MAX",              quote_max,              0,      1 },
   { "SPAMNUM",          quote_spamnum,          0,      1 },
@@ -406,7 +421,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7406 $",
+  .version = "$Revision: 7895 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
