@@ -21,7 +21,7 @@
 
 /*! \file m_stats.c
  * \brief Includes required functions for processing the STATS command.
- * \version $Id: m_stats.c 7510 2016-03-26 19:48:19Z michael $
+ * \version $Id: m_stats.c 7913 2016-11-27 18:54:38Z michael $
  */
 
 #include "stdinc.h"
@@ -240,7 +240,7 @@ stats_connect(struct Client *source_p, int parc, char *parv[])
 static void
 stats_resv(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, resv_chan_get_list()->head)
   {
@@ -264,7 +264,7 @@ stats_resv(struct Client *source_p, int parc, char *parv[])
 static void
 stats_memory(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node, *node2;
+  dlink_node *node, *node2;
 
   unsigned int local_client_conf_count = 0;      /* local client conf links */
   unsigned int users_counted = 0;                /* user structs */
@@ -276,10 +276,8 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   unsigned int channel_invex = 0;
 
   unsigned int wwu = 0;                  /* whowas users */
-  unsigned int aways_counted = 0;
   unsigned int number_ips_stored = 0;        /* number of ip addresses hashed */
 
-  size_t channel_memory = 0;
   size_t channel_ban_memory = 0;
   size_t channel_except_memory = 0;
   size_t channel_invex_memory = 0;
@@ -296,9 +294,6 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   size_t local_client_memory_used  = 0;
   size_t remote_client_memory_used = 0;
 
-  size_t total_memory = 0;
-  unsigned int channel_topics = 0;
-
   unsigned int watch_list_headers = 0;   /* watchlist headers     */
   unsigned int watch_list_entries = 0;   /* watchlist entries     */
   size_t watch_list_memory = 0; /* watchlist memory used */
@@ -321,24 +316,14 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
       ++remote_client_count;
 
     if (IsClient(target_p))
-    {
       ++users_counted;
-
-      if (target_p->away[0])
-        ++aways_counted;
-    }
   }
 
-  /* Count up all channels, ban lists, except lists, Invex lists */
-  channel_memory = dlink_list_length(&channel_list) * sizeof(struct Channel);
-
+  /* Count up all members, invites, ban lists, except lists, Invex lists */
   DLINK_FOREACH(node, channel_list.head)
   {
     const struct Channel *chptr = node->data;
 
-    if (chptr->topic[0])
-      ++channel_topics;
-
     channel_members += dlink_list_length(&chptr->members);
     channel_invites += dlink_list_length(&chptr->invites);
 
@@ -371,18 +356,16 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
 
   watch_count_memory(&watch_list_headers, &watch_list_memory);
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :WATCH headers %u(%zu) entries %u(%u)",
+                     "z :WATCH headers %u(%zu) entries %u(%zu)",
                      watch_list_headers,
-                     watch_list_memory, watch_list_entries,
+                     watch_list_memory,
+                     watch_list_entries,
                      watch_list_entries * sizeof(dlink_node) * 2);
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :Clients %u(%u)",
+                     "z :Clients %u(%zu)",
                      users_counted,
-                     (users_counted * sizeof(struct Client)));
-
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :User aways %u", aways_counted);
+                     users_counted * sizeof(struct Client));
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Attached confs %u(%zu)",
@@ -407,9 +390,9 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
                      dlink_list_length(class_get_list()) * sizeof(struct ClassItem));
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "z :Channels %u(%zu) Topics %u",
+                     "z :Channels %u(%zu)",
                      dlink_list_length(&channel_list),
-                     channel_memory, channel_topics);
+                     dlink_list_length(&channel_list) * sizeof(struct Channel));
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Bans %u(%zu)",
@@ -428,7 +411,7 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
                      channel_members,
                      channel_members * sizeof(struct Membership),
                      channel_invites,
-                     channel_invites * sizeof(dlink_node) * 2);
+                     channel_invites * sizeof(struct Invite));
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Safelist %u(%zu)",
@@ -446,13 +429,11 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
                      number_ips_stored, mem_ips_stored);
 
   local_client_memory_used = local_client_count *(sizeof(struct Client) + sizeof(struct Connection));
-  total_memory += local_client_memory_used;
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Local client Memory in use: %u(%zu)",
                      local_client_count, local_client_memory_used);
 
   remote_client_memory_used = remote_client_count * sizeof(struct Client);
-  total_memory += remote_client_memory_used;
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Remote client Memory in use: %u(%zu)",
                      remote_client_count, remote_client_memory_used);
@@ -481,7 +462,7 @@ stats_dns_servers(struct Client *source_p, int parc, char *parv[])
 static void
 stats_deny(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
@@ -511,7 +492,7 @@ stats_deny(struct Client *source_p, int parc, char *parv[])
 static void
 stats_tdeny(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
@@ -541,7 +522,7 @@ stats_tdeny(struct Client *source_p, int parc, char *parv[])
 static void
 stats_exempt(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   if (ConfigGeneral.stats_e_disabled)
   {
@@ -567,7 +548,7 @@ stats_exempt(struct Client *source_p, int parc, char *parv[])
 static void
 stats_events(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node;
+  dlink_node *node;
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "E :Operation                      Next Execution");
@@ -587,7 +568,7 @@ stats_events(struct Client *source_p, int parc, char *parv[])
 static void
 stats_hubleaf(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node, *node2;
+  dlink_node *node, *node2;
 
   DLINK_FOREACH(node, connect_items.head)
   {
@@ -652,7 +633,7 @@ show_iline_prefix(const struct Client *source_p, const struct MaskItem *conf)
 static void
 report_auth(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
@@ -720,7 +701,7 @@ stats_auth(struct Client *source_p, int parc, char *parv[])
 static void
 report_Klines(struct Client *source_p, int tkline)
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
   char c = '\0';
 
   if (tkline)
@@ -837,7 +818,7 @@ stats_messages(struct Client *source_p, int parc, char *parv[])
 static void
 stats_operedup(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
   unsigned int opercount = 0;
   char buf[IRCD_BUFSIZE] = "";
 
@@ -880,13 +861,13 @@ stats_operedup(struct Client *source_p, int parc, char *parv[])
 static void
 show_ports(struct Client *source_p)
 {
-  char buf[8] = "";
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, listener_get_list()->head)
   {
-    const struct Listener *listener = node->data;
+    char buf[8];
     char *p = buf;
+    const struct Listener *listener = node->data;
 
     if (listener->flags & LISTENER_HIDDEN)
     {
@@ -901,8 +882,7 @@ show_ports(struct Client *source_p)
       *p++ = 's';
     *p = '\0';
 
-    if (HasUMode(source_p, UMODE_ADMIN) &&
-        (MyConnect(source_p) || !ConfigServerHide.hide_server_ips))
+    if (HasUMode(source_p, UMODE_ADMIN) && !ConfigServerHide.hide_server_ips)
       sendto_one_numeric(source_p, &me, RPL_STATSPLINE, 'P', listener->port,
                          listener->name,
                          listener->ref_count, buf,
@@ -926,7 +906,7 @@ stats_ports(struct Client *source_p, int parc, char *parv[])
 static void
 stats_tstats(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
   struct ServerStatistics tmp;
   struct ServerStatistics *sp = &tmp;
 
@@ -1026,7 +1006,7 @@ stats_shared(struct Client *source_p, int parc, char *parv[])
 static void
 stats_servers(struct Client *source_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, local_server_list.head)
   {
@@ -1047,7 +1027,7 @@ stats_servers(struct Client *source_p, int parc, char *parv[])
 static void
 stats_class(struct Client *source_p, int parc, char *parv[])
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, class_get_list()->head)
   {
@@ -1099,7 +1079,7 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
                target_p->connection->recv.bytes >> 10,
                (unsigned int)(CurrentTime - target_p->connection->firsttime),
                (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since) : 0,
-               HasUMode(source_p, UMODE_OPER) ? show_capabilities(target_p) : "TS");
+               HasUMode(source_p, UMODE_OPER) ? get_capabilities(target_p) : "TS");
   }
 
   sendB >>= 10;
@@ -1167,18 +1147,12 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
 
   /*
    * Send info about connections which match, or all if the
-   * mask matches from. Only restrictions are on those who
-   * are invisible not being visible to 'foreigners' who use
-   * a wild card based search to list it.
+   * mask matches from.
    */
   DLINK_FOREACH(node, list->head)
   {
     const struct Client *target_p = node->data;
-
-    if (HasUMode(target_p, UMODE_INVISIBLE) && (doall || wilds) &&
-        !(MyConnect(source_p) && HasUMode(source_p, UMODE_OPER)) &&
-        !HasUMode(target_p, UMODE_OPER) && (target_p != source_p))
-      continue;
+    enum addr_mask_type type = 0;
 
     if (!doall && wilds && match(name, target_p->name))
       continue;
@@ -1186,56 +1160,25 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
     if (!(doall || wilds) && irccmp(name, target_p->name))
       continue;
 
-    /*
-     * This basically shows ips for our opers if it's not a server/admin, or
-     * it's one of our admins.
-     */
-    if (MyConnect(source_p) && HasUMode(source_p, UMODE_OPER) &&
-        (HasUMode(source_p, UMODE_ADMIN) ||
-        (!IsServer(target_p) && !HasUMode(target_p, UMODE_ADMIN) &&
-        !IsHandshake(target_p) && !IsConnecting(target_p))))
-    {
-      sendto_one_numeric(source_p, &me, RPL_STATSLINKINFO,
-                 (IsUpper(statchar)) ?
-                 get_client_name(target_p, SHOW_IP) :
-                 get_client_name(target_p, HIDE_IP),
-                 dbuf_length(&target_p->connection->buf_sendq),
-                 target_p->connection->send.messages,
-                 target_p->connection->send.bytes >> 10,
-                 target_p->connection->recv.messages,
-                 target_p->connection->recv.bytes >> 10,
-                 (unsigned int)(CurrentTime - target_p->connection->firsttime),
-                 (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since) : 0,
-                 IsServer(target_p) ? show_capabilities(target_p) : "-");
-    }
+    if (IsUpper(statchar))
+      type = SHOW_IP;
     else
-    {
-      /* If it's a server, mask the real IP */
-      if (IsServer(target_p) || IsHandshake(target_p) || IsConnecting(target_p))
-        sendto_one_numeric(source_p, &me, RPL_STATSLINKINFO,
-                   get_client_name(target_p, MASK_IP),
-                   dbuf_length(&target_p->connection->buf_sendq),
-                   target_p->connection->send.messages,
-                   target_p->connection->send.bytes >> 10,
-                   target_p->connection->recv.messages,
-                   target_p->connection->recv.bytes >> 10,
-                   (unsigned int)(CurrentTime - target_p->connection->firsttime),
-                   (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since):0,
-                   IsServer(target_p) ? show_capabilities(target_p) : "-");
-      else /* show the real IP */
-        sendto_one_numeric(source_p, &me, RPL_STATSLINKINFO,
-                   (IsUpper(statchar)) ?
-                   get_client_name(target_p, SHOW_IP) :
-                   get_client_name(target_p, HIDE_IP),
-                   dbuf_length(&target_p->connection->buf_sendq),
-                   target_p->connection->send.messages,
-                   target_p->connection->send.bytes >> 10,
-                   target_p->connection->recv.messages,
-                   target_p->connection->recv.bytes >> 10,
-                   (unsigned int)(CurrentTime - target_p->connection->firsttime),
-                   (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since):0,
-                   IsServer(target_p) ? show_capabilities(target_p) : "-");
-    }
+      type = HIDE_IP;
+
+    if (IsServer(target_p) || IsConnecting(target_p) || IsHandshake(target_p))
+      if (!HasUMode(source_p, UMODE_ADMIN))
+        type = MASK_IP;
+
+    sendto_one_numeric(source_p, &me, RPL_STATSLINKINFO,
+                       get_client_name(target_p, type),
+                       dbuf_length(&target_p->connection->buf_sendq),
+                       target_p->connection->send.messages,
+                       target_p->connection->send.bytes >> 10,
+                       target_p->connection->recv.messages,
+                       target_p->connection->recv.bytes >> 10,
+                       (unsigned int)(CurrentTime - target_p->connection->firsttime),
+                       (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since) : 0,
+                       IsServer(target_p) ? get_capabilities(target_p) : "-");
   }
 }
 
@@ -1432,7 +1375,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7510 $",
+  .version = "$Revision: 7913 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
