@@ -22,13 +22,12 @@
 
 /*! \file m_svskill.c
  * \brief Includes required functions for processing the SVSKILL command.
- * \version $Id: m_svskill.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_svskill.c 7512 2016-03-26 19:55:16Z michael $
  */
 
 #include "stdinc.h"
 #include "client.h"
 #include "ircd.h"
-#include "server.h"
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
@@ -54,8 +53,8 @@ ms_svskill(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
   const char *comment = NULL;
-  char reason[KILLLEN + 1] = "SVSKilled: ";
-  time_t ts = 0;
+  char reason[REASONLEN + 1] = "SVSKilled: ";
+  uintmax_t ts = 0;
 
   if (!HasFlag(source_p, FLAGS_SERVICE))
     return 0;
@@ -66,7 +65,7 @@ ms_svskill(struct Client *source_p, int parc, char *parv[])
   if (parc > 3)
   {
     comment = parv[3] ? parv[3] : CONF_NOREASON;
-    ts = strtoimax(parv[2], NULL, 10);
+    ts = strtoumax(parv[2], NULL, 10);
   }
   else
     comment = (parc > 2 && parv[2]) ? parv[2] : CONF_NOREASON;
@@ -129,7 +128,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7512 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
