@@ -21,7 +21,7 @@
 
 /*! \file m_tburst.c
  * \brief Includes required functions for processing the TBURST command.
- * \version $Id: m_tburst.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_tburst.c 7329 2016-02-18 21:07:50Z michael $
  */
 
 #include "stdinc.h"
@@ -48,15 +48,15 @@
  *      - parv[2] = channel name
  *      - parv[3] = topic timestamp
  *      - parv[4] = topic setter
- *      - parv[5] = topic
+ *      - parv[5] = topic (can be an empty string)
  */
 static int
 ms_tburst(struct Client *source_p, int parc, char *parv[])
 {
   struct Channel *chptr = NULL;
   int accept_remote = 0;
-  time_t remote_channel_ts = strtoimax(parv[1], NULL, 10);
-  time_t remote_topic_ts = strtoimax(parv[3], NULL, 10);
+  uintmax_t remote_channel_ts = strtoumax(parv[1], NULL, 10);
+  uintmax_t remote_topic_ts = strtoumax(parv[3], NULL, 10);
   const char *topic = parv[5];
   const char *setby = parv[4];
 
@@ -146,7 +146,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7329 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
