@@ -21,7 +21,7 @@
 
 /*! \file m_trace.c
  * \brief Includes required functions for processing the TRACE command.
- * \version $Id: m_trace.c 7045 2016-01-09 20:11:17Z michael $
+ * \version $Id: m_trace.c 7796 2016-10-18 17:26:37Z michael $
  */
 
 #include "stdinc.h"
@@ -46,7 +46,7 @@ static void
 trace_get_dependent(unsigned int *const server,
                     unsigned int *const client, const struct Client *target_p)
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   (*server)++;
   (*client) += dlink_list_length(&target_p->serv->client_list);
@@ -231,7 +231,7 @@ do_actual_trace(struct Client *source_p, int parc, char *parv[])
   {
     const struct ClassItem *class = node->data;
 
-    if (class->ref_count > 0)
+    if (class->ref_count)
       sendto_one_numeric(source_p, &me, RPL_TRACECLASS, class->name, class->ref_count);
   }
 
@@ -331,7 +331,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7045 $",
+  .version = "$Revision: 7796 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
