@@ -21,7 +21,7 @@
 
 /*! \file m_undline.c
  * \brief Includes required functions for processing the UNDLINE command.
- * \version $Id: m_undline.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_undline.c 7428 2016-03-07 17:46:09Z michael $
  */
 
 #include "stdinc.h"
@@ -29,6 +29,8 @@
 #include "client.h"
 #include "irc_string.h"
 #include "conf.h"
+#include "conf_cluster.h"
+#include "conf_shared.h"
 #include "ircd.h"
 #include "hostmask.h"
 #include "numeric.h"
@@ -127,7 +129,7 @@ mo_undline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!parse_aline("UNDLINE", source_p, parc, parv, 0, &addr,
+  if (!parse_aline("UNDLINE", source_p, parc, parv, &addr,
                    NULL, NULL, &target_server, NULL))
     return 0;
 
@@ -141,7 +143,7 @@ mo_undline(struct Client *source_p, int parc, char *parv[])
       return 0;
   }
   else
-    cluster_a_line(source_p, "UNDLINE", CAPAB_UNDLN, SHARED_UNDLINE, "%s", addr);
+    cluster_distribute(source_p, "UNDLINE", CAPAB_UNDLN, CLUSTER_UNDLINE, "%s", addr);
 
   dline_remove_and_notify(source_p, addr);
   return 0;
@@ -156,7 +158,7 @@ mo_undline(struct Client *source_p, int parc, char *parv[])
  *                 pointers.
  * \note Valid arguments for this command are:
  *      - parv[0] = command
- *      - parv[1] = target server
+ *      - parv[1] = target server mask
  *      - parv[2] = IP address
  */
 static int
@@ -174,9 +176,8 @@ ms_undline(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
-      find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
-                              source_p->username, source_p->host,
-                              SHARED_UNDLINE))
+      shared_find(SHARED_UNDLINE, source_p->servptr->name,
+                  source_p->username, source_p->host))
     dline_remove_and_notify(source_p, addr);
 
   return 0;
@@ -210,7 +211,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7428 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
