@@ -21,62 +21,58 @@
 
 /*! \file m_unresv.c
  * \brief Includes required functions for processing the UNRESV command.
- * \version $Id: m_unresv.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_unresv.c 7428 2016-03-07 17:46:09Z michael $
  */
 
 #include "stdinc.h"
+#include "list.h"
 #include "client.h"
-#include "ircd.h"
 #include "irc_string.h"
+#include "ircd.h"
+#include "conf.h"
+#include "conf_cluster.h"
+#include "conf_resv.h"
+#include "conf_shared.h"
 #include "numeric.h"
-#include "server.h"
+#include "log.h"
 #include "send.h"
+#include "server.h"
 #include "parse.h"
 #include "modules.h"
-#include "conf.h"
-#include "log.h"
-#include "resv.h"
+#include "memory.h"
 
 
 static void
-resv_remove(struct Client *source_p, const char *name)
+resv_remove(struct Client *source_p, const char *mask)
 {
-  unsigned int type_int = CONF_CRESV;
-  const char *type_str = "channel";
-  struct MaskItem *conf = NULL;
+  struct ResvItem *resv = NULL;
 
-  if (!IsChanPrefix(*name))
-  {
-    type_int = CONF_NRESV;
-    type_str = "nick";
-  }
-
-  if ((conf = find_exact_name_conf(type_int, NULL, name, NULL, NULL)) == NULL)
+  if ((resv = resv_find(mask, irccmp)) == NULL)
   {
     if (IsClient(source_p))
-     sendto_one_notice(source_p, &me, ":A RESV does not exist for %s: %s", type_str, name);
+      sendto_one_notice(source_p, &me, ":No RESV for %s", mask);
 
     return;
   }
 
-  if (!IsConfDatabase(conf))
+  if (!resv->in_database)
   {
     if (IsClient(source_p))
-      sendto_one_notice(source_p, &me, ":The RESV for %s: %s is in ircd.conf and must be removed by hand.",
-                        type_str, name);
+      sendto_one_notice(source_p, &me, ":The RESV for %s is in ircd.conf and must be removed by hand",
+                        resv->mask);
     return;
   }
 
-  conf_free(conf);
+  resv_delete(resv);
 
   if (IsClient(source_p))
-    sendto_one_notice(source_p, &me, ":The RESV has been removed on %s: %s", type_str, name);
+    sendto_one_notice(source_p, &me, ":RESV for [%s] is removed", mask);
 
   sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                       "%s has removed the RESV for %s: %s",
-                       get_oper_name(source_p), type_str, name);
+                       "%s has removed the RESV for: [%s]",
+                       get_oper_name(source_p), mask);
   ilog(LOG_TYPE_RESV, "%s removed RESV for [%s]",
-       get_oper_name(source_p), name);
+       get_oper_name(source_p), mask);
 }
 
 /*! \brief UNRESV command handler
@@ -95,8 +91,7 @@ resv_remove(struct Client *source_p, const char *name)
 static int
 mo_unresv(struct Client *source_p, int parc, char *parv[])
 {
-  char *resv = NULL;
-  char *reason = NULL;
+  char *mask = NULL;
   char *target_server = NULL;
 
   if (!HasOFlag(source_p, OPER_FLAG_UNRESV))
@@ -105,23 +100,23 @@ mo_unresv(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!parse_aline("UNRESV", source_p, parc, parv, 0, &resv, NULL,
-                   NULL, &target_server, &reason))
+  if (!parse_aline("UNRESV", source_p, parc, parv, &mask, NULL,
+                   NULL, &target_server, NULL))
     return 0;
 
   if (target_server)
   {
     sendto_match_servs(source_p, target_server, CAPAB_CLUSTER, "UNRESV %s %s",
-                       target_server, resv);
+                       target_server, mask);
 
     /* Allow ON to apply local unresv as well if it matches */
     if (match(target_server, me.name))
       return 0;
   }
   else
-    cluster_a_line(source_p, "UNRESV", CAPAB_KLN, SHARED_UNRESV, resv);
+    cluster_distribute(source_p, "UNRESV", CAPAB_KLN, CLUSTER_UNRESV, mask);
 
-  resv_remove(source_p, resv);
+  resv_remove(source_p, mask);
   return 0;
 }
 
@@ -134,8 +129,8 @@ mo_unresv(struct Client *source_p, int parc, char *parv[])
  *                 pointers.
  * \note Valid arguments for this command are:
  *      - parv[0] = command
- *      - parv[1] = target server
- *      - parv[2] = channel/nick
+ *      - parv[1] = target server mask
+ *      - parv[2] = name mask
  */
 static int
 ms_unresv(struct Client *source_p, int parc, char *parv[])
@@ -150,9 +145,8 @@ ms_unresv(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
-      find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
-                              source_p->username, source_p->host,
-                              SHARED_UNRESV))
+      shared_find(SHARED_UNRESV, source_p->servptr->name,
+                  source_p->username, source_p->host))
     resv_remove(source_p, parv[2]);
 
   return 0;
@@ -184,7 +178,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7428 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
