@@ -21,7 +21,7 @@
 
 /*! \file m_userhost.c
  * \brief Includes required functions for processing the USERHOST command.
- * \version $Id: m_userhost.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_userhost.c 7047 2016-01-10 12:38:40Z michael $
  */
 
 #include "stdinc.h"
@@ -70,7 +70,7 @@ m_userhost(struct Client *source_p, int parc, char *parv[])
        * lookup (USERHOST) to figure out what the clients' local IP
        * is. Useful for things like NAT, and dynamic dial-up users.
        */
-      if (MyClient(target_p) && (target_p == source_p))
+      if (MyConnect(target_p) && (target_p == source_p))
       {
         rl = snprintf(response, sizeof(response), "%s%s=%c%s@%s ",
                       target_p->name,
@@ -131,7 +131,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7047 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
