@@ -21,7 +21,7 @@
 
 /*! \file m_who.c
  * \brief Includes required functions for processing the WHO command.
- * \version $Id: m_who.c 7329 2016-02-18 21:07:50Z michael $
+ * \version $Id: m_who.c 7644 2016-07-16 17:56:53Z michael $
  */
 
 #include "stdinc.h"
@@ -82,6 +82,42 @@ do_who(struct Client *source_p, const struct Client *target_p,
                status, target_p->hopcount, target_p->info);
 }
 
+/*!
+ * \param source_p Pointer to client requesting who
+ * \param target_p Pointer to client to do who on
+ * \param mask Mask to match
+ * \return 1 if mask matches, 0 otherwise
+ */
+static int
+who_matches(struct Client *source_p, struct Client *target_p, const char *mask)
+{
+  if (!mask)
+    return 1;
+
+  if (!match(mask, target_p->name))
+    return 1;
+
+  if (!match(mask, target_p->username))
+    return 1;
+
+  if (!match(mask, target_p->host))
+    return 1;
+
+  if (!match(mask, target_p->info))
+    return 1;
+
+  if (HasUMode(source_p, UMODE_OPER))
+    if (!match(mask, target_p->sockhost))
+      return 1;
+
+  if (HasUMode(source_p, UMODE_OPER) ||
+      (!ConfigServerHide.hide_servers && !IsHidden(target_p->servptr)))
+    if (!match(mask, target_p->servptr->name))
+      return 1;
+
+  return 0;
+}
+
 /* who_common_channel
  * inputs	- pointer to client requesting who
  * 		- pointer to channel member chain.
@@ -113,12 +149,7 @@ who_common_channel(struct Client *source_p, struct Channel *chptr, const char *m
 
     AddFlag(target_p, FLAGS_MARK);
 
-    if ((mask == NULL) ||
-      !match(mask, target_p->name) || !match(mask, target_p->username) ||
-      !match(mask, target_p->host) ||
-      ((!ConfigServerHide.hide_servers || HasUMode(source_p, UMODE_OPER)) &&
-       !match(mask, target_p->servptr->name)) ||
-      !match(mask, target_p->info))
+    if (who_matches(source_p, target_p, mask))
     {
       do_who(source_p, target_p, NULL, "");
 
@@ -187,10 +218,7 @@ who_global(struct Client *source_p, const char *mask, int server_oper)
           (HasUMode(target_p, UMODE_HIDDEN) && !HasUMode(source_p, UMODE_OPER)))
         continue;
 
-    if (!mask ||
-        !match(mask, target_p->name) || !match(mask, target_p->username) ||
-        !match(mask, target_p->host) || !match(mask, target_p->servptr->name) ||
-        !match(mask, target_p->info))
+    if (who_matches(source_p, target_p, mask))
     {
       do_who(source_p, target_p, NULL, "");
 
@@ -277,7 +305,7 @@ m_who(struct Client *source_p, int parc, char *parv[])
     /* List all users on a given channel */
     if ((chptr = hash_find_channel(mask)))
     {
-      if (IsMember(source_p, chptr) || HasUMode(source_p, UMODE_ADMIN))
+      if (HasUMode(source_p, UMODE_ADMIN) || IsMember(source_p, chptr))
         do_who_on_channel(source_p, chptr, 1, server_oper);
       else if (!SecretChannel(chptr))
         do_who_on_channel(source_p, chptr, 0, server_oper);
@@ -357,7 +385,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7329 $",
+  .version = "$Revision: 7644 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
