@@ -21,7 +21,7 @@
 
 /*! \file m_whois.c
  * \brief Includes required functions for processing the WHOIS command.
- * \version $Id: m_whois.c 7329 2016-02-18 21:07:50Z michael $
+ * \version $Id: m_whois.c 7871 2016-11-09 20:13:07Z michael $
  */
 
 #include "stdinc.h"
@@ -69,7 +69,7 @@ static void
 whois_person(struct Client *source_p, struct Client *target_p)
 {
   char buf[IRCD_BUFSIZE] = "";
-  const dlink_node *node = NULL;
+  dlink_node *node;
   const struct ServicesTag *svstag = NULL;
   char *t = NULL;
   int cur_len = 0;
@@ -115,7 +115,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
   }
 
   if ((ConfigServerHide.hide_servers || IsHidden(target_p->servptr)) &&
-      !(HasUMode(source_p, UMODE_OPER) || target_p == source_p))
+      !(HasUMode(source_p, UMODE_OPER) || source_p == target_p))
     sendto_one_numeric(source_p, &me, RPL_WHOISSERVER, target_p->name,
                        ConfigServerHide.hidden_name,
                        ConfigServerInfo.network_desc);
@@ -202,6 +202,10 @@ whois_person(struct Client *source_p, struct Client *target_p)
       sendto_one_numeric(source_p, &me, RPL_WHOISIDLE, target_p->name,
                          client_get_idle_time(source_p, target_p),
                          target_p->connection->firsttime);
+
+  if (HasUMode(target_p, UMODE_SPY) && source_p != target_p)
+    sendto_one_notice(target_p, &me, ":*** Notice -- %s (%s@%s) [%s] is doing a /whois on you",
+                      source_p->name, source_p->username, source_p->host, source_p->servptr->name);
 }
 
 /* do_whois()
@@ -337,7 +341,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7329 $",
+  .version = "$Revision: 7871 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
