@@ -21,7 +21,7 @@
 
 /*! \file m_whowas.c
  * \brief Includes required functions for processing the WHOWAS command.
- * \version $Id: m_whowas.c 7448 2016-03-11 17:21:27Z michael $
+ * \version $Id: m_whowas.c 7686 2016-08-18 17:32:04Z michael $
  */
 
 #include "stdinc.h"
@@ -47,7 +47,7 @@ do_whowas(struct Client *source_p, const int parc, char *parv[])
 {
   int cur = 0;
   int max = -1;
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   if (parc > 2 && !EmptyString(parv[2]))
     max = atoi(parv[2]);
@@ -186,7 +186,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7448 $",
+  .version = "$Revision: 7686 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
