@@ -21,7 +21,7 @@
 
 /*! \file m_xline.c
  * \brief Includes required functions for processing the XLINE command.
- * \version $Id: m_xline.c 7434 2016-03-09 17:49:48Z michael $
+ * \version $Id: m_xline.c 7674 2016-07-20 18:54:17Z michael $
  */
 
 #include "stdinc.h"
@@ -67,8 +67,7 @@ xline_check(const struct GecosItem *gecos)
  * side effects - when successful, adds an xline to the conf
  */
 static void
-xline_handle(struct Client *source_p, const char *mask, const char *reason,
-             uintmax_t duration)
+xline_handle(struct Client *source_p, const char *mask, const char *reason, uintmax_t duration)
 {
   char buf[IRCD_BUFSIZE];
   struct GecosItem *gecos = NULL;
@@ -241,7 +240,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7434 $",
+  .version = "$Revision: 7674 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
