@@ -21,7 +21,7 @@
 
 /*! \file auth.c
  * \brief Functions for querying a users ident.
- * \version $Id: auth.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: auth.c 7913 2016-11-27 18:54:38Z michael $
  */
 
 /*
@@ -286,7 +286,7 @@ start_auth(struct Client *client_p)
 static void
 timeout_auth_queries_event(void *notused)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   DLINK_FOREACH_SAFE(node, node_next, auth_list.head)
   {
@@ -388,7 +388,7 @@ check_ident_reply(char *const reply)
 {
   char *token = NULL, *end = NULL;
   char *vector[USERID_TOKEN_COUNT];
-  const int count = token_vector(reply, ':', vector, USERID_TOKEN_COUNT);
+  const unsigned int count = token_vector(reply, ':', vector, USERID_TOKEN_COUNT);
 
   if (USERID_TOKEN_COUNT != count)
     return NULL;
