@@ -21,7 +21,7 @@
 
 /*! \file channel.c
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.c 7543 2016-04-21 11:15:58Z michael $
+ * \version $Id: channel.c 7913 2016-11-27 18:54:38Z michael $
  */
 
 #include "stdinc.h"
@@ -47,7 +47,7 @@
 dlink_list channel_list;
 mp_pool_t *ban_pool;    /*! \todo ban_pool shouldn't be a global var */
 
-static mp_pool_t *member_pool, *channel_pool;
+static mp_pool_t *member_pool, *channel_pool, *invite_pool;
 
 
 /*! \brief Initializes the channel blockheap, adds known channel CAPAB
@@ -58,6 +58,7 @@ channel_init(void)
   add_capability("EX", CAPAB_EX);
   add_capability("IE", CAPAB_IE);
 
+  invite_pool = mp_pool_new(sizeof(struct Invite), MP_CHUNK_SIZE_INVITE);
   channel_pool = mp_pool_new(sizeof(struct Channel), MP_CHUNK_SIZE_CHANNEL);
   ban_pool = mp_pool_new(sizeof(struct Ban), MP_CHUNK_SIZE_BAN);
   member_pool = mp_pool_new(sizeof(struct Membership), MP_CHUNK_SIZE_MEMBER);
@@ -76,7 +77,7 @@ add_user_to_channel(struct Channel *chptr, struct Client *client_p,
 {
   assert(IsClient(client_p));
 
-  if (GlobalSetOptions.joinfloodtime > 0)
+  if (GlobalSetOptions.joinfloodtime)
   {
     if (flood_ctrl)
       ++chptr->number_joined;
@@ -151,10 +152,10 @@ remove_user_from_channel(struct Membership *member)
  */
 static void
 channel_send_members(struct Client *client_p, const struct Channel *chptr,
-                     char *modebuf, char *parabuf)
+                     const char *modebuf, const char *parabuf)
 {
   char buf[IRCD_BUFSIZE] = "";
-  const dlink_node *node = NULL;
+  dlink_node *node;
   int tlen;              /* length of text to append */
   char *t, *start;       /* temp char pointer */
 
@@ -216,7 +217,7 @@ static void
 channel_send_mask_list(struct Client *client_p, const struct Channel *chptr,
                        const dlink_list *list, const char flag)
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
   char mbuf[IRCD_BUFSIZE] = "";
   char pbuf[IRCD_BUFSIZE] = "";
   int tlen, mlen, cur_len;
@@ -335,12 +336,9 @@ channel_free_mask_list(dlink_list *list)
 struct Channel *
 channel_make(const char *name)
 {
-  struct Channel *chptr = NULL;
-
   assert(!EmptyString(name));
 
-  chptr = mp_pool_get(channel_pool);
-
+  struct Channel *chptr = mp_pool_get(channel_pool);
   /* Doesn't hurt to set it here */
   chptr->creationtime = CurrentTime;
   chptr->last_join_time = CurrentTime;
@@ -361,7 +359,7 @@ channel_make(const char *name)
 void
 channel_free(struct Channel *chptr)
 {
-  clear_invites_channel(chptr);
+  clear_invite_list(&chptr->invites);
 
   /* Free ban/exception/invex lists */
   channel_free_mask_list(&chptr->banlist);
@@ -398,7 +396,7 @@ void
 channel_member_names(struct Client *client_p, struct Channel *chptr,
                      int show_eon)
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
   char buf[IRCD_BUFSIZE + 1] = "";
   char *t = NULL, *start = NULL;
   int tlen = 0;
@@ -470,6 +468,32 @@ channel_member_names(struct Client *client_p, struct Channel *chptr,
     sendto_one_numeric(client_p, &me, RPL_ENDOFNAMES, chptr->name);
 }
 
+static struct Invite *
+find_invite(struct Channel *chptr, struct Client *client_p)
+{
+  dlink_node *node, *node_next;
+  dlink_list *list;
+
+  /* Take the shortest of the two lists */
+  if (dlink_list_length(&client_p->connection->invited) < dlink_list_length(&chptr->invites))
+    list = &client_p->connection->invited;
+  else
+    list = &chptr->invites;
+
+  DLINK_FOREACH_SAFE(node, node_next, list->head)
+  {
+    struct Invite *invite = node->data;
+
+    if (ConfigChannel.invite_expire_time &&
+        ConfigChannel.invite_expire_time + invite->when < CurrentTime)
+      del_invite(invite);
+    else if (invite->chptr == chptr && invite->client_p == client_p)
+      return invite;
+  }
+
+  return NULL;
+}
+
 /*! \brief Adds client to invite list
  * \param chptr    Pointer to channel block
  * \param client_p Pointer to client to add invite to
@@ -477,61 +501,50 @@ channel_member_names(struct Client *client_p, struct Channel *chptr,
 void
 add_invite(struct Channel *chptr, struct Client *client_p)
 {
-  assert(IsClient(client_p));
+  struct Invite *invite;
 
-  del_invite(chptr, client_p);
+  if ((invite = find_invite(chptr, client_p)))
+    del_invite(invite);
+
+  invite = mp_pool_get(invite_pool);
+  invite->client_p = client_p;
+  invite->chptr = chptr;
+  invite->when = CurrentTime;
 
   /* Delete last link in chain if the list is max length */
   while (dlink_list_length(&client_p->connection->invited) && 
-         dlink_list_length(&client_p->connection->invited) >= ConfigChannel.max_channels)
-    del_invite(client_p->connection->invited.tail->data, client_p);
+         dlink_list_length(&client_p->connection->invited) >= ConfigChannel.max_invites)
+    del_invite(client_p->connection->invited.tail->data);
 
   /* Add client to channel invite list */
-  dlinkAdd(client_p, make_dlink_node(), &chptr->invites);
+  dlinkAdd(invite, &invite->chan_node, &chptr->invites);
 
   /* Add channel to the end of the client invite list */
-  dlinkAdd(chptr, make_dlink_node(), &client_p->connection->invited);
+  dlinkAdd(invite, &invite->user_node, &client_p->connection->invited);
 }
 
 /*! \brief Delete Invite block from channel invite list
  *         and client invite list
- * \param chptr    Pointer to Channel struct
- * \param client_p Pointer to client to remove invites from
+ * \param invite Pointer to Invite struct
  */
 void
-del_invite(struct Channel *chptr, struct Client *client_p)
+del_invite(struct Invite *invite)
 {
-  dlink_node *node = NULL;
+  dlinkDelete(&invite->user_node, &invite->client_p->connection->invited);
+  dlinkDelete(&invite->chan_node, &invite->chptr->invites);
 
-  if ((node = dlinkFindDelete(&client_p->connection->invited, chptr)))
-    free_dlink_node(node);
-
-  if ((node = dlinkFindDelete(&chptr->invites, client_p)))
-    free_dlink_node(node);
+  /* Release memory pointed to by 'invite' */
+  mp_pool_release(invite);
 }
 
-/*! \brief Removes all invites of a specific channel
- * \param chptr Pointer to Channel struct
+/*! \brief Removes and frees all Invite blocks from a list
+ * \param list Pointer to a dlink_list
  */
 void
-clear_invites_channel(struct Channel *chptr)
+clear_invite_list(dlink_list *list)
 {
-  dlink_node *node = NULL, *node_next = NULL;
-
-  DLINK_FOREACH_SAFE(node, node_next, chptr->invites.head)
-    del_invite(chptr, node->data);
-}
-
-/*! \brief Removes all invites of a specific client
- * \param client_p Pointer to Client struct
- */
-void
-clear_invites_client(struct Client *client_p)
-{
-  dlink_node *node = NULL, *node_next = NULL;
-
-  DLINK_FOREACH_SAFE(node, node_next, client_p->connection->invited.head)
-    del_invite(node->data, client_p);
+  while (list->head)
+    del_invite(list->head->data);
 }
 
 /* get_member_status()
@@ -580,7 +593,7 @@ get_member_status(const struct Membership *member, const int combine)
 static int
 find_bmask(const struct Client *client_p, const dlink_list *list)
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, list->head)
   {
@@ -636,7 +649,7 @@ is_banned(const struct Channel *chptr, const struct Client *client_p)
  *         or 0 if allowed to join.
  */
 static int
-can_join(struct Client *client_p, const struct Channel *chptr, const char *key)
+can_join(struct Client *client_p, struct Channel *chptr, const char *key)
 {
   if ((chptr->mode.mode & MODE_SSLONLY) && !HasUMode(client_p, UMODE_SSL))
     return ERR_SSLONLYCHAN;
@@ -648,7 +661,7 @@ can_join(struct Client *client_p, const struct Channel *chptr, const char *key)
     return ERR_OPERONLYCHAN;
 
   if (chptr->mode.mode & MODE_INVITEONLY)
-    if (!dlinkFind(&client_p->connection->invited, chptr))
+    if (!find_invite(chptr, client_p))
       if (!find_bmask(client_p, &chptr->invexlist))
         return ERR_INVITEONLYCHAN;
 
@@ -674,7 +687,7 @@ has_member_flags(const struct Membership *member, const unsigned int flags)
 struct Membership *
 find_channel_link(struct Client *client_p, struct Channel *chptr)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   if (!IsClient(client_p))
     return NULL;
@@ -947,18 +960,16 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
 {
   char *p = NULL;
   char *chan_list = NULL;
-  struct Channel *chptr = NULL;
   const struct ResvItem *resv = NULL;
   const struct ClassItem *const class = get_class_ptr(&client_p->connection->confs);
-  int i = 0;
   unsigned int flags = 0;
 
   assert(IsClient(client_p));
 
   chan_list = channel_find_last0(client_p, channel);
 
-  for (const char *chan = strtok_r(chan_list, ",", &p); chan;
-                   chan = strtok_r(NULL,      ",", &p))
+  for (const char *name = strtok_r(chan_list, ",", &p); name;
+                   name = strtok_r(NULL,      ",", &p))
   {
     const char *key = NULL;
 
@@ -970,41 +981,41 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
     if (key && *key == '\0')
       key = NULL;
 
-    if (!channel_check_name(chan, 1))
+    if (!channel_check_name(name, 1))
     {
-      sendto_one_numeric(client_p, &me, ERR_BADCHANNAME, chan);
+      sendto_one_numeric(client_p, &me, ERR_BADCHANNAME, name);
       continue;
     }
 
     if (!HasFlag(client_p, FLAGS_EXEMPTRESV) &&
         !(HasUMode(client_p, UMODE_OPER) && HasOFlag(client_p, OPER_FLAG_JOIN_RESV)) &&
-        ((resv = resv_find(chan, match)) && !resv_exempt_find(client_p, resv)))
+        ((resv = resv_find(name, match)) && !resv_exempt_find(client_p, resv)))
     {
-      sendto_one_numeric(client_p, &me, ERR_CHANBANREASON, chan, resv->reason);
+      sendto_one_numeric(client_p, &me, ERR_CHANBANREASON, name, resv->reason);
       sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                            "Forbidding reserved channel %s from user %s",
-                           chan, get_client_name(client_p, HIDE_IP));
+                           name, get_client_name(client_p, HIDE_IP));
       continue;
     }
 
     if (dlink_list_length(&client_p->channel) >=
         ((class->max_channels) ? class->max_channels : ConfigChannel.max_channels))
     {
-      sendto_one_numeric(client_p, &me, ERR_TOOMANYCHANNELS, chan);
+      sendto_one_numeric(client_p, &me, ERR_TOOMANYCHANNELS, name);
       break;
     }
 
-    if ((chptr = hash_find_channel(chan)))
+    struct Channel *chptr;
+    if ((chptr = hash_find_channel(name)))
     {
       if (IsMember(client_p, chptr))
         continue;
 
-      /*
-       * can_join checks for +i key, bans.
-       */
-      if ((i = can_join(client_p, chptr, key)))
+      /* can_join() checks for +i, +l, key, bans, etc. */
+      int ret = can_join(client_p, chptr, key);
+      if (ret)
       {
-        sendto_one_numeric(client_p, &me, i, chptr->name);
+        sendto_one_numeric(client_p, &me, ret, chptr->name);
         continue;
       }
 
@@ -1020,7 +1031,7 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
     else
     {
       flags = CHFL_CHANOP;
-      chptr = channel_make(chan);
+      chptr = channel_make(name);
     }
 
     if (!HasUMode(client_p, UMODE_OPER))
@@ -1079,7 +1090,9 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
                              client_p->host, client_p->away);
     }
 
-    del_invite(chptr, client_p);
+    struct Invite *invite = find_invite(chptr, client_p);
+    if (invite)
+      del_invite(invite);
 
     if (chptr->topic[0])
     {
@@ -1095,7 +1108,7 @@ channel_do_join(struct Client *client_p, char *channel, char *key_list)
 }
 
 /*! \brief Removes a client from a specific channel
- * \param client_p Pointer to source client to remove
+ * \param client_p Pointer to client to remove
  * \param name     Name of channel to remove from
  * \param reason   Part reason to show
  */
@@ -1150,7 +1163,7 @@ channel_part_one_client(struct Client *client_p, const char *name, const char *r
 void
 channel_do_part(struct Client *client_p, char *channel, const char *reason)
 {
-  char *p = NULL, *name = NULL;
+  char *p = NULL;
   char buf[KICKLEN + 1] = "";
 
   assert(IsClient(client_p));
@@ -1158,7 +1171,7 @@ channel_do_part(struct Client *client_p, char *channel, const char *reason)
   if (!EmptyString(reason))
     strlcpy(buf, reason, sizeof(buf));
 
-  for (name = strtok_r(channel, ",", &p); name;
-       name = strtok_r(NULL,    ",", &p))
+  for (const char *name = strtok_r(channel, ",", &p); name;
+                   name = strtok_r(NULL,    ",", &p))
     channel_part_one_client(client_p, name, buf);
 }
