@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.c
  * \brief Controls modes on channels.
- * \version $Id: channel_mode.c 7516 2016-03-30 18:22:29Z michael $
+ * \version $Id: channel_mode.c 7796 2016-10-18 17:26:37Z michael $
  */
 
 #include "stdinc.h"
@@ -113,10 +113,8 @@ check_string(char *s)
 int
 add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int type)
 {
-  dlink_list *list = NULL;
-  dlink_node *node = NULL;
-  struct Ban *ban = NULL;
-  size_t len = 0;
+  dlink_list *list;
+  dlink_node *node;
   char name[NICKLEN + 1] = "";
   char user[USERLEN + 1] = "";
   char host[HOSTLEN + 1] = "";
@@ -153,29 +151,28 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
    * Re-assemble a new n!u@h and print it back to banid for sending
    * the mode to the channel.
    */
-  len = snprintf(banid, IRCD_BUFSIZE, "%s!%s@%s", name, user, host);
+  size_t len = snprintf(banid, IRCD_BUFSIZE, "%s!%s@%s", name, user, host);
 
   switch (type)
   {
     case CHFL_BAN:
       list = &chptr->banlist;
-      clear_ban_cache_channel(chptr);
+      clear_ban_cache_list(&chptr->locmembers);
       break;
     case CHFL_EXCEPTION:
       list = &chptr->exceptlist;
-      clear_ban_cache_channel(chptr);
+      clear_ban_cache_list(&chptr->locmembers);
       break;
     case CHFL_INVEX:
       list = &chptr->invexlist;
       break;
     default:
-      assert(0);
-      return 0;
+      list = NULL;  /* Let it crash */
   }
 
   DLINK_FOREACH(node, list->head)
   {
-    ban = node->data;
+    const struct Ban *ban = node->data;
 
     if (!irccmp(ban->name, name) &&
         !irccmp(ban->user, user) &&
@@ -183,7 +180,7 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
       return 0;
   }
 
-  ban = mp_pool_get(ban_pool);
+  struct Ban *ban = mp_pool_get(ban_pool);
   ban->when = CurrentTime;
   ban->len = len - 2;  /* -2 for ! + @ */
   ban->type = parse_netmask(host, &ban->addr, &ban->bits);
@@ -214,8 +211,8 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
 static int
 del_id(struct Channel *chptr, char *banid, unsigned int type)
 {
-  dlink_list *list = NULL;
-  dlink_node *node = NULL;
+  dlink_list *list;
+  dlink_node *node;
   char name[NICKLEN + 1] = "";
   char user[USERLEN + 1] = "";
   char host[HOSTLEN + 1] = "";
@@ -244,18 +241,17 @@ del_id(struct Channel *chptr, char *banid, unsigned int type)
   {
     case CHFL_BAN:
       list = &chptr->banlist;
-      clear_ban_cache_channel(chptr);
+      clear_ban_cache_list(&chptr->locmembers);
       break;
     case CHFL_EXCEPTION:
       list = &chptr->exceptlist;
-      clear_ban_cache_channel(chptr);
+      clear_ban_cache_list(&chptr->locmembers);
       break;
     case CHFL_INVEX:
       list = &chptr->invexlist;
       break;
     default:
-      assert(0);
-      return 0;
+      list = NULL;  /* Let it crash */
   }
 
   DLINK_FOREACH(node, list->head)
@@ -344,23 +340,11 @@ fix_key(char *arg)
  * side effects - clear ban cache
  */
 void
-clear_ban_cache_channel(struct Channel *chptr)
+clear_ban_cache_list(dlink_list *list)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
-  DLINK_FOREACH(node, chptr->locmembers.head)
-  {
-    struct Membership *member = node->data;
-    member->flags &= ~(CHFL_BAN_SILENCED | CHFL_BAN_CHECKED);
-  }
-}
-
-void
-clear_ban_cache_client(struct Client *client_p)
-{
-  dlink_node *node = NULL;
-
-  DLINK_FOREACH(node, client_p->channel.head)
+  DLINK_FOREACH(node, list->head)
   {
     struct Membership *member = node->data;
     member->flags &= ~(CHFL_BAN_SILENCED | CHFL_BAN_CHECKED);
@@ -555,7 +539,7 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 {
   if (dir == MODE_QUERY || parc <= *parn)
   {
-    dlink_node *node = NULL;
+    dlink_node *node;
 
     if (*errors & SM_ERR_RPL_B)
       return;
@@ -621,7 +605,7 @@ chm_except(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 {
   if (dir == MODE_QUERY || parc <= *parn)
   {
-    dlink_node *node = NULL;
+    dlink_node *node;
 
     if (*errors & SM_ERR_RPL_E)
       return;
@@ -687,7 +671,7 @@ chm_invex(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 {
   if (dir == MODE_QUERY || parc <= *parn)
   {
-    dlink_node *node = NULL;
+    dlink_node *node;
 
     if (*errors & SM_ERR_RPL_I)
       return;
