@@ -21,7 +21,7 @@
 
 /*! \file client.c
  * \brief Controls clients.
- * \version $Id: client.c 7487 2016-03-16 15:31:44Z michael $
+ * \version $Id: client.c 7871 2016-11-09 20:13:07Z michael $
  */
 
 #include "stdinc.h"
@@ -86,7 +86,9 @@ make_client(struct Client *from)
 {
   struct Client *const client_p = mp_pool_get(client_pool);
 
-  if (!from)
+  if (from)
+    client_p->from = from;
+  else
   {
     client_p->from = client_p;  /* 'from' of local client is self! */
     client_p->connection = mp_pool_get(connection_pool);
@@ -98,8 +100,6 @@ make_client(struct Client *from)
     /* as good a place as any... */
     dlinkAdd(client_p, &client_p->connection->lclient_node, &unknown_list);
   }
-  else
-    client_p->from = from;
 
   client_p->idhnext = client_p;
   client_p->hnext = client_p;
@@ -498,12 +498,8 @@ find_chasing(struct Client *source_p, const char *name)
     return NULL;
 
   target_p = whowas_get_history(name, ConfigGeneral.kill_chase_time_limit);
-
   if (!target_p)
-  {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, name);
-    return NULL;
-  }
 
   return target_p;
 }
@@ -621,7 +617,7 @@ exit_one_client(struct Client *source_p, const char *comment)
 
     if (MyConnect(source_p))
     {
-      clear_invites_client(source_p);
+      clear_invite_list(&source_p->connection->invited);
       del_all_accepts(source_p);
     }
   }
@@ -642,7 +638,7 @@ exit_one_client(struct Client *source_p, const char *comment)
     hash_del_client(source_p);
 
   if (HasFlag(source_p, FLAGS_USERHOST))
-    userhost_del(source_p->username, source_p->host, !MyConnect(source_p));
+    userhost_del(source_p->sockhost, !MyConnect(source_p));
 
   update_client_exit_stats(source_p);
 
@@ -826,8 +822,7 @@ exit_client(struct Client *source_p, const char *comment)
     }
   }
   else if (IsClient(source_p) && !HasFlag(source_p, FLAGS_KILLED))
-    sendto_server(source_p->from, 0, 0, ":%s QUIT :%s",
-                  source_p->id, comment);
+    sendto_server(source_p->from, 0, 0, ":%s QUIT :%s", source_p->id, comment);
 
   /* The client *better* be off all of the lists */
   assert(dlinkFind(&unknown_list, source_p) == NULL);
@@ -1067,10 +1062,10 @@ client_get_idle_time(const struct Client *source_p,
   else
     idle = CurrentTime - target_p->connection->last_privmsg;
 
-  if (!max_idle)
-    idle = 0;
-  else
+  if (max_idle)
     idle %= max_idle;
+  else
+    idle = 0;
 
   if (idle < min_idle)
     idle = min_idle + (idle % (max_idle - min_idle));
