@@ -21,7 +21,7 @@
 
 /*! \file conf.c
  * \brief Configuration file functions.
- * \version $Id: conf.c 7536 2016-04-11 15:02:36Z michael $
+ * \version $Id: conf.c 7859 2016-11-08 20:09:29Z michael $
  */
 
 #include "stdinc.h"
@@ -220,14 +220,13 @@ attach_iline(struct Client *client_p, struct MaskItem *conf)
   const struct ClassItem *const class = conf->class;
   struct ip_entry *ip_found;
   int a_limit_reached = 0;
-  unsigned int local = 0, global = 0, ident = 0;
+  unsigned int local = 0, global = 0;
 
   ip_found = ipcache_find_or_add_address(&client_p->connection->ip);
   ip_found->count++;
   AddFlag(client_p, FLAGS_IPHASH);
 
-  userhost_count(client_p->username, client_p->host,
-                 &global, &local, &ident);
+  userhost_count(client_p->sockhost, &global, &local);
 
   /* XXX blah. go down checking the various silly limits
    * setting a_limit_reached if any limit is reached.
@@ -237,13 +236,10 @@ attach_iline(struct Client *client_p, struct MaskItem *conf)
     a_limit_reached = 1;
   else if (class->max_perip && ip_found->count > class->max_perip)
     a_limit_reached = 1;
-  else if (class->max_local && local >= class->max_local)
+  else if (class->max_local && local >= class->max_local) /* XXX: redundant */
     a_limit_reached = 1;
   else if (class->max_global && global >= class->max_global)
     a_limit_reached = 1;
-  else if (class->max_ident && ident >= class->max_ident &&
-           client_p->username[0] != '~')
-    a_limit_reached = 1;
 
   if (a_limit_reached)
   {
@@ -643,10 +639,12 @@ set_default_conf(void)
   ConfigChannel.invite_client_count = 10;
   ConfigChannel.invite_client_time = 300;
   ConfigChannel.invite_delay_channel = 5;
+  ConfigChannel.invite_expire_time = 1800;
   ConfigChannel.knock_client_count = 1;
   ConfigChannel.knock_client_time = 300;
   ConfigChannel.knock_delay_channel = 60;
   ConfigChannel.max_channels = 25;
+  ConfigChannel.max_invites = 20;
   ConfigChannel.max_bans = 25;
   ConfigChannel.default_join_flood_count = 18;
   ConfigChannel.default_join_flood_time = 6;
@@ -675,6 +673,7 @@ set_default_conf(void)
   ConfigGeneral.disable_auth = 0;
   ConfigGeneral.kill_chase_time_limit = 90;
   ConfigGeneral.default_floodcount = 8;
+  ConfigGeneral.default_floodtime = 1;
   ConfigGeneral.failed_oper_notice = 1;
   ConfigGeneral.dots_in_ident = 0;
   ConfigGeneral.min_nonwildcard = 4;
@@ -729,7 +728,7 @@ validate_conf(void)
 static void
 read_conf(FILE *file)
 {
-  lineno = 0;
+  lineno = 1;
 
   set_default_conf();  /* Set default values prior to conf parsing */
   conf_parser_ctx.pass = 1;
@@ -755,8 +754,11 @@ void
 conf_rehash(int sig)
 {
   if (sig)
+  {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Got signal SIGHUP, reloading configuration file(s)");
+    ilog(LOG_TYPE_IRCD, "Got signal SIGHUP, reloading configuration file(s)");
+  }
 
   restart_resolver();
 
@@ -1182,30 +1184,26 @@ conf_add_class_to_conf(struct MaskItem *conf, const char *name)
 void
 yyerror(const char *msg)
 {
-  char newlinebuf[IRCD_BUFSIZE];
-
   if (conf_parser_ctx.pass != 1)
     return;
 
-  strip_tabs(newlinebuf, linebuf, sizeof(newlinebuf));
+  const char *p = stripws(linebuf);
   sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                        "\"%s\", line %u: %s: %s",
-                       conffilebuf, lineno + 1, msg, newlinebuf);
+                       conffilebuf, lineno, msg, p);
   ilog(LOG_TYPE_IRCD, "\"%s\", line %u: %s: %s",
-       conffilebuf, lineno + 1, msg, newlinebuf);
+       conffilebuf, lineno, msg, p);
 }
 
 void
 conf_error_report(const char *msg)
 {
-  char newlinebuf[IRCD_BUFSIZE];
-
-  strip_tabs(newlinebuf, linebuf, sizeof(newlinebuf));
+  const char *p = stripws(linebuf);
   sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                        "\"%s\", line %u: %s: %s",
-                       conffilebuf, lineno + 1, msg, newlinebuf);
+                       conffilebuf, lineno, msg, p);
   ilog(LOG_TYPE_IRCD, "\"%s\", line %u: %s: %s",
-       conffilebuf, lineno + 1, msg, newlinebuf);
+       conffilebuf, lineno, msg, p);
 }
 
 /*
