@@ -21,7 +21,7 @@
 
 /*! \file hostmask.c
  * \brief Code to efficiently find IP & hostmask based configs.
- * \version $Id: hostmask.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: hostmask.c 7913 2016-11-27 18:54:38Z michael $
  */
 
 #include "stdinc.h"
@@ -154,9 +154,13 @@ try_parse_v6_netmask(const char *text, struct irc_ssaddr *addr, int *b)
 
   /* And assign... -A1kmm */
   if (addr)
+  {
+    v6->sin6_family = AF_INET6;
+
     for (dp = 0; dp < 8; ++dp)
       /* The cast is a kludge to make netbsd work. */
       ((unsigned short *)&v6->sin6_addr)[dp] = htons(dc[dp]);
+  }
 
   if (b)
     *b = bits;
@@ -234,8 +238,12 @@ try_parse_v4_netmask(const char *text, struct irc_ssaddr *addr, int *b)
   for (n = bits / 8 + (bits % 8 ? 1 : 0); n < 4; ++n)
     addb[n] = 0;
   if (addr)
+  {
+    v4->sin_family = AF_INET;
     v4->sin_addr.s_addr =
       htonl(addb[0] << 24 | addb[1] << 16 | addb[2] << 8 | addb[3]);
+  }
+
   if (b)
     *b = bits;
   return HM_IPV4;
@@ -251,6 +259,9 @@ try_parse_v4_netmask(const char *text, struct irc_ssaddr *addr, int *b)
 int
 parse_netmask(const char *text, struct irc_ssaddr *addr, int *b)
 {
+  if (addr)
+    memset(addr, 0, sizeof(struct irc_ssaddr));
+
   if (strchr(text, '.'))
     return try_parse_v4_netmask(text, addr, b);
   if (strchr(text, ':'))
@@ -439,10 +450,9 @@ find_conf_by_address(const char *name, const struct irc_ssaddr *addr, unsigned i
                      int fam, const char *username, const char *password, int do_match)
 {
   unsigned int hprecv = 0;
-  dlink_node *node = NULL;
+  dlink_node *node;
   struct MaskItem *hprec = NULL;
   struct AddressRec *arec = NULL;
-  int b;
   int (*cmpfunc)(const char *, const char *) = do_match ? match : irccmp;
 
   if (addr)
@@ -450,7 +460,7 @@ find_conf_by_address(const char *name, const struct irc_ssaddr *addr, unsigned i
     /* Check for IPV6 matches... */
     if (fam == AF_INET6)
     {
-      for (b = 128; b >= 0; b -= 16)
+      for (int b = 128; b >= 0; b -= 16)
       {
         DLINK_FOREACH(node, atable[hash_ipv6(addr, b)].head)
         {
@@ -473,7 +483,7 @@ find_conf_by_address(const char *name, const struct irc_ssaddr *addr, unsigned i
     }
     else if (fam == AF_INET)
     {
-      for (b = 32; b >= 0; b -= 8)
+      for (int b = 32; b >= 0; b -= 8)
       {
         DLINK_FOREACH(node, atable[hash_ipv4(addr, b)].head)
         {
@@ -557,8 +567,7 @@ find_address_conf(const char *host, const char *user, const struct irc_ssaddr *i
   struct MaskItem *authcnf = NULL, *killcnf = NULL;
 
   /* Find the best auth{} block... If none, return NULL -A1kmm */
-  if ((authcnf = find_conf_by_address(host, ip, CONF_CLIENT, aftype, user,
-                                      password, 1)) == NULL)
+  if ((authcnf = find_conf_by_address(host, ip, CONF_CLIENT, aftype, user, password, 1)) == NULL)
     return NULL;
 
   /* If they are exempt from K-lines, return the best auth{} block. -A1kmm */
@@ -604,7 +613,6 @@ find_dline_conf(const struct irc_ssaddr *addr, int aftype)
 struct AddressRec *
 add_conf_by_address(const unsigned int type, struct MaskItem *conf)
 {
-  struct AddressRec *arec = NULL;
   const char *const hostname = conf->host;
   const char *const username = conf->user;
   static unsigned int prec_value = UINT_MAX;
@@ -612,7 +620,7 @@ add_conf_by_address(const unsigned int type, struct MaskItem *conf)
 
   assert(type && !EmptyString(hostname));
 
-  arec = xcalloc(sizeof(struct AddressRec));
+  struct AddressRec *arec = xcalloc(sizeof(struct AddressRec));
   arec->masktype = parse_netmask(hostname, &arec->Mask.ipa.addr, &bits);
   arec->Mask.ipa.bits = bits;
   arec->username = username;
@@ -652,7 +660,7 @@ delete_one_address_conf(const char *address, struct MaskItem *conf)
 {
   int bits = 0;
   uint32_t hv = 0;
-  dlink_node *node = NULL;
+  dlink_node *node;
   struct irc_ssaddr addr;
 
   switch (parse_netmask(address, &addr, &bits))
@@ -699,7 +707,7 @@ delete_one_address_conf(const char *address, struct MaskItem *conf)
 void
 clear_out_address_conf(void)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
@@ -751,7 +759,7 @@ hostmask_send_expiration(const struct AddressRec *const arec)
 void
 hostmask_expire_temporary(void)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
