@@ -21,7 +21,7 @@
 
 /*! \file irc_string.c
  * \brief IRC string functions.
- * \version $Id: irc_string.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: irc_string.c 7796 2016-10-18 17:26:37Z michael $
  */
 
 #include "config.h"
@@ -48,25 +48,19 @@ has_wildcards(const char *str)
   return 0;
 }
 
-/*
- * strip_tabs(dst, src, length)
- *
- *   Copies src to dst, while converting all \t (tabs) into spaces.
- */
-void
-strip_tabs(char *dest, const char *src, size_t len)
+const char *
+stripws(char *txt)
 {
-  char *d = dest;
+  while (*txt == '\t' || *txt == ' ')
+    ++txt;
 
-  /* Sanity check; we don't want anything nasty... */
-  assert(dest);
-  assert(src);
-  assert(len > 0);
+  char *tmp = txt + strlen(txt) - 1;
+  while (tmp >= txt && (*tmp == '\t' || *tmp == ' '))
+    --tmp;
 
-  for (; --len && *src; ++src)
-    *d++ = *src == '\t' ? ' ' : *src;
+  *(tmp + 1) = '\0';
 
-  *d = '\0'; /* NUL terminate, thanks and goodbye */
+  return txt;
 }
 
 /*
@@ -116,12 +110,11 @@ strtok_r(char *str, const char *fs, char **save)
  * \param size Maximum number of elements to put in \a vector.
  * \return Number of elements written to \a vector.
  */
-int
-token_vector(char *names, char token, char *vector[], int size)
+unsigned int
+token_vector(char *names, char token, char *vector[], unsigned int size)
 {
-  int count = 0;
+  unsigned int count = 0;
   char *start = names;
-  char *end = NULL;
 
   assert(names);
   assert(vector);
@@ -129,8 +122,8 @@ token_vector(char *names, char token, char *vector[], int size)
 
   vector[count++] = start;
 
-  for (end = strchr(start, token); end;
-       end = strchr(start, token))
+  for (char *end = strchr(start, token); end;
+             end = strchr(start, token))
   {
     *end++ = '\0';
     start = end;
