@@ -21,7 +21,7 @@
 
 /*! \file ircd.c
  * \brief Starts up and runs the ircd.
- * \version $Id: ircd.c 7439 2016-03-10 20:03:41Z michael $
+ * \version $Id: ircd.c 7859 2016-11-08 20:09:29Z michael $
  */
 
 #include "stdinc.h"
@@ -220,27 +220,12 @@ initialize_global_set_options(void)
   GlobalSetOptions.spam_time = MIN_JOIN_LEAVE_TIME;
   GlobalSetOptions.spam_num = MAX_JOIN_LEAVE_COUNT;
   GlobalSetOptions.floodcount = ConfigGeneral.default_floodcount;
+  GlobalSetOptions.floodtime = ConfigGeneral.default_floodtime;
   GlobalSetOptions.joinfloodcount = ConfigChannel.default_join_flood_count;
   GlobalSetOptions.joinfloodtime = ConfigChannel.default_join_flood_time;
   GlobalSetOptions.ident_timeout = IDENT_TIMEOUT;
 }
 
-/* initialize_server_capabs()
- *
- * inputs       - none
- * output       - none
- */
-static void
-initialize_server_capabs(void)
-{
-  add_capability("QS", CAPAB_QS);
-  add_capability("EOB", CAPAB_EOB);
-  add_capability("CLUSTER", CAPAB_CLUSTER);
-  add_capability("SVS", CAPAB_SVS);
-  add_capability("CHW", CAPAB_CHW);
-  add_capability("HOPS", CAPAB_HOPS);
-}
-
 /* write_pidfile()
  *
  * inputs       - filename+path of pid file
@@ -409,7 +394,7 @@ main(int argc, char *argv[])
   if (!server_state.foreground)
   {
     make_daemon();
-    close_standard_fds(); /* this needs to be before init_netio()! */
+    close_standard_fds(); /* this needs to be before netio_init()! */
   }
   else
     print_startup(getpid());
@@ -420,7 +405,7 @@ main(int argc, char *argv[])
   fdlist_init();
   log_set_file(LOG_TYPE_IRCD, 0, logFileName);
 
-  init_netio();         /* This needs to be setup early ! -- adrian */
+  netio_init();         /* This needs to be setup early ! -- adrian */
   tls_init();
 
   /* Check if there is pidfile and daemon already running */
@@ -438,10 +423,10 @@ main(int argc, char *argv[])
   whowas_init();
   watch_init();
   auth_init();          /* Initialise the auth code */
-  init_resolver();      /* Needs to be setup before the io loop */
+  resolver_init();      /* Needs to be setup before the io loop */
   modules_init();
   read_conf_files(1);   /* cold start init conf files */
-  initialize_server_capabs();   /* Set up default_server_capabs */
+  server_capab_init();  /* Set up default_server_capabs */
   initialize_global_set_options();  /* Has to be called after read_conf_files() */
   channel_init();
   read_links_file();
