@@ -22,7 +22,7 @@
 
 /*! \file motd.c
  * \brief Message-of-the-day manipulation implementation.
- * \version $Id: motd.c 7265 2016-02-06 19:01:29Z michael $
+ * \version $Id: motd.c 7913 2016-11-27 18:54:38Z michael $
  */
 
 #include "stdinc.h"
@@ -98,7 +98,6 @@ static struct MotdCache *
 motd_cache(struct Motd *motd)
 {
   FILE *file = NULL;
-  struct MotdCache *cache = NULL;
   struct stat sb;
   char line[MOTD_LINESIZE + 2];  /* +2 for \r\n */
   char *tmp = NULL;
@@ -114,7 +113,7 @@ motd_cache(struct Motd *motd)
   /* Try to find it in the list of cached files */
   DLINK_FOREACH(node, MotdList.cachelist.head)
   {
-    cache = node->data;
+    struct MotdCache *cache = node->data;
 
     if (!strcmp(cache->path, motd->path) && cache->maxcount == motd->maxcount)
     {
@@ -141,7 +140,7 @@ motd_cache(struct Motd *motd)
   }
 
   /* Ok, allocate a structure; we'll realloc later to trim memory */
-  cache = xcalloc(sizeof(struct MotdCache) + (MOTD_LINESIZE * MOTD_MAXLINES));
+  struct MotdCache *cache = xcalloc(sizeof(struct MotdCache) + (MOTD_LINESIZE * MOTD_MAXLINES));
   cache->ref = 1;
   cache->path = xstrdup(motd->path);
   cache->maxcount = motd->maxcount;
@@ -331,7 +330,7 @@ motd_signon(struct Client *client_p)
 void
 motd_recache(void)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   motd_decache(MotdList.local);  /* Decache local and remote MOTDs */
   motd_decache(MotdList.remote);
@@ -404,7 +403,7 @@ motd_clear(void)
 void
 motd_report(struct Client *client_p, int parc, char *parv[])
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, MotdList.other.head)
   {
@@ -421,7 +420,7 @@ motd_report(struct Client *client_p, int parc, char *parv[])
 void
 motd_memory_count(struct Client *client_p)
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
   unsigned int mt  = 0;  /* Motd count */
   unsigned int mtc = 0;  /* Motd cache count */
   size_t mtm  = 0;  /* Memory consumed by motd */
