@@ -21,7 +21,7 @@
 
 /*! \file res.c
  * \brief ircd resolver functions
- * \version $Id: res.c 7329 2016-02-18 21:07:50Z michael $
+ * \version $Id: res.c 7913 2016-11-27 18:54:38Z michael $
  */
 
 /*
@@ -79,8 +79,7 @@ static void res_readreply(fde_t *, void *);
 struct reslist
 {
   dlink_node node;                           /**< Doubly linked list node. */
-  int id;                                    /**< Request ID (from request header). */
-  int sent;                                  /**< Number of requests sent */
+  unsigned int id;                           /**< Request ID (from request header). */
   char type;                                 /**< Current request type. */
   char retries;                              /**< Retry counter */
   unsigned int sends;                        /**< Number of sends (>1 means resent). */
@@ -118,10 +117,10 @@ make_request(dns_callback_fnc callback, void *ctx)
 {
   struct reslist *request = mp_pool_get(dns_pool);
 
-  request->sentat       = CurrentTime;
-  request->retries      = 2;
-  request->timeout      = 4;  /* Start at 4 and exponential inc. */
-  request->callback     = callback;
+  request->sentat = CurrentTime;
+  request->retries = 2;
+  request->timeout = 4;  /* Start at 4 and exponential inc. */
+  request->callback = callback;
   request->callback_ctx = ctx;
 
   dlinkAdd(request, &request->node, &request_list);
@@ -215,7 +214,7 @@ restart_resolver(void)
 void
 delete_resolver_queries(const void *vptr)
 {
-  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *node, *node_next;
 
   DLINK_FOREACH_SAFE(node, node_next, request_list.head)
   {
@@ -233,10 +232,9 @@ delete_resolver_queries(const void *vptr)
  * isn't present. Returns number of messages successfully sent to
  * nameservers or -1 if no successful sends.
  */
-static int
+static void
 send_res_msg(const unsigned char *msg, int len, unsigned int rcount)
 {
-  int sent = 0;
   unsigned int max_queries = IRCD_MIN(irc_nscount, rcount);
 
   /* RES_PRIMARY option is not implemented
@@ -246,23 +244,17 @@ send_res_msg(const unsigned char *msg, int len, unsigned int rcount)
     max_queries = 1;
 
   for (unsigned int i = 0; i < max_queries; ++i)
-  {
-    if (sendto(ResolverFileDescriptor.fd, msg, len, 0,
-        (struct sockaddr*)&(irc_nsaddr_list[i]),
-        irc_nsaddr_list[i].ss_len) == len)
-      ++sent;
-  }
-
-  return sent;
+    sendto(ResolverFileDescriptor.fd, msg, len, 0,
+           (struct sockaddr *)&irc_nsaddr_list[i], irc_nsaddr_list[i].ss_len);
 }
 
 /*
  * find_id - find a dns request id (id is determined by dn_mkquery)
  */
 static struct reslist *
-find_id(int id)
+find_id(unsigned int id)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, request_list.head)
   {
@@ -303,7 +295,7 @@ query_name(const char *name, int query_class, int type, struct reslist *request)
     request->id = header->id;
     ++request->sends;
 
-    request->sent += send_res_msg(buf, request_len, request->sends);
+    send_res_msg(buf, request_len, request->sends);
   }
 }
 
@@ -318,10 +310,10 @@ do_query_name(dns_callback_fnc callback, void *ctx, const char *name,
 
   strlcpy(host_name, name, sizeof(host_name));
 
-  if (request == NULL)
+  if (!request)
   {
-    request             = make_request(callback, ctx);
-    request->type       = type;
+    request = make_request(callback, ctx);
+    request->type = type;
     request->namelength = strlcpy(request->name, host_name, sizeof(request->name));
   }
 
@@ -374,9 +366,9 @@ do_query_number(dns_callback_fnc callback, void *ctx,
              (unsigned int)(cp[0] & 0xf), (unsigned int)(cp[0] >> 4));
   }
 
-  if (request == NULL)
+  if (!request)
   {
-    request       = make_request(callback, ctx);
+    request = make_request(callback, ctx);
     request->type = T_PTR;
     memcpy(&request->addr, addr, sizeof(struct irc_ssaddr));
   }
@@ -448,7 +440,7 @@ proc_answer(struct reslist *request, HEADER *header, unsigned char *buf, unsigne
    */
   while (header->ancount > 0 && current < eob)
   {
-    header->ancount--;
+    --header->ancount;
 
     n = irc_dn_expand(buf, eob, current, hostbuf, sizeof(hostbuf));
 
@@ -538,7 +530,6 @@ static void
 res_readreply(fde_t *fd, void *data)
 {
   unsigned char buf[sizeof(HEADER) + MAXPACKET];
-  HEADER *header;
   struct reslist *request = NULL;
   ssize_t rc = 0;
   socklen_t len = sizeof(struct irc_ssaddr);
@@ -558,7 +549,7 @@ res_readreply(fde_t *fd, void *data)
     /*
      * Convert DNS reply reader from Network byte order to CPU byte order.
      */
-    header = (HEADER *)buf;
+    HEADER *header = (HEADER *)buf;
     header->ancount = ntohs(header->ancount);
     header->qdcount = ntohs(header->qdcount);
     header->nscount = ntohs(header->nscount);
@@ -574,8 +565,8 @@ res_readreply(fde_t *fd, void *data)
     if (header->rcode != NO_ERRORS || header->ancount == 0)
     {
       /*
-       * If a bad error was returned, stop here and don't
-       * send any more (no retries granted).
+       * If a bad error was returned, stop here and don't send
+       * any more (no retries granted).
        */
       (*request->callback)(request->callback_ctx, NULL, NULL, 0);
       rem_request(request);
@@ -614,6 +605,7 @@ res_readreply(fde_t *fd, void *data)
         gethost_byname_type(request->callback, request->callback_ctx, request->name, T_AAAA);
       else
         gethost_byname_type(request->callback, request->callback_ctx, request->name, T_A);
+
       rem_request(request);
     }
     else
@@ -638,15 +630,13 @@ res_readreply(fde_t *fd, void *data)
 static uintmax_t
 timeout_query_list(void)
 {
-  dlink_node *node = NULL, *node_next = NULL;
-  struct reslist *request = NULL;
+  dlink_node *node, *node_next;
   uintmax_t next_time = 0;
-  uintmax_t timeout   = 0;
 
   DLINK_FOREACH_SAFE(node, node_next, request_list.head)
   {
-    request = node->data;
-    timeout = request->sentat + request->timeout;
+    struct reslist *request = node->data;
+    uintmax_t timeout = request->sentat + request->timeout;
 
     if (CurrentTime >= timeout)
     {
@@ -681,10 +671,10 @@ timeout_resolver(void *unused)
 }
 
 /*
- * init_resolver - initialize resolver and resolver library
+ * resolver_init - initialize resolver and resolver library
  */
 void
-init_resolver(void)
+resolver_init(void)
 {
   static struct event event_timeout_resolver =
   {
