@@ -21,13 +21,10 @@
 
 /*! \file s_bsd.c
  * \brief Network functions.
- * \version $Id: s_bsd.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: s_bsd.c 7667 2016-07-20 17:09:36Z michael $
  */
 
 #include "stdinc.h"
-#ifdef HAVE_LIBCRYPTO
-#include "rsa.h"
-#endif
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
 #include <netinet/tcp.h>
@@ -179,7 +176,7 @@ close_connection(struct Client *client_p)
     ServerStats.is_sbr += client_p->connection->recv.bytes;
     ServerStats.is_sti += CurrentTime - client_p->connection->firsttime;
 
-    DLINK_FOREACH(node, server_items.head)
+    DLINK_FOREACH(node, connect_items.head)
     {
       struct MaskItem *conf = node->data;
 
@@ -196,15 +193,9 @@ close_connection(struct Client *client_p)
   else
     ++ServerStats.is_ni;
 
-#ifdef HAVE_LIBCRYPTO
-  if (client_p->connection->fd.ssl)
-  {
-    SSL_set_shutdown(client_p->connection->fd.ssl, SSL_RECEIVED_SHUTDOWN);
+  if (tls_isusing(&client_p->connection->fd.ssl))
+    tls_shutdown(&client_p->connection->fd.ssl);
 
-    if (!SSL_shutdown(client_p->connection->fd.ssl))
-      SSL_shutdown(client_p->connection->fd.ssl);
-  }
-#endif
   if (client_p->connection->fd.flags.open)
     fd_close(&client_p->connection->fd);
 
@@ -217,7 +208,6 @@ close_connection(struct Client *client_p)
   detach_conf(client_p, CONF_CLIENT | CONF_OPER | CONF_SERVER);
 }
 
-#ifdef HAVE_LIBCRYPTO
 /*
  * ssl_handshake - let OpenSSL initialize the protocol. Register for
  * read/write events if necessary.
@@ -226,64 +216,40 @@ static void
 ssl_handshake(fde_t *fd, void *data)
 {
   struct Client *client_p = data;
-  X509 *cert = NULL;
-  int ret = 0;
 
-  if ((ret = SSL_accept(client_p->connection->fd.ssl)) <= 0)
+  tls_handshake_status_t ret = tls_handshake(&client_p->connection->fd.ssl, TLS_ROLE_SERVER, NULL);
+  if (ret != TLS_HANDSHAKE_DONE)
   {
     if ((CurrentTime - client_p->connection->firsttime) > CONNECTTIMEOUT)
     {
-      exit_client(client_p, "Timeout during SSL handshake");
+      exit_client(client_p, "Timeout during TLS handshake");
       return;
     }
 
-    switch (SSL_get_error(client_p->connection->fd.ssl, ret))
+    switch (ret)
     {
-      case SSL_ERROR_WANT_WRITE:
+      case TLS_HANDSHAKE_WANT_WRITE:
         comm_setselect(&client_p->connection->fd, COMM_SELECT_WRITE,
                        ssl_handshake, client_p, CONNECTTIMEOUT);
         return;
-
-      case SSL_ERROR_WANT_READ:
+      case TLS_HANDSHAKE_WANT_READ:
         comm_setselect(&client_p->connection->fd, COMM_SELECT_READ,
                        ssl_handshake, client_p, CONNECTTIMEOUT);
         return;
-
       default:
-        exit_client(client_p, "Error during SSL handshake");
+        exit_client(client_p, "Error during TLS handshake");
         return;
     }
   }
 
   comm_settimeout(&client_p->connection->fd, 0, NULL, NULL);
 
-  if ((cert = SSL_get_peer_certificate(client_p->connection->fd.ssl)))
-  {
-    int res = SSL_get_verify_result(client_p->connection->fd.ssl);
-    char buf[EVP_MAX_MD_SIZE * 2 + 1] = "";
-    unsigned char md[EVP_MAX_MD_SIZE] = "";
-
-    if (res == X509_V_OK || res == X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN ||
-        res == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE ||
-        res == X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT)
-    {
-      unsigned int n = 0;
-
-      if (X509_digest(cert, ConfigServerInfo.message_digest_algorithm, md, &n))
-      {
-        binary_to_hex(md, buf, n);
-        client_p->certfp = xstrdup(buf);
-      }
-    }
-    else
-      ilog(LOG_TYPE_IRCD, "Client %s!%s@%s gave bad SSL client certificate: %d",
-           client_p->name, client_p->username, client_p->host, res);
-    X509_free(cert);
-  }
+  if (!tls_verify_cert(&client_p->connection->fd.ssl, ConfigServerInfo.message_digest_algorithm, &client_p->certfp))
+    ilog(LOG_TYPE_IRCD, "Client %s!%s@%s gave bad TLS client certificate",
+         client_p->name, client_p->username, client_p->host);
 
   start_auth(client_p);
 }
-#endif
 
 /*
  * add_connection - creates a client which has just connected to us on
@@ -313,19 +279,25 @@ add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
   client_p->connection->aftype = client_p->connection->ip.ss.ss_family;
 
 #ifdef HAVE_LIBGEOIP
-  /* XXX IPV6 SUPPORT XXX */
-  if (irn->ss.ss_family == AF_INET && geoip_ctx)
+  if (irn->ss.ss_family == AF_INET && GeoIPv4_ctx)
   {
-    const struct sockaddr_in *v4 = (const struct sockaddr_in *)&client_p->connection->ip;
-    client_p->connection->country_id = GeoIP_id_by_ipnum(geoip_ctx, (unsigned long)ntohl(v4->sin_addr.s_addr));
+    GeoIPLookup gl;
+    const struct sockaddr_in *const v4 = (const struct sockaddr_in *)&client_p->connection->ip;
+    client_p->connection->country_id = GeoIP_id_by_ipnum_gl(GeoIPv4_ctx, (unsigned long)ntohl(v4->sin_addr.s_addr), &gl);
+  }
+  else if (irn->ss.ss_family == AF_INET6 && GeoIPv6_ctx)
+  {
+    GeoIPLookup gl;
+    const struct sockaddr_in6 *const v6 = (const struct sockaddr_in6 *)&client_p->connection->ip;
+    client_p->connection->country_id = GeoIP_id_by_ipnum_v6_gl(GeoIPv6_ctx, v6->sin6_addr, &gl);
   }
 #endif
 
   if (client_p->sockhost[0] == ':' && client_p->sockhost[1] == ':')
   {
     strlcpy(client_p->host, "0", sizeof(client_p->host));
-    strlcpy(client_p->host+1, client_p->sockhost, sizeof(client_p->host)-1);
-    memmove(client_p->sockhost+1, client_p->sockhost, sizeof(client_p->sockhost)-1);
+    strlcpy(client_p->host + 1, client_p->sockhost, sizeof(client_p->host) - 1);
+    memmove(client_p->sockhost + 1, client_p->sockhost, sizeof(client_p->sockhost) - 1);
     client_p->sockhost[0] = '0';
   }
   else
@@ -334,25 +306,19 @@ add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
   client_p->connection->listener = listener;
   ++listener->ref_count;
 
-#ifdef HAVE_LIBCRYPTO
   if (listener->flags & LISTENER_SSL)
   {
-    if ((client_p->connection->fd.ssl = SSL_new(ConfigServerInfo.server_ctx)) == NULL)
+    if (!tls_new(&client_p->connection->fd.ssl, fd, TLS_ROLE_SERVER))
     {
-      ilog(LOG_TYPE_IRCD, "SSL_new() ERROR! -- %s",
-           ERR_error_string(ERR_get_error(), NULL));
-
       SetDead(client_p);
-      exit_client(client_p, "SSL_new failed");
+      exit_client(client_p, "TLS context initialization failed");
       return;
     }
 
     AddFlag(client_p, FLAGS_SSL);
-    SSL_set_fd(client_p->connection->fd.ssl, fd);
     ssl_handshake(NULL, client_p);
   }
   else
-#endif
     start_auth(client_p);
 }
 
@@ -389,7 +355,7 @@ ignoreErrno(int ierrno)
  * Set the timeout for the fd
  */
 void
-comm_settimeout(fde_t *fd, time_t timeout, void (*callback)(fde_t *, void *), void *cbdata)
+comm_settimeout(fde_t *fd, uintmax_t timeout, void (*callback)(fde_t *, void *), void *cbdata)
 {
   assert(fd->flags.open);
 
@@ -411,7 +377,7 @@ comm_settimeout(fde_t *fd, time_t timeout, void (*callback)(fde_t *, void *), vo
  * comm_close() is replaced with fd_close() in fdlist.c
  */
 void
-comm_setflush(fde_t *fd, time_t timeout, void (*callback)(fde_t *, void *), void *cbdata)
+comm_setflush(fde_t *fd, uintmax_t timeout, void (*callback)(fde_t *, void *), void *cbdata)
 {
   assert(fd->flags.open);
 
@@ -430,12 +396,12 @@ comm_setflush(fde_t *fd, time_t timeout, void (*callback)(fde_t *, void *), void
 void
 comm_checktimeouts(void *unused)
 {
-  int i;
   fde_t *F;
   void (*hdl)(fde_t *, void *);
   void *data;
 
-  for (i = 0; i < FD_HASH_SIZE; i++)
+  for (unsigned int i = 0; i < FD_HASH_SIZE; i++)
+  {
     for (F = fd_hash[i]; F != NULL; F = fd_next_in_loop)
     {
       assert(F->flags.open);
@@ -462,6 +428,7 @@ comm_checktimeouts(void *unused)
         hdl(F, data);
       }
     }
+  }
 }
 
 /*
@@ -480,7 +447,7 @@ comm_checktimeouts(void *unused)
 void
 comm_connect_tcp(fde_t *fd, const char *host, unsigned short port, struct sockaddr *clocal,
                  int socklen, void (*callback)(fde_t *, int, void *), void *data,
-                 int aftype, time_t timeout)
+                 int aftype, uintmax_t timeout)
 {
   struct addrinfo hints, *res;
   char portname[PORTNAMELEN + 1];
@@ -499,7 +466,7 @@ comm_connect_tcp(fde_t *fd, const char *host, unsigned short port, struct sockad
    * virtual host IP, for completeness.
    *   -- adrian
    */
-  if ((clocal != NULL) && (bind(fd->fd, clocal, socklen) < 0))
+  if (clocal && bind(fd->fd, clocal, socklen) < 0)
   {
     /* Failure, call the callback with COMM_ERR_BIND */
     comm_connect_callback(fd, COMM_ERR_BIND);
@@ -507,6 +474,7 @@ comm_connect_tcp(fde_t *fd, const char *host, unsigned short port, struct sockad
   }
 
   memset(&hints, 0, sizeof(hints));
+
   hints.ai_family = AF_UNSPEC;
   hints.ai_socktype = SOCK_STREAM;
   hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
@@ -529,12 +497,14 @@ comm_connect_tcp(fde_t *fd, const char *host, unsigned short port, struct sockad
   {
     /* We have a valid IP, so we just call tryconnect */
     /* Make sure we actually set the timeout here .. */
-    assert(res != NULL);
+    assert(res);
+
     memcpy(&fd->connect.hostaddr, res->ai_addr, res->ai_addrlen);
     fd->connect.hostaddr.ss_len = res->ai_addrlen;
     fd->connect.hostaddr.ss.ss_family = res->ai_family;
     freeaddrinfo(res);
-    comm_settimeout(fd, timeout*1000, comm_connect_timeout, NULL);
+
+    comm_settimeout(fd, timeout * 1000, comm_connect_timeout, NULL);
     comm_connect_tryconnect(fd, NULL);
   }
 }
@@ -583,7 +553,7 @@ comm_connect_timeout(fde_t *fd, void *unused)
 static void
 comm_connect_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char *name, size_t namelength)
 {
-  fde_t *F = vptr;
+  fde_t *const F = vptr;
 
   if (!addr)
   {
@@ -601,8 +571,9 @@ comm_connect_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char
    *     -- adrian
    */
   memcpy(&F->connect.hostaddr, addr, addr->ss_len);
+
   /* The cast is hacky, but safe - port offset is same on v4 and v6 */
-  ((struct sockaddr_in *) &F->connect.hostaddr)->sin_port = F->connect.hostaddr.ss_port;
+  ((struct sockaddr_in *)&F->connect.hostaddr)->sin_port = F->connect.hostaddr.ss_port;
   F->connect.hostaddr.ss_len = addr->ss_len;
 
   /* Now, call the tryconnect() routine to try a connect() */
@@ -620,15 +591,12 @@ comm_connect_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char
 static void
 comm_connect_tryconnect(fde_t *fd, void *unused)
 {
-  int retval;
-
   /* This check is needed or re-entrant s_bsd_* like sigio break it. */
   if (fd->connect.callback == NULL)
     return;
 
   /* Try the connect() */
-  retval = connect(fd->fd, (struct sockaddr *) &fd->connect.hostaddr,
-    fd->connect.hostaddr.ss_len);
+  int retval = connect(fd->fd, (struct sockaddr *)&fd->connect.hostaddr, fd->connect.hostaddr.ss_len);
 
   /* Error? */
   if (retval < 0)
@@ -642,8 +610,7 @@ comm_connect_tryconnect(fde_t *fd, void *unused)
       comm_connect_callback(fd, COMM_OK);
     else if (ignoreErrno(errno))
       /* Ignore error? Reschedule */
-      comm_setselect(fd, COMM_SELECT_WRITE, comm_connect_tryconnect,
-                     NULL, 0);
+      comm_setselect(fd, COMM_SELECT_WRITE, comm_connect_tryconnect, NULL, 0);
     else
       /* Error? Fail with COMM_ERR_CONNECT */
       comm_connect_callback(fd, COMM_ERR_CONNECT);
@@ -675,8 +642,6 @@ comm_errstr(int error)
 int
 comm_open(fde_t *F, int family, int sock_type, int proto, const char *note)
 {
-  int fd;
-
   /* First, make sure we aren't going to run out of file descriptors */
   if (number_fd >= hard_fdlimit)
   {
@@ -689,7 +654,7 @@ comm_open(fde_t *F, int family, int sock_type, int proto, const char *note)
    * limit if/when we get an error, but we can deal with that later.
    * XXX !!! -- adrian
    */
-  fd = socket(family, sock_type, proto);
+  int fd = socket(family, sock_type, proto);
   if (fd < 0)
     return -1; /* errno will be passed through, yay.. */
 
@@ -710,7 +675,6 @@ comm_open(fde_t *F, int family, int sock_type, int proto, const char *note)
 int
 comm_accept(struct Listener *lptr, struct irc_ssaddr *addr)
 {
-  int newfd;
   socklen_t addrlen = sizeof(struct irc_ssaddr);
 
   if (number_fd >= hard_fdlimit)
@@ -726,16 +690,16 @@ comm_accept(struct Listener *lptr, struct irc_ssaddr *addr)
    * reserved fd limit, but we can deal with that when comm_open()
    * also does it. XXX -- adrian
    */
-  newfd = accept(lptr->fd.fd, (struct sockaddr *)addr, &addrlen);
-  if (newfd < 0)
+  int fd = accept(lptr->fd.fd, (struct sockaddr *)addr, &addrlen);
+  if (fd < 0)
     return -1;
 
   remove_ipv6_mapping(addr);
 
-  setup_socket(newfd);
+  setup_socket(fd);
 
   /* .. and return */
-  return newfd;
+  return fd;
 }
 
 /*
