@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_epoll.c
  * \brief Linux epoll() compatible network routines.
- * \version $Id: s_bsd_epoll.c 7329 2016-02-18 21:07:50Z michael $
+ * \version $Id: s_bsd_epoll.c 7667 2016-07-20 17:09:36Z michael $
  */
 
 #include "stdinc.h"
@@ -37,19 +37,19 @@ static fde_t efd;
 
 
 /*
- * init_netio
+ * netio_init
  *
  * This is a needed exported function which will be called to initialise
  * the network loop code.
  */
 void
-init_netio(void)
+netio_init(void)
 {
   int fd;
 
   if ((fd = epoll_create(hard_fdlimit)) < 0)
   {
-    ilog(LOG_TYPE_IRCD, "init_netio: couldn't open epoll fd: %s",
+    ilog(LOG_TYPE_IRCD, "netio_init: couldn't open epoll fd: %s",
          strerror(errno));
     exit(EXIT_FAILURE); /* Whee! */
   }
