@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_kqueue.c
  * \brief kqueue() compatible network routines.
- * \version $Id: s_bsd_kqueue.c 7329 2016-02-18 21:07:50Z michael $
+ * \version $Id: s_bsd_kqueue.c 7759 2016-10-05 18:33:01Z michael $
  */
 
 #include "stdinc.h"
@@ -40,19 +40,19 @@ static int kqoff;      /* offset into the buffer */
 
 
 /*
- * init_netio
+ * netio_init
  *
  * This is a needed exported function which will be called to initialise
  * the network loop code.
  */
 void
-init_netio(void)
+netio_init(void)
 {
   int fd;
 
   if ((fd = kqueue()) < 0)
   {
-    ilog(LOG_TYPE_IRCD, "init_netio: couldn't open kqueue fd: %s", strerror(errno));
+    ilog(LOG_TYPE_IRCD, "netio_init: couldn't open kqueue fd: %s", strerror(errno));
     exit(EXIT_FAILURE); /* Whee! */
   }
 
@@ -65,7 +65,7 @@ init_netio(void)
 static void
 kq_update_events(int fd, int filter, int what)
 {
-  static struct timespec zero_timespec = {0, 0};
+  const struct timespec zero_timespec = { .tv_sec = 0, .tv_nsec = 0 };
   struct kevent *kep = kq_fdlist + kqoff;
 
   EV_SET(kep, (uintptr_t) fd, (short) filter, what, 0, 0, NULL);
