@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_poll.c
  * \brief POSIX poll() compatible network routines.
- * \version $Id: s_bsd_poll.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: s_bsd_poll.c 7667 2016-07-20 17:09:36Z michael $
  */
 
 #include "stdinc.h"
@@ -48,13 +48,13 @@ static int pollnum;
 
 
 /*
- * init_netio
+ * netio_init
  *
  * This is a needed exported function which will be called to initialise
  * the network loop code.
  */
 void
-init_netio(void)
+netio_init(void)
 {
   pollfds_size = hard_fdlimit;
   pollfds = xcalloc(sizeof(struct pollfd) * pollfds_size);
@@ -68,7 +68,7 @@ init_netio(void)
  */
 void
 comm_setselect(fde_t *F, unsigned int type, void (*handler)(fde_t *, void *),
-               void *client_data, time_t timeout)
+               void *client_data, uintmax_t timeout)
 {
   int new_events;
 
