@@ -21,14 +21,10 @@
 
 /*! \file s_serv.c
  * \brief Server related functions.
- * \version $Id: server.c 7033 2016-01-03 14:37:29Z michael $
+ * \version $Id: server.c 7686 2016-08-18 17:32:04Z michael $
  */
 
 #include "stdinc.h"
-#ifdef HAVE_LIBCRYPTO
-#include <openssl/rsa.h>
-#include "rsa.h"
-#endif
 #include "list.h"
 #include "client.h"
 #include "event.h"
@@ -37,15 +33,12 @@
 #include "ircd.h"
 #include "ircd_defs.h"
 #include "s_bsd.h"
-#include "numeric.h"
 #include "packet.h"
 #include "conf.h"
 #include "server.h"
 #include "log.h"
-#include "user.h"
 #include "send.h"
 #include "memory.h"
-#include "channel.h"
 #include "parse.h"
 
 
@@ -259,7 +252,7 @@ try_connections(void *unused)
   if (GlobalSetOptions.autoconn == 0)
     return;
 
-  DLINK_FOREACH(node, server_items.head)
+  DLINK_FOREACH(node, connect_items.head)
   {
     struct MaskItem *conf = node->data;
 
@@ -295,8 +288,8 @@ try_connections(void *unused)
       /* Move this entry to the end of the list, if not already last */
       if (node->next)
       {
-        dlinkDelete(node, &server_items);
-        dlinkAddTail(conf, &conf->node, &server_items);
+        dlinkDelete(node, &connect_items);
+        dlinkAddTail(conf, &conf->node, &connect_items);
       }
 
       if (find_servconn_in_progress(conf->name))
@@ -349,24 +342,23 @@ int
 check_server(const char *name, struct Client *client_p)
 {
   dlink_node *node = NULL;
-  struct MaskItem *conf        = NULL;
   struct MaskItem *server_conf = NULL;
   int error = -1;
 
   assert(client_p);
 
   /* Loop through looking for all possible connect items that might work */
-  DLINK_FOREACH(node, server_items.head)
+  DLINK_FOREACH(node, connect_items.head)
   {
-    conf = node->data;
+    struct MaskItem *conf = node->data;
 
-    if (match(name, conf->name))
+    if (irccmp(name, conf->name))
       continue;
 
     error = -3;
 
-    if (!match(conf->host, client_p->host) ||
-        !match(conf->host, client_p->sockhost))
+    if (!irccmp(conf->host, client_p->host) ||
+        !irccmp(conf->host, client_p->sockhost))
     {
       error = -2;
 
@@ -409,6 +401,22 @@ check_server(const char *name, struct Client *client_p)
   return 0;
 }
 
+/* server_capab_init()
+ *
+ * inputs       - none
+ * output       - none
+ */
+void
+server_capab_init(void)
+{
+  add_capability("QS", CAPAB_QS);
+  add_capability("EOB", CAPAB_EOB);
+  add_capability("CLUSTER", CAPAB_CLUSTER);
+  add_capability("SVS", CAPAB_SVS);
+  add_capability("CHW", CAPAB_CHW);
+  add_capability("HOPS", CAPAB_HOPS);
+}
+
 /* add_capability()
  *
  * inputs	- string name of CAPAB
@@ -462,7 +470,7 @@ delete_capability(const char *name)
 unsigned int
 find_capability(const char *name)
 {
-  const dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, server_capabilities_list.head)
   {
@@ -475,33 +483,6 @@ find_capability(const char *name)
   return 0;
 }
 
-/* send_capabilities()
- *
- * inputs	- Client pointer to send to
- *		- int flag of capabilities that this server can send
- * output	- NONE
- * side effects	- send the CAPAB line to a server  -orabidoo
- *
- */
-void
-send_capabilities(struct Client *client_p)
-{
-  char buf[IRCD_BUFSIZE] = "";
-  const dlink_node *node = NULL;
-
-  DLINK_FOREACH(node, server_capabilities_list.head)
-  {
-    const struct Capability *cap = node->data;
-
-    strlcat(buf, cap->name, sizeof(buf));
-
-    if (node->next)
-      strlcat(buf, " ", sizeof(buf));
-  }
-
-  sendto_one(client_p, "CAPAB :%s", buf);
-}
-
 /*
  * show_capabilities - show current server capabilities
  *
@@ -510,25 +491,27 @@ send_capabilities(struct Client *client_p)
  * side effects - build up string representing capabilities of server listed
  */
 const char *
-show_capabilities(const struct Client *target_p)
+get_capabilities(const struct Client *client_p)
 {
-  static char msgbuf[IRCD_BUFSIZE] = "";
-  const dlink_node *node = NULL;
+  static char buf[IRCD_BUFSIZE] = "";
+  dlink_node *node;
 
-  strlcpy(msgbuf, "TS", sizeof(msgbuf));
+  buf[0] = '\0';
 
   DLINK_FOREACH(node, server_capabilities_list.head)
   {
     const struct Capability *cap = node->data;
 
-    if (!IsCapable(target_p, cap->cap))
+    if (client_p && !IsCapable(client_p, cap->cap))
       continue;
 
-    strlcat(msgbuf,       " ", sizeof(msgbuf));
-    strlcat(msgbuf, cap->name, sizeof(msgbuf));
+    strlcat(buf, cap->name, sizeof(buf));
+
+    if (node->next)
+      strlcat(buf, " ", sizeof(buf));
   }
 
-  return msgbuf;
+  return buf;
 }
 
 /* make_server()
@@ -758,15 +741,12 @@ serv_connect(struct MaskItem *conf, struct Client *by)
   return 1;
 }
 
-#ifdef HAVE_LIBCRYPTO
 static void
 finish_ssl_server_handshake(struct Client *client_p)
 {
-  struct MaskItem *conf = NULL;
-
-  conf = find_conf_name(&client_p->connection->confs,
-                        client_p->name, CONF_SERVER);
-  if (conf == NULL)
+  const struct MaskItem *conf = find_conf_name(&client_p->connection->confs,
+                                                client_p->name, CONF_SERVER);
+  if (!conf)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Lost connect{} block for %s", get_client_name(client_p, SHOW_IP));
@@ -777,9 +757,9 @@ finish_ssl_server_handshake(struct Client *client_p)
     return;
   }
 
-  sendto_one(client_p, "PASS %s TS %d %s", conf->spasswd, TS_CURRENT, me.id);
+  sendto_one(client_p, "PASS %s TS %u %s", conf->spasswd, TS_CURRENT, me.id);
 
-  send_capabilities(client_p);
+  sendto_one(client_p, "CAPAB :%s", get_capabilities(NULL));
 
   sendto_one(client_p, "SERVER %s 1 :%s%s",
              me.name, ConfigServerHide.hidden ? "(H) " : "",
@@ -807,34 +787,33 @@ static void
 ssl_server_handshake(fde_t *fd, void *data)
 {
   struct Client *client_p = data;
-  X509 *cert = NULL;
-  int ret = 0;
+  const char *sslerr = NULL;
 
-  if ((ret = SSL_connect(client_p->connection->fd.ssl)) <= 0)
+  tls_handshake_status_t ret = tls_handshake(&client_p->connection->fd.ssl, TLS_ROLE_CLIENT, &sslerr);
+  if (ret != TLS_HANDSHAKE_DONE)
   {
     if ((CurrentTime - client_p->connection->firsttime) > CONNECTTIMEOUT)
     {
-      exit_client(client_p, "Timeout during SSL handshake");
+      exit_client(client_p, "Timeout during TLS handshake");
       return;
     }
 
-    switch (SSL_get_error(client_p->connection->fd.ssl, ret))
+    switch (ret)
     {
-      case SSL_ERROR_WANT_WRITE:
+      case TLS_HANDSHAKE_WANT_WRITE:
         comm_setselect(&client_p->connection->fd, COMM_SELECT_WRITE,
                        ssl_server_handshake, client_p, CONNECTTIMEOUT);
         return;
-      case SSL_ERROR_WANT_READ:
+      case TLS_HANDSHAKE_WANT_READ:
         comm_setselect(&client_p->connection->fd, COMM_SELECT_READ,
                        ssl_server_handshake, client_p, CONNECTTIMEOUT);
         return;
       default:
       {
-        const char *sslerr = ERR_error_string(ERR_get_error(), NULL);
         sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                              "Error connecting to %s: %s", client_p->name,
-                             sslerr ? sslerr : "unknown SSL error");
-        exit_client(client_p, "Error during SSL handshake");
+                             sslerr ? sslerr : "unknown TLS error");
+        exit_client(client_p, "Error during TLS handshake");
         return;
       }
     }
@@ -842,29 +821,9 @@ ssl_server_handshake(fde_t *fd, void *data)
 
   comm_settimeout(&client_p->connection->fd, 0, NULL, NULL);
 
-  if ((cert = SSL_get_peer_certificate(client_p->connection->fd.ssl)))
-  {
-    int res = SSL_get_verify_result(client_p->connection->fd.ssl);
-    char buf[EVP_MAX_MD_SIZE * 2 + 1] = "";
-    unsigned char md[EVP_MAX_MD_SIZE] = "";
-
-    if (res == X509_V_OK || res == X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN ||
-        res == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE ||
-        res == X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT)
-    {
-      unsigned int n = 0;
-
-      if (X509_digest(cert, ConfigServerInfo.message_digest_algorithm, md, &n))
-      {
-        binary_to_hex(md, buf, n);
-        client_p->certfp = xstrdup(buf);
-      }
-    }
-    else
-      ilog(LOG_TYPE_IRCD, "Server %s!%s@%s gave bad SSL client certificate: %d",
-           client_p->name, client_p->username, client_p->host, res);
-    X509_free(cert);
-  }
+  if (!tls_verify_cert(&client_p->connection->fd.ssl, ConfigServerInfo.message_digest_algorithm, &client_p->certfp))
+    ilog(LOG_TYPE_IRCD, "Server %s!%s@%s gave bad TLS client certificate",
+         client_p->name, client_p->username, client_p->host);
 
   finish_ssl_server_handshake(client_p);
 }
@@ -872,23 +831,18 @@ ssl_server_handshake(fde_t *fd, void *data)
 static void
 ssl_connect_init(struct Client *client_p, const struct MaskItem *conf, fde_t *fd)
 {
-  if ((client_p->connection->fd.ssl = SSL_new(ConfigServerInfo.client_ctx)) == NULL)
+  if (!tls_new(&client_p->connection->fd.ssl, fd->fd, TLS_ROLE_CLIENT))
   {
-    ilog(LOG_TYPE_IRCD, "SSL_new() ERROR! -- %s",
-         ERR_error_string(ERR_get_error(), NULL));
     SetDead(client_p);
-    exit_client(client_p, "SSL_new failed");
+    exit_client(client_p, "TLS context initialization failed");
     return;
   }
 
-  SSL_set_fd(fd->ssl, fd->fd);
-
   if (!EmptyString(conf->cipher_list))
-    SSL_set_cipher_list(client_p->connection->fd.ssl, conf->cipher_list);
+    tls_set_ciphers(&client_p->connection->fd.ssl, conf->cipher_list);
 
   ssl_server_handshake(NULL, client_p);
 }
-#endif
 
 /* serv_connect_callback() - complete a server connection.
  *
@@ -902,15 +856,13 @@ static void
 serv_connect_callback(fde_t *fd, int status, void *data)
 {
   struct Client *const client_p = data;
-  const struct MaskItem *conf = NULL;
 
   /* First, make sure it's a real client! */
   assert(client_p);
   assert(&client_p->connection->fd == fd);
 
   /* Next, for backward purposes, record the ip of the server */
-  memcpy(&client_p->connection->ip, &fd->connect.hostaddr,
-         sizeof(struct irc_ssaddr));
+  memcpy(&client_p->connection->ip, &fd->connect.hostaddr, sizeof(struct irc_ssaddr));
 
   /* Check the status */
   if (status != COMM_OK)
@@ -932,10 +884,10 @@ serv_connect_callback(fde_t *fd, int status, void *data)
   }
 
   /* COMM_OK, so continue the connection procedure */
-  /* Get the C/N lines */
-  conf = find_conf_name(&client_p->connection->confs,
-                        client_p->name, CONF_SERVER);
-  if (conf == NULL)
+  /* Get the connect {} block */
+  const struct MaskItem *conf = find_conf_name(&client_p->connection->confs,
+                                                client_p->name, CONF_SERVER);
+  if (!conf)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Lost connect{} block for %s", get_client_name(client_p, SHOW_IP));
@@ -949,17 +901,15 @@ serv_connect_callback(fde_t *fd, int status, void *data)
   /* Next, send the initial handshake */
   SetHandshake(client_p);
 
-#ifdef HAVE_LIBCRYPTO
   if (IsConfSSL(conf))
   {
     ssl_connect_init(client_p, conf, fd);
     return;
   }
-#endif
 
-  sendto_one(client_p, "PASS %s TS %d %s", conf->spasswd, TS_CURRENT, me.id);
+  sendto_one(client_p, "PASS %s TS %u %s", conf->spasswd, TS_CURRENT, me.id);
 
-  send_capabilities(client_p);
+  sendto_one(client_p, "CAPAB :%s", get_capabilities(NULL));
 
   sendto_one(client_p, "SERVER %s 1 :%s%s", me.name,
              ConfigServerHide.hidden ? "(H) " : "", me.info);
@@ -986,14 +936,13 @@ struct Client *
 find_servconn_in_progress(const char *name)
 {
   dlink_node *ptr;
-  struct Client *cptr;
 
   DLINK_FOREACH(ptr, unknown_list.head)
   {
-    cptr = ptr->data;
+    struct Client *cptr = ptr->data;
 
-    if (cptr && cptr->name[0])
-      if (!match(name, cptr->name))
+    if (cptr->name[0])
+      if (!irccmp(name, cptr->name))
         return cptr;
   }
 
