@@ -23,7 +23,7 @@
 
 /*! \file tls_gnutls.c
  * \brief Includes all GnuTLS-specific TLS functions
- * \version $Id: tls_gnutls.c 7273 2016-02-06 20:55:20Z michael $
+ * \version $Id: tls_gnutls.c 7707 2016-09-23 16:45:18Z michael $
  */
 
 #include "stdinc.h"
@@ -158,6 +158,16 @@ tls_get_cipher(const tls_data_t *tls_data)
   return buffer;
 }
 
+const char *
+tls_get_version(void)
+{
+  static char buf[IRCD_BUFSIZE];
+
+  snprintf(buf, sizeof(buf), "GnuTLS version: library: %s, header: %s",
+           gnutls_check_version(NULL), GNUTLS_VERSION);
+  return buf;
+}
+
 int
 tls_isusing(tls_data_t *tls_data)
 {
