@@ -21,7 +21,7 @@
 
 /*! \file user.c
  * \brief User related functions.
- * \version $Id: user.c 7303 2016-02-10 10:34:25Z michael $
+ * \version $Id: user.c 7770 2016-10-08 16:30:18Z michael $
  */
 
 #include "stdinc.h"
@@ -109,39 +109,39 @@ user_modes_init(void)
  * side effects - display to client user counts etc.
  */
 void
-show_lusers(struct Client *source_p)
+show_lusers(struct Client *client_p)
 {
-  if (!ConfigServerHide.hide_servers || HasUMode(source_p, UMODE_OPER))
-    sendto_one_numeric(source_p, &me, RPL_LUSERCLIENT, (Count.total - Count.invisi),
+  if (!ConfigServerHide.hide_servers || HasUMode(client_p, UMODE_OPER))
+    sendto_one_numeric(client_p, &me, RPL_LUSERCLIENT, (Count.total - Count.invisi),
                        Count.invisi, dlink_list_length(&global_server_list));
   else
-    sendto_one_numeric(source_p, &me, RPL_LUSERCLIENT, (Count.total - Count.invisi),
+    sendto_one_numeric(client_p, &me, RPL_LUSERCLIENT, (Count.total - Count.invisi),
                        Count.invisi, 1);
 
   if (Count.oper)
-    sendto_one_numeric(source_p, &me, RPL_LUSEROP, Count.oper);
+    sendto_one_numeric(client_p, &me, RPL_LUSEROP, Count.oper);
 
   if (dlink_list_length(&unknown_list))
-    sendto_one_numeric(source_p, &me, RPL_LUSERUNKNOWN, dlink_list_length(&unknown_list));
+    sendto_one_numeric(client_p, &me, RPL_LUSERUNKNOWN, dlink_list_length(&unknown_list));
 
   if (dlink_list_length(&channel_list))
-    sendto_one_numeric(source_p, &me, RPL_LUSERCHANNELS, dlink_list_length(&channel_list));
+    sendto_one_numeric(client_p, &me, RPL_LUSERCHANNELS, dlink_list_length(&channel_list));
 
-  if (!ConfigServerHide.hide_servers || HasUMode(source_p, UMODE_OPER))
+  if (!ConfigServerHide.hide_servers || HasUMode(client_p, UMODE_OPER))
   {
-    sendto_one_numeric(source_p, &me, RPL_LUSERME, Count.local, Count.myserver);
-    sendto_one_numeric(source_p, &me, RPL_LOCALUSERS, Count.local, Count.max_loc);
+    sendto_one_numeric(client_p, &me, RPL_LUSERME, Count.local, Count.myserver);
+    sendto_one_numeric(client_p, &me, RPL_LOCALUSERS, Count.local, Count.max_loc);
   }
   else
   {
-    sendto_one_numeric(source_p, &me, RPL_LUSERME, Count.total, 0);
-    sendto_one_numeric(source_p, &me, RPL_LOCALUSERS, Count.total, Count.max_tot);
+    sendto_one_numeric(client_p, &me, RPL_LUSERME, Count.total, 0);
+    sendto_one_numeric(client_p, &me, RPL_LOCALUSERS, Count.total, Count.max_tot);
   }
 
-  sendto_one_numeric(source_p, &me, RPL_GLOBALUSERS, Count.total, Count.max_tot);
+  sendto_one_numeric(client_p, &me, RPL_GLOBALUSERS, Count.total, Count.max_tot);
 
-  if (!ConfigServerHide.hide_servers || HasUMode(source_p, UMODE_OPER))
-    sendto_one_numeric(source_p, &me, RPL_STATSCONN, Count.max_loc_con,
+  if (!ConfigServerHide.hide_servers || HasUMode(client_p, UMODE_OPER))
+    sendto_one_numeric(client_p, &me, RPL_STATSCONN, Count.max_loc_con,
                        Count.max_loc_cli, Count.totalrestartcount);
 
   if (Count.local > Count.max_loc_cli)
@@ -153,72 +153,68 @@ show_lusers(struct Client *source_p)
 
 /* report_and_set_user_flags()
  *
- * inputs       - pointer to source_p
+ * inputs       - pointer to client_p
  *              - pointer to conf for this user
  * output       - NONE
  * side effects - Report to user any special flags
  *                they are getting, and set them.
  */
 static void
-report_and_set_user_flags(struct Client *source_p, const struct MaskItem *conf)
+report_and_set_user_flags(struct Client *client_p, const struct MaskItem *conf)
 {
   /* If this user is being spoofed, tell them so */
   if (IsConfDoSpoofIp(conf))
-    sendto_one_notice(source_p, &me, ":*** Spoofing your IP");
+    sendto_one_notice(client_p, &me, ":*** Spoofing your IP");
 
   /* If this user is in the exception class, set it "E lined" */
   if (IsConfExemptKline(conf))
   {
-    AddFlag(source_p, FLAGS_EXEMPTKLINE);
-    sendto_one_notice(source_p, &me, ":*** You are exempt from K/D lines");
+    AddFlag(client_p, FLAGS_EXEMPTKLINE);
+    sendto_one_notice(client_p, &me, ":*** You are exempt from K/D lines");
   }
 
   if (IsConfExemptXline(conf))
   {
-    AddFlag(source_p, FLAGS_EXEMPTXLINE);
-    sendto_one_notice(source_p, &me, ":*** You are exempt from X lines");
+    AddFlag(client_p, FLAGS_EXEMPTXLINE);
+    sendto_one_notice(client_p, &me, ":*** You are exempt from X lines");
   }
 
   if (IsConfExemptResv(conf))
   {
-    AddFlag(source_p, FLAGS_EXEMPTRESV);
-    sendto_one_notice(source_p, &me, ":*** You are exempt from resvs");
+    AddFlag(client_p, FLAGS_EXEMPTRESV);
+    sendto_one_notice(client_p, &me, ":*** You are exempt from resvs");
   }
 
   /* If this user is exempt from user limits set it "F lined" */
   if (IsConfExemptLimits(conf))
   {
-    AddFlag(source_p, FLAGS_NOLIMIT);
-    sendto_one_notice(source_p, &me, ":*** You are exempt from user limits");
+    AddFlag(client_p, FLAGS_NOLIMIT);
+    sendto_one_notice(client_p, &me, ":*** You are exempt from user limits");
   }
 
   if (IsConfCanFlood(conf))
   {
-    AddFlag(source_p, FLAGS_CANFLOOD);
-    sendto_one_notice(source_p, &me, ":*** You are exempt from flood protection");
+    AddFlag(client_p, FLAGS_CANFLOOD);
+    sendto_one_notice(client_p, &me, ":*** You are exempt from flood protection");
   }
 }
 
 /* introduce_client()
  *
- * inputs       - source_p
+ * inputs       - client_p
  * output       - NONE
  * side effects - This common function introduces a client to the rest
  *                of the net, either from a local client connect or
  *                from a remote connect.
  */
 static void
-introduce_client(struct Client *source_p)
+introduce_client(struct Client *client_p)
 {
   dlink_node *node = NULL;
   char ubuf[IRCD_BUFSIZE] = "";
 
-  if (MyConnect(source_p))
-    send_umode(source_p, source_p, 0, ubuf);
-  else
-    send_umode(NULL, source_p, 0, ubuf);
-
-  watch_check_hash(source_p, RPL_LOGON);
+  send_umode(client_p, MyConnect(client_p), 0, ubuf);
+  watch_check_hash(client_p, RPL_LOGON);
 
   if (ubuf[0] == '\0')
   {
@@ -228,22 +224,22 @@ introduce_client(struct Client *source_p)
 
   DLINK_FOREACH(node, local_server_list.head)
   {
-    struct Client *server = node->data;
+    struct Client *server_p = node->data;
 
-    if (server == source_p->from)
+    if (server_p == client_p->from)
       continue;
 
-    sendto_one(server, ":%s UID %s %u %ju %s %s %s %s %s %s :%s",
-               source_p->servptr->id,
-               source_p->name, source_p->hopcount+1,
-               source_p->tsinfo,
-               ubuf, source_p->username, source_p->host,
-               source_p->sockhost, source_p->id,
-               source_p->account,
-               source_p->info);
+    sendto_one(server_p, ":%s UID %s %u %ju %s %s %s %s %s %s :%s",
+               client_p->servptr->id,
+               client_p->name, client_p->hopcount+1,
+               client_p->tsinfo,
+               ubuf, client_p->username, client_p->host,
+               client_p->sockhost, client_p->id,
+               client_p->account,
+               client_p->info);
 
-    if (!EmptyString(source_p->certfp))
-      sendto_one(server, ":%s CERTFP %s", source_p->id, source_p->certfp);
+    if (!EmptyString(client_p->certfp))
+      sendto_one(server_p, ":%s CERTFP %s", client_p->id, client_p->certfp);
   }
 }
 
@@ -254,27 +250,27 @@ introduce_client(struct Client *source_p)
  * side effects -
  */
 static void
-user_welcome(struct Client *source_p)
+user_welcome(struct Client *client_p)
 {
   static const char built_date[] = __DATE__ " at " __TIME__;
 
-  if (HasFlag(source_p, FLAGS_SSL))
+  if (HasFlag(client_p, FLAGS_SSL))
   {
-    AddUMode(source_p, UMODE_SSL);
-    sendto_one_notice(source_p, &me, ":*** Connected securely via %s",
-                      tls_get_cipher(&source_p->connection->fd.ssl));
+    AddUMode(client_p, UMODE_SSL);
+    sendto_one_notice(client_p, &me, ":*** Connected securely via %s",
+                      tls_get_cipher(&client_p->connection->fd.ssl));
   }
 
-  sendto_one_numeric(source_p, &me, RPL_WELCOME, ConfigServerInfo.network_name,
-                     source_p->name);
-  sendto_one_numeric(source_p, &me, RPL_YOURHOST,
-                     listener_get_name(source_p->connection->listener), ircd_version);
-  sendto_one_numeric(source_p, &me, RPL_CREATED, built_date);
-  sendto_one_numeric(source_p, &me, RPL_MYINFO, me.name, ircd_version, umode_buffer);
+  sendto_one_numeric(client_p, &me, RPL_WELCOME, ConfigServerInfo.network_name,
+                     client_p->name);
+  sendto_one_numeric(client_p, &me, RPL_YOURHOST,
+                     listener_get_name(client_p->connection->listener), ircd_version);
+  sendto_one_numeric(client_p, &me, RPL_CREATED, built_date);
+  sendto_one_numeric(client_p, &me, RPL_MYINFO, me.name, ircd_version, umode_buffer);
 
-  isupport_show(source_p);
-  show_lusers(source_p);
-  motd_signon(source_p);
+  isupport_show(client_p);
+  show_lusers(client_p);
+  motd_signon(client_p);
 }
 
 /* check_xline()
@@ -284,23 +280,23 @@ user_welcome(struct Client *source_p)
  * side effects -
  */
 static int
-check_xline(struct Client *source_p)
+check_xline(struct Client *client_p)
 {
   const struct GecosItem *gecos = NULL;
 
-  if (HasFlag(source_p, FLAGS_EXEMPTXLINE))
+  if (HasFlag(client_p, FLAGS_EXEMPTXLINE))
     return 0;
 
-  if ((gecos = gecos_find(source_p->info, match)))
+  if ((gecos = gecos_find(client_p->info, match)))
   {
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "X-line Rejecting [%s] [%s], user %s [%s]",
-                         source_p->info, gecos->reason,
-                         get_client_name(source_p, HIDE_IP),
-                         source_p->sockhost);
+                         client_p->info, gecos->reason,
+                         get_client_name(client_p, HIDE_IP),
+                         client_p->sockhost);
 
     ++ServerStats.is_ref;
-    exit_client(source_p, "Bad user info");
+    exit_client(client_p, "Bad user info");
     return 1;
   }
 
@@ -310,53 +306,52 @@ check_xline(struct Client *source_p)
 /*! \brief This function is called when both NICK and USER messages
  *      have been accepted for the client, in whatever order. Only
  *      after this, is the UID message propagated.
- * \param source_p Pointer to given client to introduce
+ * \param client_p Pointer to given client to introduce
  */
 void
-register_local_user(struct Client *source_p)
+register_local_user(struct Client *client_p)
 {
-  const char *id = NULL;
   const struct MaskItem *conf = NULL;
 
-  assert(source_p == source_p->from);
-  assert(MyConnect(source_p));
-  assert(IsUnknown(source_p));
-  assert(!source_p->connection->registration);
+  assert(client_p == client_p->from);
+  assert(MyConnect(client_p));
+  assert(IsUnknown(client_p));
+  assert(!client_p->connection->registration);
 
   if (ConfigGeneral.ping_cookie)
   {
-    if (!HasFlag(source_p, FLAGS_PINGSENT) && !source_p->connection->random_ping)
+    if (!HasFlag(client_p, FLAGS_PINGSENT) && !client_p->connection->random_ping)
     {
       do
-        source_p->connection->random_ping = genrand_int32();
-      while (!source_p->connection->random_ping);
+        client_p->connection->random_ping = genrand_int32();
+      while (!client_p->connection->random_ping);
 
-      sendto_one(source_p, "PING :%u", source_p->connection->random_ping);
-      AddFlag(source_p, FLAGS_PINGSENT);
+      sendto_one(client_p, "PING :%u", client_p->connection->random_ping);
+      AddFlag(client_p, FLAGS_PINGSENT);
       return;
     }
 
-    if (!HasFlag(source_p, FLAGS_PING_COOKIE))
+    if (!HasFlag(client_p, FLAGS_PING_COOKIE))
       return;
   }
 
-  source_p->connection->last_privmsg = CurrentTime;
+  client_p->connection->last_privmsg = CurrentTime;
   /* Straight up the maximum rate of flooding... */
-  source_p->connection->allow_read = MAX_FLOOD_BURST;
+  client_p->connection->allow_read = MAX_FLOOD_BURST;
 
-  if (!check_client(source_p))
+  if (!check_client(client_p))
     return;
 
-  if (!valid_hostname(source_p->host))
+  if (!valid_hostname(client_p->host))
   {
-    sendto_one_notice(source_p, &me, ":*** Notice -- You have an illegal "
+    sendto_one_notice(client_p, &me, ":*** Notice -- You have an illegal "
                       "character in your hostname");
-    strlcpy(source_p->host, source_p->sockhost, sizeof(source_p->host));
+    strlcpy(client_p->host, client_p->sockhost, sizeof(client_p->host));
   }
 
-  conf = source_p->connection->confs.head->data;
+  conf = client_p->connection->confs.head->data;
 
-  if (!HasFlag(source_p, FLAGS_GOTID))
+  if (!HasFlag(client_p, FLAGS_GOTID))
   {
     char username[USERLEN + 1] = "";
     unsigned int i = 0;
@@ -364,48 +359,48 @@ register_local_user(struct Client *source_p)
     if (IsNeedIdentd(conf))
     {
       ++ServerStats.is_ref;
-      sendto_one_notice(source_p, &me, ":*** Notice -- You need to install "
+      sendto_one_notice(client_p, &me, ":*** Notice -- You need to install "
                         "identd to use this server");
-      exit_client(source_p, "Install identd");
+      exit_client(client_p, "Install identd");
       return;
     }
 
-    strlcpy(username, source_p->username, sizeof(username));
+    strlcpy(username, client_p->username, sizeof(username));
 
     if (!IsNoTilde(conf))
-      source_p->username[i++] = '~';
+      client_p->username[i++] = '~';
 
     for (const char *p = username; *p && i < USERLEN; ++p)
-      source_p->username[i++] = *p;
+      client_p->username[i++] = *p;
 
-    source_p->username[i] = '\0';
+    client_p->username[i] = '\0';
   }
 
   /* Password check */
   if (!EmptyString(conf->passwd))
   {
-    if (!match_conf_password(source_p->connection->password, conf))
+    if (!match_conf_password(client_p->connection->password, conf))
     {
       ++ServerStats.is_ref;
 
-      sendto_one_numeric(source_p, &me, ERR_PASSWDMISMATCH);
-      exit_client(source_p, "Bad Password");
+      sendto_one_numeric(client_p, &me, ERR_PASSWDMISMATCH);
+      exit_client(client_p, "Bad Password");
       return;
     }
   }
 
   /*
-   * Don't free source_p->connection->password here - it can be required
+   * Don't free client_p->connection->password here - it can be required
    * by masked /stats I if there are auth {} blocks with need_password = no;
    * --adx
    */
 
   /*
-   * Report if user has &^>= etc. and set flags as needed in source_p
+   * Report if user has &^>= etc. and set flags as needed in client_p
    */
-  report_and_set_user_flags(source_p, conf);
+  report_and_set_user_flags(client_p, conf);
 
-  if (IsDead(source_p))
+  if (IsDead(client_p))
     return;
 
   /*
@@ -417,48 +412,49 @@ register_local_user(struct Client *source_p)
    *   -Taner
    */
   if ((Count.local >= GlobalSetOptions.maxclients + MAX_BUFFER) ||
-      (Count.local >= GlobalSetOptions.maxclients && !HasFlag(source_p, FLAGS_NOLIMIT)))
+      (Count.local >= GlobalSetOptions.maxclients && !HasFlag(client_p, FLAGS_NOLIMIT)))
   {
     sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
                          "Too many clients, rejecting %s[%s].",
-                         source_p->name, source_p->host);
+                         client_p->name, client_p->host);
     ++ServerStats.is_ref;
-    exit_client(source_p, "Sorry, server is full - try later");
+    exit_client(client_p, "Sorry, server is full - try later");
     return;
   }
 
-  if (!valid_username(source_p->username, 1))
+  if (!valid_username(client_p->username, 1))
   {
     char buf[IRCD_BUFSIZE] = "";
 
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "Invalid username: %s (%s@%s)",
-                         source_p->name, source_p->username, source_p->host);
+                         client_p->name, client_p->username, client_p->host);
     ++ServerStats.is_ref;
-    snprintf(buf, sizeof(buf), "Invalid username [%s]", source_p->username);
-    exit_client(source_p, buf);
+    snprintf(buf, sizeof(buf), "Invalid username [%s]", client_p->username);
+    exit_client(client_p, buf);
     return;
   }
 
-  if (check_xline(source_p))
+  if (check_xline(client_p))
     return;
 
+  const char *id;
   while (hash_find_id((id = uid_get())))
     ;
 
-  strlcpy(source_p->id, id, sizeof(source_p->id));
-  hash_add_id(source_p);
+  strlcpy(client_p->id, id, sizeof(client_p->id));
+  hash_add_id(client_p);
 
   sendto_realops_flags(UMODE_CCONN, L_ALL, SEND_NOTICE,
                        "Client connecting: %s (%s@%s) [%s] {%s} [%s] <%s>",
-                       source_p->name, source_p->username, source_p->host,
-                       source_p->sockhost,
-                       get_client_class(&source_p->connection->confs),
-                       source_p->info, source_p->id);
+                       client_p->name, client_p->username, client_p->host,
+                       client_p->sockhost,
+                       get_client_class(&client_p->connection->confs),
+                       client_p->info, client_p->id);
 
   if (ConfigGeneral.invisible_on_connect)
   {
-    AddUMode(source_p, UMODE_INVISIBLE);
+    AddUMode(client_p, UMODE_INVISIBLE);
     ++Count.invisi;
   }
 
@@ -476,26 +472,26 @@ register_local_user(struct Client *source_p)
     Count.max_tot = Count.total;
   ++Count.totalrestartcount;
 
-  assert(source_p->servptr == &me);
-  SetClient(source_p);
-  dlinkAdd(source_p, &source_p->lnode, &source_p->servptr->serv->client_list);
-  dlinkAdd(source_p, &source_p->node, &global_client_list);
+  assert(client_p->servptr == &me);
+  SetClient(client_p);
+  dlinkAdd(client_p, &client_p->lnode, &client_p->servptr->serv->client_list);
+  dlinkAdd(client_p, &client_p->node, &global_client_list);
 
-  assert(dlinkFind(&unknown_list, source_p));
+  assert(dlinkFind(&unknown_list, client_p));
 
-  dlink_move_node(&source_p->connection->lclient_node,
+  dlink_move_node(&client_p->connection->lclient_node,
                   &unknown_list, &local_client_list);
 
-  user_welcome(source_p);
-  userhost_add(source_p->username, source_p->host, 0);
-  AddFlag(source_p, FLAGS_USERHOST);
+  user_welcome(client_p);
+  userhost_add(client_p->sockhost, 0);
+  AddFlag(client_p, FLAGS_USERHOST);
 
-  introduce_client(source_p);
+  introduce_client(client_p);
 }
 
 /* register_remote_user()
  *
- * inputs       - source_p remote or directly connected client
+ * inputs       - client_p remote or directly connected client
  *              - username to register as
  *              - host name to register as
  *              - server name
@@ -504,51 +500,34 @@ register_local_user(struct Client *source_p)
  *		  is introduced by a server.
  */
 void
-register_remote_user(struct Client *source_p)
+register_remote_user(struct Client *client_p)
 {
-  const struct Client *target_p = NULL;
-
-  if ((target_p = source_p->servptr) && target_p->from != source_p->from)
-  {
-    sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
-                         "Bad User [%s] :%s USER %s@%s %s, != %s[%s]",
-                         source_p->from->name, source_p->name, source_p->username,
-                         source_p->host, source_p->servptr->name,
-                         target_p->name, target_p->from->name);
-    sendto_one(source_p->from,
-               ":%s KILL %s :%s (UID from wrong direction (%s != %s))",
-               me.id, source_p->id, me.name, source_p->servptr->name,
-               target_p->from->name);
-
-    AddFlag(source_p, FLAGS_KILLED);
-    exit_client(source_p, "UID server wrong direction");
-    return;
-  }
+  assert(client_p->servptr->from == client_p->from);
 
   /*
    * If the nick has been introduced by a services server,
    * make it a service as well.
    */
-  if (HasFlag(source_p->servptr, FLAGS_SERVICE))
-    AddFlag(source_p, FLAGS_SERVICE);
+  if (HasFlag(client_p->servptr, FLAGS_SERVICE))
+    AddFlag(client_p, FLAGS_SERVICE);
 
   if (++Count.total > Count.max_tot)
     Count.max_tot = Count.total;
 
-  SetClient(source_p);
-  dlinkAdd(source_p, &source_p->lnode, &source_p->servptr->serv->client_list);
-  dlinkAdd(source_p, &source_p->node, &global_client_list);
-  userhost_add(source_p->username, source_p->host, 1);
-  AddFlag(source_p, FLAGS_USERHOST);
+  SetClient(client_p);
+  dlinkAdd(client_p, &client_p->lnode, &client_p->servptr->serv->client_list);
+  dlinkAdd(client_p, &client_p->node, &global_client_list);
+  userhost_add(client_p->sockhost, 1);
+  AddFlag(client_p, FLAGS_USERHOST);
 
-  if (HasFlag(source_p->servptr, FLAGS_EOB))
+  if (HasFlag(client_p->servptr, FLAGS_EOB))
     sendto_realops_flags(UMODE_FARCONNECT, L_ALL, SEND_NOTICE,
                          "Client connecting at %s: %s (%s@%s) [%s] [%s] <%s>",
-                         source_p->servptr->name,
-                         source_p->name, source_p->username, source_p->host,
-                         source_p->sockhost, source_p->info, source_p->id);
+                         client_p->servptr->name,
+                         client_p->name, client_p->username, client_p->host,
+                         client_p->sockhost, client_p->info, client_p->id);
 
-  introduce_client(source_p);
+  introduce_client(client_p);
 }
 
 /* valid_hostname()
@@ -660,30 +639,26 @@ valid_nickname(const char *nickname, const int local)
   return p - nickname <= NICKLEN;
 }
 
-/* send_umode()
- * send the MODE string for user (user) to connection client_p
- * -avalon
- *
- * inputs	- client_p
- *		- source_p
- *		- int old
- * 		- suplied umode_buf
- * output	- NONE
+/*! \brief Builds a mode change string to buffer pointed by \a buf
+ * \param client_p  Pointer to client
+ * \param dispatch  Whether to send a MODE message to client_p
+ * \param old       Old user mode to compare against when building new mode buffer
+ * \param buf       Pointer to buffer to build string in
  */
 void
-send_umode(struct Client *client_p, struct Client *source_p,
-           unsigned int old, char *umode_buf)
+send_umode(struct Client *client_p, unsigned int dispatch,
+           unsigned int old, char *buf)
 {
-  char *m = umode_buf;
+  char *m = buf;
   int what = 0;
 
   /*
    * Build a string in umode_buf to represent the change in the user's
-   * mode between the new (source_p->umodes) and 'old'.
+   * mode between the new (client_p->umodes) and 'old'.
    */
   for (const struct user_modes *tab = umode_tab; tab->c; ++tab)
   {
-    if ((tab->flag & old) && !HasUMode(source_p, tab->flag))
+    if ((tab->flag & old) && !HasUMode(client_p, tab->flag))
     {
       if (what == MODE_DEL)
         *m++ = tab->c;
@@ -694,7 +669,7 @@ send_umode(struct Client *client_p, struct Client *source_p,
         *m++ = tab->c;
       }
     }
-    else if (!(tab->flag & old) && HasUMode(source_p, tab->flag))
+    else if (!(tab->flag & old) && HasUMode(client_p, tab->flag))
     {
       if (what == MODE_ADD)
         *m++ = tab->c;
@@ -709,10 +684,10 @@ send_umode(struct Client *client_p, struct Client *source_p,
 
   *m = '\0';
 
-  if (*umode_buf && client_p)
+  if (dispatch && *buf)
     sendto_one(client_p, ":%s!%s@%s MODE %s :%s",
                client_p->name, client_p->username,
-               client_p->host, client_p->name, umode_buf);
+               client_p->host, client_p->name, buf);
 }
 
 /* send_umode_out()
@@ -722,62 +697,56 @@ send_umode(struct Client *client_p, struct Client *source_p,
  * side effects - Only send ubuf out to servers that know about this client
  */
 void
-send_umode_out(struct Client *source_p, unsigned int old)
+send_umode_out(struct Client *client_p, unsigned int old)
 {
   char buf[IRCD_BUFSIZE] = "";
 
-  send_umode(MyClient(source_p) ? source_p : NULL, source_p, old, buf);
+  send_umode(client_p, MyConnect(client_p), old, buf);
 
   if (buf[0])
-    sendto_server(source_p, 0, 0, ":%s MODE %s :%s",
-                  source_p->id, source_p->id, buf);
+    sendto_server(client_p, 0, 0, ":%s MODE %s :%s",
+                  client_p->id, client_p->id, buf);
 }
 
 void
-user_set_hostmask(struct Client *target_p, const char *hostname, const int what)
+user_set_hostmask(struct Client *client_p, const char *hostname, const int what)
 {
   dlink_node *node = NULL;
 
-  if (!strcmp(target_p->host, hostname))
+  if (!strcmp(client_p->host, hostname))
     return;
 
   switch (what)
   {
     case MODE_ADD:
-      AddUMode(target_p, UMODE_HIDDENHOST);
+      AddUMode(client_p, UMODE_HIDDENHOST);
       break;
     case MODE_DEL:
-      DelUMode(target_p, UMODE_HIDDENHOST);
+      DelUMode(client_p, UMODE_HIDDENHOST);
       break;
     default: return;
   }
 
   if (ConfigGeneral.cycle_on_host_change)
-    sendto_common_channels_local(target_p, 0, 0, CAP_CHGHOST, ":%s!%s@%s QUIT :Changing hostname",
-                                 target_p->name, target_p->username, target_p->host);
+    sendto_common_channels_local(client_p, 0, 0, CAP_CHGHOST, ":%s!%s@%s QUIT :Changing hostname",
+                                 client_p->name, client_p->username, client_p->host);
 
-  sendto_common_channels_local(target_p, 0, CAP_CHGHOST, 0, ":%s!%s@%s CHGHOST %s %s",
-                               target_p->name, target_p->username,
-                               target_p->host, target_p->username, hostname);
+  sendto_common_channels_local(client_p, 0, CAP_CHGHOST, 0, ":%s!%s@%s CHGHOST %s %s",
+                               client_p->name, client_p->username,
+                               client_p->host, client_p->username, hostname);
 
-  if (HasFlag(target_p, FLAGS_USERHOST))
-    userhost_del(target_p->username, target_p->host, !MyConnect(target_p));
+  strlcpy(client_p->host, hostname, sizeof(client_p->host));
 
-  strlcpy(target_p->host, hostname, sizeof(target_p->host));
-
-  userhost_add(target_p->username, target_p->host, !MyConnect(target_p));
-  AddFlag(target_p, FLAGS_USERHOST);
-
-  if (MyConnect(target_p))
+  if (MyConnect(client_p))
   {
-    sendto_one_numeric(target_p, &me, RPL_VISIBLEHOST, target_p->host);
-    clear_ban_cache_client(target_p);
+    sendto_one_numeric(client_p, &me, RPL_VISIBLEHOST, client_p->host);
+    clear_ban_cache_list(&client_p->channel);
   }
 
   if (!ConfigGeneral.cycle_on_host_change)
     return;
 
-  DLINK_FOREACH(node, target_p->channel.head)
+  DLINK_FOREACH(node, client_p->channel.head)
   {
     char modebuf[CMEMBER_STATUS_FLAGS_LEN + 1];
     char nickbuf[CMEMBER_STATUS_FLAGS_LEN * NICKLEN + CMEMBER_STATUS_FLAGS_LEN] = "";
@@ -788,40 +757,40 @@ user_set_hostmask(struct Client *target_p, const char *hostname, const int what)
     if (has_member_flags(member, CHFL_CHANOP))
     {
       *p++ = 'o';
-      len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", target_p->name);
+      len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", client_p->name);
     }
 
     if (has_member_flags(member, CHFL_HALFOP))
     {
       *p++ = 'h';
-      len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", target_p->name);
+      len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", client_p->name);
     }
 
     if (has_member_flags(member, CHFL_VOICE))
     {
       *p++ = 'v';
-      len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", target_p->name);
+      len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", client_p->name);
     }
 
     *p = '\0';
 
-    sendto_channel_local(target_p, member->chptr, 0, CAP_EXTENDED_JOIN, CAP_CHGHOST, ":%s!%s@%s JOIN %s %s :%s",
-                         target_p->name, target_p->username,
-                         target_p->host, member->chptr->name,
-                         target_p->account, target_p->info);
-    sendto_channel_local(target_p, member->chptr, 0, 0, CAP_EXTENDED_JOIN | CAP_CHGHOST, ":%s!%s@%s JOIN :%s",
-                         target_p->name, target_p->username,
-                         target_p->host, member->chptr->name);
+    sendto_channel_local(client_p, member->chptr, 0, CAP_EXTENDED_JOIN, CAP_CHGHOST, ":%s!%s@%s JOIN %s %s :%s",
+                         client_p->name, client_p->username,
+                         client_p->host, member->chptr->name,
+                         client_p->account, client_p->info);
+    sendto_channel_local(client_p, member->chptr, 0, 0, CAP_EXTENDED_JOIN | CAP_CHGHOST, ":%s!%s@%s JOIN :%s",
+                         client_p->name, client_p->username,
+                         client_p->host, member->chptr->name);
 
     if (nickbuf[0])
-      sendto_channel_local(target_p, member->chptr, 0, 0, CAP_CHGHOST, ":%s MODE %s +%s %s",
-                           target_p->servptr->name, member->chptr->name,
+      sendto_channel_local(client_p, member->chptr, 0, 0, CAP_CHGHOST, ":%s MODE %s +%s %s",
+                           client_p->servptr->name, member->chptr->name,
                            modebuf, nickbuf);
   }
 
-  if (target_p->away[0])
-    sendto_common_channels_local(target_p, 0, CAP_AWAY_NOTIFY, CAP_CHGHOST,
+  if (client_p->away[0])
+    sendto_common_channels_local(client_p, 0, CAP_AWAY_NOTIFY, CAP_CHGHOST,
                                  ":%s!%s@%s AWAY :%s",
-                                 target_p->name, target_p->username,
-                                 target_p->host, target_p->away);
+                                 client_p->name, client_p->username,
+                                 client_p->host, client_p->away);
 }
