@@ -21,7 +21,7 @@
 
 /*! \file version.c
  * \brief Includes license and version information shown in /info.
- * \version $Id: version.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: version.c 7699 2016-09-04 15:46:47Z michael $
  */
 
 #include "patchlevel.h"
@@ -50,22 +50,19 @@ const char *infotext[] =
   "of people, all of us.",
   "",
   "Anyone is welcome to contribute to this effort. You are encouraged",
-  "to participate in the Hybrid mailing list. To subscribe to the",
-  "Hybrid List, use this link:",
+  "to participate in the ircd-hybrid mailing list. To subscribe to the",
+  "ircd-hybrid list, use this link:",
   "  https://lists.ircd-hybrid.org/mailman/listinfo/hybrid",
   "",
   "The core team as of this major release:",
   "",
-  "billy-jon, William Bierman III <bill@mu.org>",
-  "cryogen, Stuart Walsh <stu@ipng.org.uk>",
   "Dianora, Diane Bruce <db@db.net>",
-  "metalrock, Jack Low <jclow@csupomona.edu>",
   "Michael, Michael Wobst <michael@ircd-hybrid.de>",
   "Rodder, Jon Lusky <lusky@blown.net>",
   "Wohali, Joan Touzet <joant@ieee.org>",
   "",
   "The following people have contributed blood, sweat, and/or code to",
-  "recent releases of Hybrid, in nick alphabetical order:",
+  "recent releases of ircd-hybrid, in nick alphabetical order:",
   "",
   "A1kmm, Andrew Miller <a1kmm@mware.virtualave.net>",
   "Adam, Adam <Adam@anope.org>",
@@ -73,8 +70,10 @@ const char *infotext[] =
   "adx, Piotr Nizynski <nizynski@sysplex.pl>",
   "AndroSyn, Aaron Sethman <androsyn@ratbox.org>",
   "bane, Dragan Dosen <bane@idolnet.org>",
+  "billy-jon, William Bierman III <bill@thebiermans.org>",
   "bysin, Ben Kittridge <bkittridge@cfl.rr.com>",
   "cosine, Patrick Alken <wnder@uwns.underworld.net>",
+  "cryogen, Stuart Walsh <stu@ipng.org.uk>",
   "David-T, David Taylor <davidt@yadt.co.uk>",
   "Dom, Dominic Hargreaves <dom@earth.li>",
   "Fawkes, Christoph Ostermeier <fawkes@phat-net.de>",
@@ -91,7 +90,9 @@ const char *infotext[] =
   "knight, Alan LeVee <alan.levee@prometheus-designs.net>",
   "kre, Dinko Korunic <kreator@fly.srk.fer.hr>",
   "madmax, Paul Lomax <madmax@efnet.org>",
-  "Riedel, Dennis Vink, <riedel@chaotic.nl>",
+  "metalrock, Jack Low <xxjack12xx@gmail.com>",
+  "r0d3nt, Andrew Strutt <andrew.strutt@gmail.com>",
+  "Riedel, Dennis Vink <riedel@chaotic.nl>",
   "scuzzy, David Todd <scuzzy@aniverse.net>",
   "spookey, David Colburn <spookey@spookey.org>",
   "TimeMr14C, Yusuf Iskenderoglu <uhc0@stud.uni-karlsruhe.de>",
